/* PresenterNotes.c generated by valac 0.56.18, the Vala compiler
 * generated from PresenterNotes.vala, do not modify */

/*
* Copyright (c) 2018 Felipe Escoto (https://github.com/Philip-Scott/Spice-up)
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the
* Free Software Foundation, Inc., 59 Temple Place - Suite 330,
* Boston, MA 02111-1307, USA.
*
* Authored by: Felipe Escoto <felescoto95@hotmail.com>
*/

#include <gtk/gtk.h>
#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define SPICE_TYPE_PRESENTER_NOTES (spice_presenter_notes_get_type ())
#define SPICE_PRESENTER_NOTES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_PRESENTER_NOTES, SpicePresenterNotes))
#define SPICE_PRESENTER_NOTES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_PRESENTER_NOTES, SpicePresenterNotesClass))
#define SPICE_IS_PRESENTER_NOTES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_PRESENTER_NOTES))
#define SPICE_IS_PRESENTER_NOTES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_PRESENTER_NOTES))
#define SPICE_PRESENTER_NOTES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_PRESENTER_NOTES, SpicePresenterNotesClass))

typedef struct _SpicePresenterNotes SpicePresenterNotes;
typedef struct _SpicePresenterNotesClass SpicePresenterNotesClass;
typedef struct _SpicePresenterNotesPrivate SpicePresenterNotesPrivate;
enum  {
	SPICE_PRESENTER_NOTES_0_PROPERTY,
	SPICE_PRESENTER_NOTES_NOTES_AREA_PROPERTY,
	SPICE_PRESENTER_NOTES_NOTES_FOCUS_PROPERTY,
	SPICE_PRESENTER_NOTES_NUM_PROPERTIES
};
static GParamSpec* spice_presenter_notes_properties[SPICE_PRESENTER_NOTES_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
enum  {
	SPICE_PRESENTER_NOTES_TEXT_CHANGED_SIGNAL,
	SPICE_PRESENTER_NOTES_NUM_SIGNALS
};
static guint spice_presenter_notes_signals[SPICE_PRESENTER_NOTES_NUM_SIGNALS] = {0};

struct _SpicePresenterNotes {
	GtkRevealer parent_instance;
	SpicePresenterNotesPrivate * priv;
};

struct _SpicePresenterNotesClass {
	GtkRevealerClass parent_class;
};

struct _SpicePresenterNotesPrivate {
	GtkTextView* _notes_area;
	gboolean setting_text;
};

static gint SpicePresenterNotes_private_offset;
static gpointer spice_presenter_notes_parent_class = NULL;

VALA_EXTERN GType spice_presenter_notes_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpicePresenterNotes, g_object_unref)
VALA_EXTERN void spice_presenter_notes_focus_notes (SpicePresenterNotes* self);
VALA_EXTERN GtkTextView* spice_presenter_notes_get_notes_area (SpicePresenterNotes* self);
VALA_EXTERN void spice_presenter_notes_set_text (SpicePresenterNotes* self,
                                     const gchar* text);
VALA_EXTERN SpicePresenterNotes* spice_presenter_notes_new (void);
VALA_EXTERN SpicePresenterNotes* spice_presenter_notes_construct (GType object_type);
static void spice_presenter_notes_set_notes_area (SpicePresenterNotes* self,
                                           GtkTextView* value);
VALA_EXTERN gboolean spice_presenter_notes_get_notes_focus (SpicePresenterNotes* self);
static GObject * spice_presenter_notes_constructor (GType type,
                                             guint n_construct_properties,
                                             GObjectConstructParam * construct_properties);
static void _spice_presenter_notes___lambda95_ (SpicePresenterNotes* self);
static void __spice_presenter_notes___lambda95__gtk_text_buffer_changed (GtkTextBuffer* _sender,
                                                                  gpointer self);
static void spice_presenter_notes_finalize (GObject * obj);
static GType spice_presenter_notes_get_type_once (void);
static void _vala_spice_presenter_notes_get_property (GObject * object,
                                               guint property_id,
                                               GValue * value,
                                               GParamSpec * pspec);
static void _vala_spice_presenter_notes_set_property (GObject * object,
                                               guint property_id,
                                               const GValue * value,
                                               GParamSpec * pspec);

static inline gpointer
spice_presenter_notes_get_instance_private (SpicePresenterNotes* self)
{
	return G_STRUCT_MEMBER_P (self, SpicePresenterNotes_private_offset);
}

void
spice_presenter_notes_focus_notes (SpicePresenterNotes* self)
{
	GtkTextView* _tmp0_;
#line 63 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	g_return_if_fail (self != NULL);
#line 64 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp0_ = self->priv->_notes_area;
#line 64 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	gtk_widget_grab_focus ((GtkWidget*) _tmp0_);
#line 136 "PresenterNotes.c"
}

void
spice_presenter_notes_set_text (SpicePresenterNotes* self,
                                const gchar* text)
{
	GtkTextView* _tmp0_;
	GtkTextBuffer* _tmp1_;
	GtkTextBuffer* _tmp2_;
#line 67 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	g_return_if_fail (self != NULL);
#line 67 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	g_return_if_fail (text != NULL);
#line 68 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	self->priv->setting_text = TRUE;
#line 69 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp0_ = self->priv->_notes_area;
#line 69 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp1_ = gtk_text_view_get_buffer (_tmp0_);
#line 69 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp2_ = _tmp1_;
#line 69 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	g_object_set (_tmp2_, "text", text, NULL);
#line 70 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	self->priv->setting_text = FALSE;
#line 162 "PresenterNotes.c"
}

SpicePresenterNotes*
spice_presenter_notes_construct (GType object_type)
{
	SpicePresenterNotes * self = NULL;
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	self = (SpicePresenterNotes*) g_object_new (object_type, NULL);
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	return self;
#line 173 "PresenterNotes.c"
}

SpicePresenterNotes*
spice_presenter_notes_new (void)
{
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	return spice_presenter_notes_construct (SPICE_TYPE_PRESENTER_NOTES);
#line 181 "PresenterNotes.c"
}

GtkTextView*
spice_presenter_notes_get_notes_area (SpicePresenterNotes* self)
{
	GtkTextView* result;
	GtkTextView* _tmp0_;
#line 25 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 25 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp0_ = self->priv->_notes_area;
#line 25 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	result = _tmp0_;
#line 25 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	return result;
#line 197 "PresenterNotes.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 25 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	return self ? g_object_ref (self) : NULL;
#line 205 "PresenterNotes.c"
}

static void
spice_presenter_notes_set_notes_area (SpicePresenterNotes* self,
                                      GtkTextView* value)
{
	GtkTextView* old_value;
#line 25 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	g_return_if_fail (self != NULL);
#line 25 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	old_value = spice_presenter_notes_get_notes_area (self);
#line 25 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	if (old_value != value) {
#line 219 "PresenterNotes.c"
		GtkTextView* _tmp0_;
#line 25 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 25 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		_g_object_unref0 (self->priv->_notes_area);
#line 25 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		self->priv->_notes_area = _tmp0_;
#line 25 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		g_object_notify_by_pspec ((GObject *) self, spice_presenter_notes_properties[SPICE_PRESENTER_NOTES_NOTES_AREA_PROPERTY]);
#line 229 "PresenterNotes.c"
	}
}

gboolean
spice_presenter_notes_get_notes_focus (SpicePresenterNotes* self)
{
	gboolean result;
	GtkTextView* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 30 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 31 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp0_ = self->priv->_notes_area;
#line 31 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	g_object_get ((GtkWidget*) _tmp0_, "has-focus", &_tmp1_, NULL);
#line 31 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp2_ = _tmp1_;
#line 31 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	result = _tmp2_;
#line 31 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	return result;
#line 252 "PresenterNotes.c"
}

static void
_spice_presenter_notes___lambda95_ (SpicePresenterNotes* self)
{
#line 46 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	if (!self->priv->setting_text) {
#line 260 "PresenterNotes.c"
		GtkTextView* _tmp0_;
		GtkTextBuffer* _tmp1_;
		GtkTextBuffer* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
#line 47 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		_tmp0_ = self->priv->_notes_area;
#line 47 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		_tmp1_ = gtk_text_view_get_buffer (_tmp0_);
#line 47 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		_tmp2_ = _tmp1_;
#line 47 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		g_object_get (_tmp2_, "text", &_tmp3_, NULL);
#line 47 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		_tmp4_ = _tmp3_;
#line 47 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		_tmp5_ = _tmp4_;
#line 47 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		g_signal_emit (self, spice_presenter_notes_signals[SPICE_PRESENTER_NOTES_TEXT_CHANGED_SIGNAL], 0, _tmp5_);
#line 47 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		_g_free0 (_tmp5_);
#line 283 "PresenterNotes.c"
	}
}

static void
__spice_presenter_notes___lambda95__gtk_text_buffer_changed (GtkTextBuffer* _sender,
                                                             gpointer self)
{
#line 45 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_spice_presenter_notes___lambda95_ ((SpicePresenterNotes*) self);
#line 293 "PresenterNotes.c"
}

static GObject *
spice_presenter_notes_constructor (GType type,
                                   guint n_construct_properties,
                                   GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	SpicePresenterNotes * self;
	GtkGrid* grid = NULL;
	GtkGrid* _tmp0_;
	GtkGrid* _tmp1_;
	GtkTextView* _tmp2_;
	GtkTextView* _tmp3_;
	GtkTextView* _tmp4_;
	GtkTextView* _tmp5_;
	GtkTextView* _tmp6_;
	GtkStyleContext* _tmp7_;
	GtkTextView* _tmp8_;
	GtkStyleContext* _tmp9_;
	GtkTextView* _tmp10_;
	GtkTextBuffer* _tmp11_;
	GtkTextBuffer* _tmp12_;
	GtkScrolledWindow* notes_scrolled = NULL;
	GtkScrolledWindow* _tmp13_;
	GtkScrolledWindow* _tmp14_;
	GtkScrolledWindow* _tmp15_;
	GtkScrolledWindow* _tmp16_;
	GtkTextView* _tmp17_;
	GtkGrid* _tmp18_;
	GtkSeparator* _tmp19_;
	GtkSeparator* _tmp20_;
	GtkGrid* _tmp21_;
	GtkScrolledWindow* _tmp22_;
	GtkGrid* _tmp23_;
#line 35 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	parent_class = G_OBJECT_CLASS (spice_presenter_notes_parent_class);
#line 35 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 35 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPICE_TYPE_PRESENTER_NOTES, SpicePresenterNotes);
#line 36 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp0_ = (GtkGrid*) gtk_grid_new ();
#line 36 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	g_object_ref_sink (_tmp0_);
#line 36 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	grid = _tmp0_;
#line 37 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp1_ = grid;
#line 37 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	gtk_orientable_set_orientation ((GtkOrientable*) _tmp1_, GTK_ORIENTATION_VERTICAL);
#line 39 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp2_ = (GtkTextView*) gtk_text_view_new ();
#line 39 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	g_object_ref_sink (_tmp2_);
#line 39 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp3_ = _tmp2_;
#line 39 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	spice_presenter_notes_set_notes_area (self, _tmp3_);
#line 39 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_g_object_unref0 (_tmp3_);
#line 40 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp4_ = self->priv->_notes_area;
#line 40 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	gtk_text_view_set_wrap_mode (_tmp4_, GTK_WRAP_WORD);
#line 41 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp5_ = self->priv->_notes_area;
#line 41 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	gtk_text_view_set_left_margin (_tmp5_, 6);
#line 42 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp6_ = self->priv->_notes_area;
#line 42 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp7_ = gtk_widget_get_style_context ((GtkWidget*) _tmp6_);
#line 42 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	gtk_style_context_add_class (_tmp7_, "h3");
#line 43 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp8_ = self->priv->_notes_area;
#line 43 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp9_ = gtk_widget_get_style_context ((GtkWidget*) _tmp8_);
#line 43 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	gtk_style_context_add_class (_tmp9_, "h4");
#line 45 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp10_ = self->priv->_notes_area;
#line 45 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp11_ = gtk_text_view_get_buffer (_tmp10_);
#line 45 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp12_ = _tmp11_;
#line 45 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	g_signal_connect_object (_tmp12_, "changed", (GCallback) __spice_presenter_notes___lambda95__gtk_text_buffer_changed, self, 0);
#line 51 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp13_ = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
#line 51 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	g_object_ref_sink (_tmp13_);
#line 51 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	notes_scrolled = _tmp13_;
#line 52 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp14_ = notes_scrolled;
#line 52 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	gtk_scrolled_window_set_min_content_height (_tmp14_, 150);
#line 53 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp15_ = notes_scrolled;
#line 53 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	gtk_widget_set_hexpand ((GtkWidget*) _tmp15_, TRUE);
#line 54 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp16_ = notes_scrolled;
#line 54 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp17_ = self->priv->_notes_area;
#line 54 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	gtk_container_add ((GtkContainer*) _tmp16_, (GtkWidget*) _tmp17_);
#line 56 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp18_ = grid;
#line 56 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp19_ = (GtkSeparator*) gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
#line 56 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	g_object_ref_sink (_tmp19_);
#line 56 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp20_ = _tmp19_;
#line 56 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	gtk_container_add ((GtkContainer*) _tmp18_, (GtkWidget*) _tmp20_);
#line 56 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_g_object_unref0 (_tmp20_);
#line 57 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp21_ = grid;
#line 57 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp22_ = notes_scrolled;
#line 57 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	gtk_container_add ((GtkContainer*) _tmp21_, (GtkWidget*) _tmp22_);
#line 59 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_tmp23_ = grid;
#line 59 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp23_);
#line 60 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 35 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_g_object_unref0 (notes_scrolled);
#line 35 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_g_object_unref0 (grid);
#line 35 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	return obj;
#line 434 "PresenterNotes.c"
}

static void
spice_presenter_notes_class_init (SpicePresenterNotesClass * klass,
                                  gpointer klass_data)
{
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	spice_presenter_notes_parent_class = g_type_class_peek_parent (klass);
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	g_type_class_adjust_private_offset (klass, &SpicePresenterNotes_private_offset);
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_spice_presenter_notes_get_property;
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_spice_presenter_notes_set_property;
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	G_OBJECT_CLASS (klass)->constructor = spice_presenter_notes_constructor;
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	G_OBJECT_CLASS (klass)->finalize = spice_presenter_notes_finalize;
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SPICE_PRESENTER_NOTES_NOTES_AREA_PROPERTY, spice_presenter_notes_properties[SPICE_PRESENTER_NOTES_NOTES_AREA_PROPERTY] = g_param_spec_object ("notes-area", "notes-area", "notes-area", gtk_text_view_get_type (), G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SPICE_PRESENTER_NOTES_NOTES_FOCUS_PROPERTY, spice_presenter_notes_properties[SPICE_PRESENTER_NOTES_NOTES_FOCUS_PROPERTY] = g_param_spec_boolean ("notes-focus", "notes-focus", "notes-focus", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	spice_presenter_notes_signals[SPICE_PRESENTER_NOTES_TEXT_CHANGED_SIGNAL] = g_signal_new ("text-changed", SPICE_TYPE_PRESENTER_NOTES, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
#line 459 "PresenterNotes.c"
}

static void
spice_presenter_notes_instance_init (SpicePresenterNotes * self,
                                     gpointer klass)
{
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	self->priv = spice_presenter_notes_get_instance_private (self);
#line 27 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	self->priv->setting_text = FALSE;
#line 470 "PresenterNotes.c"
}

static void
spice_presenter_notes_finalize (GObject * obj)
{
	SpicePresenterNotes * self;
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPICE_TYPE_PRESENTER_NOTES, SpicePresenterNotes);
#line 25 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	_g_object_unref0 (self->priv->_notes_area);
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	G_OBJECT_CLASS (spice_presenter_notes_parent_class)->finalize (obj);
#line 483 "PresenterNotes.c"
}

static GType
spice_presenter_notes_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (SpicePresenterNotesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spice_presenter_notes_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpicePresenterNotes), 0, (GInstanceInitFunc) spice_presenter_notes_instance_init, NULL };
	GType spice_presenter_notes_type_id;
	spice_presenter_notes_type_id = g_type_register_static (gtk_revealer_get_type (), "SpicePresenterNotes", &g_define_type_info, 0);
	SpicePresenterNotes_private_offset = g_type_add_instance_private (spice_presenter_notes_type_id, sizeof (SpicePresenterNotesPrivate));
	return spice_presenter_notes_type_id;
}

GType
spice_presenter_notes_get_type (void)
{
	static volatile gsize spice_presenter_notes_type_id__once = 0;
	if (g_once_init_enter (&spice_presenter_notes_type_id__once)) {
		GType spice_presenter_notes_type_id;
		spice_presenter_notes_type_id = spice_presenter_notes_get_type_once ();
		g_once_init_leave (&spice_presenter_notes_type_id__once, spice_presenter_notes_type_id);
	}
	return spice_presenter_notes_type_id__once;
}

static void
_vala_spice_presenter_notes_get_property (GObject * object,
                                          guint property_id,
                                          GValue * value,
                                          GParamSpec * pspec)
{
	SpicePresenterNotes * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SPICE_TYPE_PRESENTER_NOTES, SpicePresenterNotes);
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	switch (property_id) {
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		case SPICE_PRESENTER_NOTES_NOTES_AREA_PROPERTY:
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		g_value_set_object (value, spice_presenter_notes_get_notes_area (self));
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		break;
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		case SPICE_PRESENTER_NOTES_NOTES_FOCUS_PROPERTY:
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		g_value_set_boolean (value, spice_presenter_notes_get_notes_focus (self));
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		break;
#line 530 "PresenterNotes.c"
		default:
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		break;
#line 536 "PresenterNotes.c"
	}
}

static void
_vala_spice_presenter_notes_set_property (GObject * object,
                                          guint property_id,
                                          const GValue * value,
                                          GParamSpec * pspec)
{
	SpicePresenterNotes * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SPICE_TYPE_PRESENTER_NOTES, SpicePresenterNotes);
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
	switch (property_id) {
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		case SPICE_PRESENTER_NOTES_NOTES_AREA_PROPERTY:
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		spice_presenter_notes_set_notes_area (self, g_value_get_object (value));
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		break;
#line 556 "PresenterNotes.c"
		default:
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 22 "../Spice-up-1.9.1/src/Widgets/PresenterNotes.vala"
		break;
#line 562 "PresenterNotes.c"
	}
}

