/* CommonBar.c generated by valac 0.56.18, the Vala compiler
 * generated from CommonBar.vala, do not modify */

/*
* Copyright (c) 2016 Felipe Escoto (https://github.com/Philip-Scott/Spice-up)
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the
* Free Software Foundation, Inc., 59 Temple Place - Suite 330,
* Boston, MA 02111-1307, USA.
*
* Authored by: Felipe Escoto <felescoto95@hotmail.com>
*/

#include <gtk/gtk.h>
#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>

#define SPICE_WINDOW_ACTION_DELETE "action_delete"
#define SPICE_WINDOW_ACTION_CLONE "action_clone"
#define SPICE_WINDOW_ACTION_BRING_FWD "action_bring_fwd"
#define SPICE_WINDOW_ACTION_BRING_BWD "action_send_bwd"
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define SPICE_WIDGETS_TYPE_TOOLBAR (spice_widgets_toolbar_get_type ())
#define SPICE_WIDGETS_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_WIDGETS_TYPE_TOOLBAR, SpiceWidgetsToolbar))
#define SPICE_WIDGETS_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_WIDGETS_TYPE_TOOLBAR, SpiceWidgetsToolbarClass))
#define SPICE_WIDGETS_IS_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_WIDGETS_TYPE_TOOLBAR))
#define SPICE_WIDGETS_IS_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_WIDGETS_TYPE_TOOLBAR))
#define SPICE_WIDGETS_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_WIDGETS_TYPE_TOOLBAR, SpiceWidgetsToolbarClass))

typedef struct _SpiceWidgetsToolbar SpiceWidgetsToolbar;
typedef struct _SpiceWidgetsToolbarClass SpiceWidgetsToolbarClass;
typedef struct _SpiceWidgetsToolbarPrivate SpiceWidgetsToolbarPrivate;

#define SPICE_TYPE_CANVAS_ITEM (spice_canvas_item_get_type ())
#define SPICE_CANVAS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_CANVAS_ITEM, SpiceCanvasItem))
#define SPICE_CANVAS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_CANVAS_ITEM, SpiceCanvasItemClass))
#define SPICE_IS_CANVAS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_CANVAS_ITEM))
#define SPICE_IS_CANVAS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_CANVAS_ITEM))
#define SPICE_CANVAS_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_CANVAS_ITEM, SpiceCanvasItemClass))

typedef struct _SpiceCanvasItem SpiceCanvasItem;
typedef struct _SpiceCanvasItemClass SpiceCanvasItemClass;

#define SPICE_WIDGETS_TYPE_COMMON_TOOLBAR (spice_widgets_common_toolbar_get_type ())
#define SPICE_WIDGETS_COMMON_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_WIDGETS_TYPE_COMMON_TOOLBAR, SpiceWidgetsCommonToolbar))
#define SPICE_WIDGETS_COMMON_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_WIDGETS_TYPE_COMMON_TOOLBAR, SpiceWidgetsCommonToolbarClass))
#define SPICE_WIDGETS_IS_COMMON_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_WIDGETS_TYPE_COMMON_TOOLBAR))
#define SPICE_WIDGETS_IS_COMMON_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_WIDGETS_TYPE_COMMON_TOOLBAR))
#define SPICE_WIDGETS_COMMON_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_WIDGETS_TYPE_COMMON_TOOLBAR, SpiceWidgetsCommonToolbarClass))

typedef struct _SpiceWidgetsCommonToolbar SpiceWidgetsCommonToolbar;
typedef struct _SpiceWidgetsCommonToolbarClass SpiceWidgetsCommonToolbarClass;
typedef struct _SpiceWidgetsCommonToolbarPrivate SpiceWidgetsCommonToolbarPrivate;

#define SPICE_TYPE_SLIDE_MANAGER (spice_slide_manager_get_type ())
#define SPICE_SLIDE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManager))
#define SPICE_SLIDE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManagerClass))
#define SPICE_IS_SLIDE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_SLIDE_MANAGER))
#define SPICE_IS_SLIDE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_SLIDE_MANAGER))
#define SPICE_SLIDE_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManagerClass))

typedef struct _SpiceSlideManager SpiceSlideManager;
typedef struct _SpiceSlideManagerClass SpiceSlideManagerClass;
enum  {
	SPICE_WIDGETS_COMMON_TOOLBAR_0_PROPERTY,
	SPICE_WIDGETS_COMMON_TOOLBAR_MANAGER_PROPERTY,
	SPICE_WIDGETS_COMMON_TOOLBAR_NUM_PROPERTIES
};
static GParamSpec* spice_widgets_common_toolbar_properties[SPICE_WIDGETS_COMMON_TOOLBAR_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define SPICE_TYPE_WINDOW (spice_window_get_type ())
#define SPICE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_WINDOW, SpiceWindow))
#define SPICE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_WINDOW, SpiceWindowClass))
#define SPICE_IS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_WINDOW))
#define SPICE_IS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_WINDOW))
#define SPICE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_WINDOW, SpiceWindowClass))

typedef struct _SpiceWindow SpiceWindow;
typedef struct _SpiceWindowClass SpiceWindowClass;

#define SPICE_TYPE_SLIDE (spice_slide_get_type ())
#define SPICE_SLIDE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_SLIDE, SpiceSlide))
#define SPICE_SLIDE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_SLIDE, SpiceSlideClass))
#define SPICE_IS_SLIDE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_SLIDE))
#define SPICE_IS_SLIDE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_SLIDE))
#define SPICE_SLIDE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_SLIDE, SpiceSlideClass))

typedef struct _SpiceSlide SpiceSlide;
typedef struct _SpiceSlideClass SpiceSlideClass;

struct _SpiceWidgetsToolbar {
	GtkBox parent_instance;
	SpiceWidgetsToolbarPrivate * priv;
	gboolean init;
	gboolean selecting;
	SpiceCanvasItem* item;
};

struct _SpiceWidgetsToolbarClass {
	GtkBoxClass parent_class;
	void (*item_selected) (SpiceWidgetsToolbar* self, SpiceCanvasItem* item, gboolean new_item);
	void (*update_properties) (SpiceWidgetsToolbar* self);
};

struct _SpiceWidgetsCommonToolbar {
	SpiceWidgetsToolbar parent_instance;
	SpiceWidgetsCommonToolbarPrivate * priv;
};

struct _SpiceWidgetsCommonToolbarClass {
	SpiceWidgetsToolbarClass parent_class;
};

struct _SpiceWidgetsCommonToolbarPrivate {
	SpiceSlideManager* _manager;
	GtkButton* to_top;
	GtkButton* to_bottom;
	GtkButton* delete_button;
	GtkButton* clone_button;
};

static gint SpiceWidgetsCommonToolbar_private_offset;
static gpointer spice_widgets_common_toolbar_parent_class = NULL;

VALA_EXTERN GType spice_widgets_toolbar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceWidgetsToolbar, g_object_unref)
VALA_EXTERN GType spice_canvas_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceCanvasItem, g_object_unref)
VALA_EXTERN GType spice_widgets_common_toolbar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceWidgetsCommonToolbar, g_object_unref)
VALA_EXTERN GType spice_slide_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceSlideManager, g_object_unref)
VALA_EXTERN void spice_widgets_toolbar_item_selected (SpiceWidgetsToolbar* self,
                                          SpiceCanvasItem* item,
                                          gboolean new_item);
VALA_EXTERN void spice_widgets_toolbar_update_properties (SpiceWidgetsToolbar* self);
VALA_EXTERN SpiceWidgetsCommonToolbar* spice_widgets_common_toolbar_new (SpiceSlideManager* slide_manager);
VALA_EXTERN SpiceWidgetsCommonToolbar* spice_widgets_common_toolbar_construct (GType object_type,
                                                                   SpiceSlideManager* slide_manager);
static void spice_widgets_common_toolbar_real_item_selected (SpiceWidgetsToolbar* base,
                                                      SpiceCanvasItem* item,
                                                      gboolean new_item);
static void spice_widgets_common_toolbar_real_update_properties (SpiceWidgetsToolbar* base);
VALA_EXTERN SpiceSlideManager* spice_widgets_common_toolbar_get_manager (SpiceWidgetsCommonToolbar* self);
static void spice_widgets_common_toolbar_set_manager (SpiceWidgetsCommonToolbar* self,
                                               SpiceSlideManager* value);
static GObject * spice_widgets_common_toolbar_constructor (GType type,
                                                    guint n_construct_properties,
                                                    GObjectConstructParam * construct_properties);
VALA_EXTERN gchar* spice_utils_get_accel_tooltip (const gchar* action_name,
                                      const gchar* description);
VALA_EXTERN GType spice_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceWindow, g_object_unref)
VALA_EXTERN SpiceWindow* spice_slide_manager_get_window (SpiceSlideManager* self);
VALA_EXTERN void spice_window_delete_object (SpiceWindow* self);
static void _spice_window_delete_object_gtk_button_clicked (GtkButton* _sender,
                                                     gpointer self);
static void _spice_widgets_common_toolbar___lambda116_ (SpiceWidgetsCommonToolbar* self);
VALA_EXTERN void spice_clipboard_duplicate (SpiceSlideManager* manager,
                                GObject* object);
VALA_EXTERN GType spice_slide_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceSlide, g_object_unref)
VALA_EXTERN SpiceSlide* spice_slide_manager_get_current_slide (SpiceSlideManager* self);
static void __spice_widgets_common_toolbar___lambda116__gtk_button_clicked (GtkButton* _sender,
                                                                     gpointer self);
VALA_EXTERN void spice_window_action_bring_fwd (SpiceWindow* self);
static void _spice_window_action_bring_fwd_gtk_button_clicked (GtkButton* _sender,
                                                        gpointer self);
VALA_EXTERN void spice_window_action_send_bwd (SpiceWindow* self);
static void _spice_window_action_send_bwd_gtk_button_clicked (GtkButton* _sender,
                                                       gpointer self);
static void spice_widgets_common_toolbar_finalize (GObject * obj);
static GType spice_widgets_common_toolbar_get_type_once (void);
static void _vala_spice_widgets_common_toolbar_get_property (GObject * object,
                                                      guint property_id,
                                                      GValue * value,
                                                      GParamSpec * pspec);
static void _vala_spice_widgets_common_toolbar_set_property (GObject * object,
                                                      guint property_id,
                                                      const GValue * value,
                                                      GParamSpec * pspec);

static inline gpointer
spice_widgets_common_toolbar_get_instance_private (SpiceWidgetsCommonToolbar* self)
{
	return G_STRUCT_MEMBER_P (self, SpiceWidgetsCommonToolbar_private_offset);
}

SpiceWidgetsCommonToolbar*
spice_widgets_common_toolbar_construct (GType object_type,
                                        SpiceSlideManager* slide_manager)
{
	SpiceWidgetsCommonToolbar * self = NULL;
#line 29 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	g_return_val_if_fail (slide_manager != NULL, NULL);
#line 30 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	self = (SpiceWidgetsCommonToolbar*) g_object_new (object_type, "manager", slide_manager, NULL);
#line 29 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	return self;
#line 234 "CommonBar.c"
}

SpiceWidgetsCommonToolbar*
spice_widgets_common_toolbar_new (SpiceSlideManager* slide_manager)
{
#line 29 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	return spice_widgets_common_toolbar_construct (SPICE_WIDGETS_TYPE_COMMON_TOOLBAR, slide_manager);
#line 242 "CommonBar.c"
}

static void
spice_widgets_common_toolbar_real_item_selected (SpiceWidgetsToolbar* base,
                                                 SpiceCanvasItem* item,
                                                 gboolean new_item)
{
	SpiceWidgetsCommonToolbar * self;
#line 76 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	self = (SpiceWidgetsCommonToolbar*) base;
#line 253 "CommonBar.c"
}

static void
spice_widgets_common_toolbar_real_update_properties (SpiceWidgetsToolbar* base)
{
	SpiceWidgetsCommonToolbar * self;
#line 80 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	self = (SpiceWidgetsCommonToolbar*) base;
#line 262 "CommonBar.c"
}

SpiceSlideManager*
spice_widgets_common_toolbar_get_manager (SpiceWidgetsCommonToolbar* self)
{
	SpiceSlideManager* result;
	SpiceSlideManager* _tmp0_;
#line 23 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 23 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp0_ = self->priv->_manager;
#line 23 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	result = _tmp0_;
#line 23 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	return result;
#line 278 "CommonBar.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 23 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	return self ? g_object_ref (self) : NULL;
#line 286 "CommonBar.c"
}

static void
spice_widgets_common_toolbar_set_manager (SpiceWidgetsCommonToolbar* self,
                                          SpiceSlideManager* value)
{
	SpiceSlideManager* old_value;
#line 23 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	g_return_if_fail (self != NULL);
#line 23 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	old_value = spice_widgets_common_toolbar_get_manager (self);
#line 23 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	if (old_value != value) {
#line 300 "CommonBar.c"
		SpiceSlideManager* _tmp0_;
#line 23 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 23 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		_g_object_unref0 (self->priv->_manager);
#line 23 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		self->priv->_manager = _tmp0_;
#line 23 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		g_object_notify_by_pspec ((GObject *) self, spice_widgets_common_toolbar_properties[SPICE_WIDGETS_COMMON_TOOLBAR_MANAGER_PROPERTY]);
#line 310 "CommonBar.c"
	}
}

static void
_spice_window_delete_object_gtk_button_clicked (GtkButton* _sender,
                                                gpointer self)
{
#line 41 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	spice_window_delete_object ((SpiceWindow*) self);
#line 320 "CommonBar.c"
}

static void
_spice_widgets_common_toolbar___lambda116_ (SpiceWidgetsCommonToolbar* self)
{
	SpiceCanvasItem* _tmp0_;
#line 48 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp0_ = ((SpiceWidgetsToolbar*) self)->item;
#line 48 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	if (_tmp0_ != NULL) {
#line 331 "CommonBar.c"
		SpiceSlideManager* _tmp1_;
		SpiceCanvasItem* _tmp2_;
#line 49 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		_tmp1_ = self->priv->_manager;
#line 49 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		_tmp2_ = ((SpiceWidgetsToolbar*) self)->item;
#line 49 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		spice_clipboard_duplicate (_tmp1_, (GObject*) _tmp2_);
#line 340 "CommonBar.c"
	} else {
		SpiceSlideManager* _tmp3_;
		SpiceSlideManager* _tmp4_;
		SpiceSlide* _tmp5_;
		SpiceSlide* _tmp6_;
#line 51 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		_tmp3_ = self->priv->_manager;
#line 51 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		_tmp4_ = self->priv->_manager;
#line 51 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		_tmp5_ = spice_slide_manager_get_current_slide (_tmp4_);
#line 51 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		_tmp6_ = _tmp5_;
#line 51 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		spice_clipboard_duplicate (_tmp3_, (GObject*) _tmp6_);
#line 356 "CommonBar.c"
	}
}

static void
__spice_widgets_common_toolbar___lambda116__gtk_button_clicked (GtkButton* _sender,
                                                                gpointer self)
{
#line 47 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_spice_widgets_common_toolbar___lambda116_ ((SpiceWidgetsCommonToolbar*) self);
#line 366 "CommonBar.c"
}

static void
_spice_window_action_bring_fwd_gtk_button_clicked (GtkButton* _sender,
                                                   gpointer self)
{
#line 68 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	spice_window_action_bring_fwd ((SpiceWindow*) self);
#line 375 "CommonBar.c"
}

static void
_spice_window_action_send_bwd_gtk_button_clicked (GtkButton* _sender,
                                                  gpointer self)
{
#line 69 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	spice_window_action_send_bwd ((SpiceWindow*) self);
#line 384 "CommonBar.c"
}

static GObject *
spice_widgets_common_toolbar_constructor (GType type,
                                          guint n_construct_properties,
                                          GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	SpiceWidgetsCommonToolbar * self;
	GtkButton* _tmp0_;
	GtkButton* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	GtkButton* _tmp4_;
	GtkStyleContext* _tmp5_;
	GtkButton* _tmp6_;
	SpiceSlideManager* _tmp7_;
	SpiceWindow* _tmp8_;
	SpiceWindow* _tmp9_;
	GtkButton* _tmp10_;
	GtkButton* _tmp11_;
	GtkStyleContext* _tmp12_;
	GtkButton* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	GtkButton* _tmp16_;
	GtkButton* _tmp17_;
	GtkButton* _tmp18_;
	GtkStyleContext* _tmp19_;
	GtkButton* _tmp20_;
	gchar* _tmp21_;
	gchar* _tmp22_;
	GtkButton* _tmp23_;
	GtkButton* _tmp24_;
	GtkStyleContext* _tmp25_;
	GtkButton* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	GtkBox* position_grid = NULL;
	GtkBox* _tmp29_;
	GtkBox* _tmp30_;
	GtkStyleContext* _tmp31_;
	GtkBox* _tmp32_;
	GtkButton* _tmp33_;
	GtkBox* _tmp34_;
	GtkButton* _tmp35_;
	GtkButton* _tmp36_;
	SpiceSlideManager* _tmp37_;
	SpiceWindow* _tmp38_;
	SpiceWindow* _tmp39_;
	GtkButton* _tmp40_;
	SpiceSlideManager* _tmp41_;
	SpiceWindow* _tmp42_;
	SpiceWindow* _tmp43_;
	GtkBox* _tmp44_;
	GtkButton* _tmp45_;
	GtkButton* _tmp46_;
#line 33 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	parent_class = G_OBJECT_CLASS (spice_widgets_common_toolbar_parent_class);
#line 33 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 33 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPICE_WIDGETS_TYPE_COMMON_TOOLBAR, SpiceWidgetsCommonToolbar);
#line 34 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	gtk_widget_set_hexpand ((GtkWidget*) self, TRUE);
#line 35 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	gtk_widget_set_halign ((GtkWidget*) self, GTK_ALIGN_END);
#line 37 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp0_ = (GtkButton*) gtk_button_new_from_icon_name ("edit-delete-symbolic", (GtkIconSize) GTK_ICON_SIZE_MENU);
#line 37 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	g_object_ref_sink (_tmp0_);
#line 37 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_g_object_unref0 (self->priv->delete_button);
#line 37 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	self->priv->delete_button = _tmp0_;
#line 38 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp1_ = self->priv->delete_button;
#line 38 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp2_ = spice_utils_get_accel_tooltip (SPICE_WINDOW_ACTION_DELETE, _ ("Delete"));
#line 38 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp3_ = _tmp2_;
#line 38 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	gtk_widget_set_tooltip_markup ((GtkWidget*) _tmp1_, _tmp3_);
#line 38 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_g_free0 (_tmp3_);
#line 39 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp4_ = self->priv->delete_button;
#line 39 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp5_ = gtk_widget_get_style_context ((GtkWidget*) _tmp4_);
#line 39 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	gtk_style_context_add_class (_tmp5_, GTK_STYLE_CLASS_RAISED);
#line 41 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp6_ = self->priv->delete_button;
#line 41 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp7_ = self->priv->_manager;
#line 41 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp8_ = spice_slide_manager_get_window (_tmp7_);
#line 41 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp9_ = _tmp8_;
#line 41 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	g_signal_connect_object (_tmp6_, "clicked", (GCallback) _spice_window_delete_object_gtk_button_clicked, _tmp9_, 0);
#line 43 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp10_ = (GtkButton*) gtk_button_new_from_icon_name ("edit-copy-symbolic", (GtkIconSize) GTK_ICON_SIZE_MENU);
#line 43 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	g_object_ref_sink (_tmp10_);
#line 43 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_g_object_unref0 (self->priv->clone_button);
#line 43 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	self->priv->clone_button = _tmp10_;
#line 44 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp11_ = self->priv->clone_button;
#line 44 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp12_ = gtk_widget_get_style_context ((GtkWidget*) _tmp11_);
#line 44 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	gtk_style_context_add_class (_tmp12_, GTK_STYLE_CLASS_RAISED);
#line 45 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp13_ = self->priv->clone_button;
#line 45 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp14_ = spice_utils_get_accel_tooltip (SPICE_WINDOW_ACTION_CLONE, _ ("Clone"));
#line 45 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp15_ = _tmp14_;
#line 45 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	gtk_widget_set_tooltip_markup ((GtkWidget*) _tmp13_, _tmp15_);
#line 45 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_g_free0 (_tmp15_);
#line 47 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp16_ = self->priv->clone_button;
#line 47 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	g_signal_connect_object (_tmp16_, "clicked", (GCallback) __spice_widgets_common_toolbar___lambda116__gtk_button_clicked, self, 0);
#line 55 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp17_ = (GtkButton*) gtk_button_new_from_icon_name ("selection-raise-symbolic", (GtkIconSize) GTK_ICON_SIZE_MENU);
#line 55 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	g_object_ref_sink (_tmp17_);
#line 55 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_g_object_unref0 (self->priv->to_top);
#line 55 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	self->priv->to_top = _tmp17_;
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp18_ = self->priv->to_top;
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp19_ = gtk_widget_get_style_context ((GtkWidget*) _tmp18_);
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	gtk_style_context_add_class (_tmp19_, GTK_STYLE_CLASS_RAISED);
#line 57 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp20_ = self->priv->to_top;
#line 57 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp21_ = spice_utils_get_accel_tooltip (SPICE_WINDOW_ACTION_BRING_FWD, _ ("Bring forward"));
#line 57 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp22_ = _tmp21_;
#line 57 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	gtk_widget_set_tooltip_markup ((GtkWidget*) _tmp20_, _tmp22_);
#line 57 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_g_free0 (_tmp22_);
#line 59 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp23_ = (GtkButton*) gtk_button_new_from_icon_name ("selection-lower-symbolic", (GtkIconSize) GTK_ICON_SIZE_MENU);
#line 59 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	g_object_ref_sink (_tmp23_);
#line 59 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_g_object_unref0 (self->priv->to_bottom);
#line 59 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	self->priv->to_bottom = _tmp23_;
#line 60 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp24_ = self->priv->to_bottom;
#line 60 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp25_ = gtk_widget_get_style_context ((GtkWidget*) _tmp24_);
#line 60 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	gtk_style_context_add_class (_tmp25_, GTK_STYLE_CLASS_RAISED);
#line 61 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp26_ = self->priv->to_bottom;
#line 61 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp27_ = spice_utils_get_accel_tooltip (SPICE_WINDOW_ACTION_BRING_BWD, _ ("Send backward"));
#line 61 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp28_ = _tmp27_;
#line 61 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	gtk_widget_set_tooltip_markup ((GtkWidget*) _tmp26_, _tmp28_);
#line 61 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_g_free0 (_tmp28_);
#line 63 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp29_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
#line 63 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	g_object_ref_sink (_tmp29_);
#line 63 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	position_grid = _tmp29_;
#line 64 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp30_ = position_grid;
#line 64 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp31_ = gtk_widget_get_style_context ((GtkWidget*) _tmp30_);
#line 64 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	gtk_style_context_add_class (_tmp31_, "linked");
#line 65 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp32_ = position_grid;
#line 65 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp33_ = self->priv->to_top;
#line 65 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	gtk_container_add ((GtkContainer*) _tmp32_, (GtkWidget*) _tmp33_);
#line 66 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp34_ = position_grid;
#line 66 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp35_ = self->priv->to_bottom;
#line 66 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	gtk_container_add ((GtkContainer*) _tmp34_, (GtkWidget*) _tmp35_);
#line 68 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp36_ = self->priv->to_top;
#line 68 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp37_ = self->priv->_manager;
#line 68 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp38_ = spice_slide_manager_get_window (_tmp37_);
#line 68 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp39_ = _tmp38_;
#line 68 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	g_signal_connect_object (_tmp36_, "clicked", (GCallback) _spice_window_action_bring_fwd_gtk_button_clicked, _tmp39_, 0);
#line 69 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp40_ = self->priv->to_bottom;
#line 69 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp41_ = self->priv->_manager;
#line 69 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp42_ = spice_slide_manager_get_window (_tmp41_);
#line 69 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp43_ = _tmp42_;
#line 69 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	g_signal_connect_object (_tmp40_, "clicked", (GCallback) _spice_window_action_send_bwd_gtk_button_clicked, _tmp43_, 0);
#line 71 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp44_ = position_grid;
#line 71 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp44_);
#line 72 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp45_ = self->priv->clone_button;
#line 72 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp45_);
#line 73 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_tmp46_ = self->priv->delete_button;
#line 73 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp46_);
#line 33 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_g_object_unref0 (position_grid);
#line 33 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	return obj;
#line 623 "CommonBar.c"
}

static void
spice_widgets_common_toolbar_class_init (SpiceWidgetsCommonToolbarClass * klass,
                                         gpointer klass_data)
{
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	spice_widgets_common_toolbar_parent_class = g_type_class_peek_parent (klass);
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	g_type_class_adjust_private_offset (klass, &SpiceWidgetsCommonToolbar_private_offset);
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	((SpiceWidgetsToolbarClass *) klass)->item_selected = (void (*) (SpiceWidgetsToolbar*, SpiceCanvasItem*, gboolean)) spice_widgets_common_toolbar_real_item_selected;
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	((SpiceWidgetsToolbarClass *) klass)->update_properties = (void (*) (SpiceWidgetsToolbar*)) spice_widgets_common_toolbar_real_update_properties;
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_spice_widgets_common_toolbar_get_property;
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_spice_widgets_common_toolbar_set_property;
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	G_OBJECT_CLASS (klass)->constructor = spice_widgets_common_toolbar_constructor;
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	G_OBJECT_CLASS (klass)->finalize = spice_widgets_common_toolbar_finalize;
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SPICE_WIDGETS_COMMON_TOOLBAR_MANAGER_PROPERTY, spice_widgets_common_toolbar_properties[SPICE_WIDGETS_COMMON_TOOLBAR_MANAGER_PROPERTY] = g_param_spec_object ("manager", "manager", "manager", SPICE_TYPE_SLIDE_MANAGER, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 648 "CommonBar.c"
}

static void
spice_widgets_common_toolbar_instance_init (SpiceWidgetsCommonToolbar * self,
                                            gpointer klass)
{
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	self->priv = spice_widgets_common_toolbar_get_instance_private (self);
#line 657 "CommonBar.c"
}

static void
spice_widgets_common_toolbar_finalize (GObject * obj)
{
	SpiceWidgetsCommonToolbar * self;
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPICE_WIDGETS_TYPE_COMMON_TOOLBAR, SpiceWidgetsCommonToolbar);
#line 23 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_g_object_unref0 (self->priv->_manager);
#line 24 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_g_object_unref0 (self->priv->to_top);
#line 25 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_g_object_unref0 (self->priv->to_bottom);
#line 26 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_g_object_unref0 (self->priv->delete_button);
#line 27 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	_g_object_unref0 (self->priv->clone_button);
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	G_OBJECT_CLASS (spice_widgets_common_toolbar_parent_class)->finalize (obj);
#line 678 "CommonBar.c"
}

static GType
spice_widgets_common_toolbar_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (SpiceWidgetsCommonToolbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spice_widgets_common_toolbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpiceWidgetsCommonToolbar), 0, (GInstanceInitFunc) spice_widgets_common_toolbar_instance_init, NULL };
	GType spice_widgets_common_toolbar_type_id;
	spice_widgets_common_toolbar_type_id = g_type_register_static (SPICE_WIDGETS_TYPE_TOOLBAR, "SpiceWidgetsCommonToolbar", &g_define_type_info, 0);
	SpiceWidgetsCommonToolbar_private_offset = g_type_add_instance_private (spice_widgets_common_toolbar_type_id, sizeof (SpiceWidgetsCommonToolbarPrivate));
	return spice_widgets_common_toolbar_type_id;
}

GType
spice_widgets_common_toolbar_get_type (void)
{
	static volatile gsize spice_widgets_common_toolbar_type_id__once = 0;
	if (g_once_init_enter (&spice_widgets_common_toolbar_type_id__once)) {
		GType spice_widgets_common_toolbar_type_id;
		spice_widgets_common_toolbar_type_id = spice_widgets_common_toolbar_get_type_once ();
		g_once_init_leave (&spice_widgets_common_toolbar_type_id__once, spice_widgets_common_toolbar_type_id);
	}
	return spice_widgets_common_toolbar_type_id__once;
}

static void
_vala_spice_widgets_common_toolbar_get_property (GObject * object,
                                                 guint property_id,
                                                 GValue * value,
                                                 GParamSpec * pspec)
{
	SpiceWidgetsCommonToolbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SPICE_WIDGETS_TYPE_COMMON_TOOLBAR, SpiceWidgetsCommonToolbar);
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	switch (property_id) {
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		case SPICE_WIDGETS_COMMON_TOOLBAR_MANAGER_PROPERTY:
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		g_value_set_object (value, spice_widgets_common_toolbar_get_manager (self));
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		break;
#line 719 "CommonBar.c"
		default:
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		break;
#line 725 "CommonBar.c"
	}
}

static void
_vala_spice_widgets_common_toolbar_set_property (GObject * object,
                                                 guint property_id,
                                                 const GValue * value,
                                                 GParamSpec * pspec)
{
	SpiceWidgetsCommonToolbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SPICE_WIDGETS_TYPE_COMMON_TOOLBAR, SpiceWidgetsCommonToolbar);
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
	switch (property_id) {
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		case SPICE_WIDGETS_COMMON_TOOLBAR_MANAGER_PROPERTY:
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		spice_widgets_common_toolbar_set_manager (self, g_value_get_object (value));
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		break;
#line 745 "CommonBar.c"
		default:
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CommonBar.vala"
		break;
#line 751 "CommonBar.c"
	}
}

