/* SlideWidget.c generated by valac 0.56.18, the Vala compiler
 * generated from SlideWidget.vala, do not modify */

/*
* Copyright (c) 2017 Felipe Escoto (https://github.com/Philip-Scott/Spice-up)
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the
* Free Software Foundation, Inc., 59 Temple Place - Suite 330,
* Boston, MA 02111-1307, USA.
*
* Authored by: Felipe Escoto <felescoto95@hotmail.com>
*/

#include <gtk/gtk.h>
#include <glib-object.h>
#include <glib.h>
#include <json-glib/json-glib.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gdk/gdk.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define SPICE_TYPE_SLIDE_WIDGET (spice_slide_widget_get_type ())
#define SPICE_SLIDE_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_SLIDE_WIDGET, SpiceSlideWidget))
#define SPICE_SLIDE_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_SLIDE_WIDGET, SpiceSlideWidgetClass))
#define SPICE_IS_SLIDE_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_SLIDE_WIDGET))
#define SPICE_IS_SLIDE_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_SLIDE_WIDGET))
#define SPICE_SLIDE_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_SLIDE_WIDGET, SpiceSlideWidgetClass))

typedef struct _SpiceSlideWidget SpiceSlideWidget;
typedef struct _SpiceSlideWidgetClass SpiceSlideWidgetClass;
typedef struct _SpiceSlideWidgetPrivate SpiceSlideWidgetPrivate;
enum  {
	SPICE_SLIDE_WIDGET_0_PROPERTY,
	SPICE_SLIDE_WIDGET_PIXBUF_PROPERTY,
	SPICE_SLIDE_WIDGET_NUM_PROPERTIES
};
static GParamSpec* spice_slide_widget_properties[SPICE_SLIDE_WIDGET_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define SPICE_TYPE_SLIDE (spice_slide_get_type ())
#define SPICE_SLIDE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_SLIDE, SpiceSlide))
#define SPICE_SLIDE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_SLIDE, SpiceSlideClass))
#define SPICE_IS_SLIDE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_SLIDE))
#define SPICE_IS_SLIDE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_SLIDE))
#define SPICE_SLIDE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_SLIDE, SpiceSlideClass))

typedef struct _SpiceSlide SpiceSlide;
typedef struct _SpiceSlideClass SpiceSlideClass;
typedef struct _SpiceSlidePrivate SpiceSlidePrivate;

#define SPICE_TYPE_CANVAS (spice_canvas_get_type ())
#define SPICE_CANVAS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_CANVAS, SpiceCanvas))
#define SPICE_CANVAS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_CANVAS, SpiceCanvasClass))
#define SPICE_IS_CANVAS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_CANVAS))
#define SPICE_IS_CANVAS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_CANVAS))
#define SPICE_CANVAS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_CANVAS, SpiceCanvasClass))

typedef struct _SpiceCanvas SpiceCanvas;
typedef struct _SpiceCanvasClass SpiceCanvasClass;
enum  {
	SPICE_SLIDE_WIDGET_SETTINGS_REQUESTED_SIGNAL,
	SPICE_SLIDE_WIDGET_NUM_SIGNALS
};
static guint spice_slide_widget_signals[SPICE_SLIDE_WIDGET_NUM_SIGNALS] = {0};

struct _SpiceSlideWidget {
	GtkEventBox parent_instance;
	SpiceSlideWidgetPrivate * priv;
	gboolean show_button;
	GtkRevealer* settings_revealer;
};

struct _SpiceSlideWidgetClass {
	GtkEventBoxClass parent_class;
};

struct _SpiceSlideWidgetPrivate {
	GtkOverlay* overlay;
	GtkImage* image;
};

struct _SpiceSlide {
	GObject parent_instance;
	SpiceSlidePrivate * priv;
	JsonObject* save_data;
	SpiceCanvas* canvas;
	GtkImage* preview;
};

struct _SpiceSlideClass {
	GObjectClass parent_class;
};

static gint SpiceSlideWidget_private_offset;
static gpointer spice_slide_widget_parent_class = NULL;

VALA_EXTERN GType spice_slide_widget_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceSlideWidget, g_object_unref)
VALA_EXTERN GType spice_slide_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceSlide, g_object_unref)
VALA_EXTERN SpiceSlideWidget* spice_slide_widget_new_from_slide (SpiceSlide* slide);
VALA_EXTERN SpiceSlideWidget* spice_slide_widget_construct_from_slide (GType object_type,
                                                           SpiceSlide* slide);
VALA_EXTERN GType spice_canvas_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceCanvas, g_object_unref)
VALA_EXTERN SpiceSlideWidget* spice_slide_widget_new (void);
VALA_EXTERN SpiceSlideWidget* spice_slide_widget_construct (GType object_type);
VALA_EXTERN void spice_slide_widget_set_pixbuf (SpiceSlideWidget* self,
                                    GdkPixbuf* value);
static GObject * spice_slide_widget_constructor (GType type,
                                          guint n_construct_properties,
                                          GObjectConstructParam * construct_properties);
static void _spice_slide_widget___lambda4_ (SpiceSlideWidget* self);
static void __spice_slide_widget___lambda4__gtk_button_clicked (GtkButton* _sender,
                                                         gpointer self);
static gboolean _spice_slide_widget___lambda5_ (SpiceSlideWidget* self,
                                         GdkEventCrossing* event);
static gboolean __spice_slide_widget___lambda5__gtk_widget_enter_notify_event (GtkWidget* _sender,
                                                                        GdkEventCrossing* event,
                                                                        gpointer self);
static gboolean _spice_slide_widget___lambda6_ (SpiceSlideWidget* self,
                                         GdkEventCrossing* event);
static gboolean __spice_slide_widget___lambda6__gtk_widget_enter_notify_event (GtkWidget* _sender,
                                                                        GdkEventCrossing* event,
                                                                        gpointer self);
static gboolean _spice_slide_widget___lambda7_ (SpiceSlideWidget* self,
                                         GdkEventCrossing* event);
static gboolean __spice_slide_widget___lambda7__gtk_widget_leave_notify_event (GtkWidget* _sender,
                                                                        GdkEventCrossing* event,
                                                                        gpointer self);
static void spice_slide_widget_finalize (GObject * obj);
static GType spice_slide_widget_get_type_once (void);
static void _vala_spice_slide_widget_set_property (GObject * object,
                                            guint property_id,
                                            const GValue * value,
                                            GParamSpec * pspec);

static inline gpointer
spice_slide_widget_get_instance_private (SpiceSlideWidget* self)
{
	return G_STRUCT_MEMBER_P (self, SpiceSlideWidget_private_offset);
}

SpiceSlideWidget*
spice_slide_widget_construct_from_slide (GType object_type,
                                         SpiceSlide* slide)
{
	SpiceSlideWidget * self = NULL;
	GtkOverlay* _tmp0_;
	GtkImage* _tmp1_;
	GtkImage* _tmp2_;
	GtkStyleContext* _tmp3_;
#line 37 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	g_return_val_if_fail (slide != NULL, NULL);
#line 37 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	self = (SpiceSlideWidget*) g_object_new (object_type, NULL);
#line 38 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp0_ = self->priv->overlay;
#line 38 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp1_ = slide->preview;
#line 38 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	gtk_container_add ((GtkContainer*) _tmp0_, (GtkWidget*) _tmp1_);
#line 39 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp2_ = slide->preview;
#line 39 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp3_ = gtk_widget_get_style_context ((GtkWidget*) _tmp2_);
#line 39 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	gtk_style_context_add_class (_tmp3_, "card");
#line 37 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	return self;
#line 200 "SlideWidget.c"
}

SpiceSlideWidget*
spice_slide_widget_new_from_slide (SpiceSlide* slide)
{
#line 37 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	return spice_slide_widget_construct_from_slide (SPICE_TYPE_SLIDE_WIDGET, slide);
#line 208 "SlideWidget.c"
}

SpiceSlideWidget*
spice_slide_widget_construct (GType object_type)
{
	SpiceSlideWidget * self = NULL;
	GtkImage* _tmp0_;
	GtkImage* _tmp1_;
	GtkStyleContext* _tmp2_;
	GtkOverlay* _tmp3_;
	GtkImage* _tmp4_;
#line 42 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	self = (SpiceSlideWidget*) g_object_new (object_type, NULL);
#line 43 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp0_ = (GtkImage*) gtk_image_new ();
#line 43 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	g_object_ref_sink (_tmp0_);
#line 43 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_g_object_unref0 (self->priv->image);
#line 43 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	self->priv->image = _tmp0_;
#line 44 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp1_ = self->priv->image;
#line 44 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp2_ = gtk_widget_get_style_context ((GtkWidget*) _tmp1_);
#line 44 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	gtk_style_context_add_class (_tmp2_, "card");
#line 45 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp3_ = self->priv->overlay;
#line 45 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp4_ = self->priv->image;
#line 45 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	gtk_container_add ((GtkContainer*) _tmp3_, (GtkWidget*) _tmp4_);
#line 42 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	return self;
#line 244 "SlideWidget.c"
}

SpiceSlideWidget*
spice_slide_widget_new (void)
{
#line 42 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	return spice_slide_widget_construct (SPICE_TYPE_SLIDE_WIDGET);
#line 252 "SlideWidget.c"
}

void
spice_slide_widget_set_pixbuf (SpiceSlideWidget* self,
                               GdkPixbuf* value)
{
	GtkImage* _tmp0_;
#line 26 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	g_return_if_fail (self != NULL);
#line 27 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp0_ = self->priv->image;
#line 27 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	gtk_image_set_from_pixbuf (_tmp0_, value);
#line 26 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	g_object_notify_by_pspec ((GObject *) self, spice_slide_widget_properties[SPICE_SLIDE_WIDGET_PIXBUF_PROPERTY]);
#line 268 "SlideWidget.c"
}

static void
_spice_slide_widget___lambda4_ (SpiceSlideWidget* self)
{
#line 70 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	g_signal_emit (self, spice_slide_widget_signals[SPICE_SLIDE_WIDGET_SETTINGS_REQUESTED_SIGNAL], 0);
#line 276 "SlideWidget.c"
}

static void
__spice_slide_widget___lambda4__gtk_button_clicked (GtkButton* _sender,
                                                    gpointer self)
{
#line 70 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_spice_slide_widget___lambda4_ ((SpiceSlideWidget*) self);
#line 285 "SlideWidget.c"
}

static gboolean
_spice_slide_widget___lambda5_ (SpiceSlideWidget* self,
                                GdkEventCrossing* event)
{
	GtkRevealer* _tmp0_;
	gboolean result;
#line 72 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 73 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp0_ = self->settings_revealer;
#line 73 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	gtk_revealer_set_reveal_child (_tmp0_, self->show_button);
#line 74 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	result = FALSE;
#line 74 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	return result;
#line 304 "SlideWidget.c"
}

static gboolean
__spice_slide_widget___lambda5__gtk_widget_enter_notify_event (GtkWidget* _sender,
                                                               GdkEventCrossing* event,
                                                               gpointer self)
{
	gboolean result;
	result = _spice_slide_widget___lambda5_ ((SpiceSlideWidget*) self, event);
#line 72 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	return result;
#line 316 "SlideWidget.c"
}

static gboolean
_spice_slide_widget___lambda6_ (SpiceSlideWidget* self,
                                GdkEventCrossing* event)
{
	GtkRevealer* _tmp0_;
	gboolean result;
#line 77 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 78 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp0_ = self->settings_revealer;
#line 78 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	gtk_revealer_set_reveal_child (_tmp0_, self->show_button);
#line 79 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	result = FALSE;
#line 79 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	return result;
#line 335 "SlideWidget.c"
}

static gboolean
__spice_slide_widget___lambda6__gtk_widget_enter_notify_event (GtkWidget* _sender,
                                                               GdkEventCrossing* event,
                                                               gpointer self)
{
	gboolean result;
	result = _spice_slide_widget___lambda6_ ((SpiceSlideWidget*) self, event);
#line 77 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	return result;
#line 347 "SlideWidget.c"
}

static gboolean
_spice_slide_widget___lambda7_ (SpiceSlideWidget* self,
                                GdkEventCrossing* event)
{
	GtkRevealer* _tmp0_;
	gboolean result;
#line 82 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 83 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp0_ = self->settings_revealer;
#line 83 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	gtk_revealer_set_reveal_child (_tmp0_, FALSE);
#line 84 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	result = FALSE;
#line 84 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	return result;
#line 366 "SlideWidget.c"
}

static gboolean
__spice_slide_widget___lambda7__gtk_widget_leave_notify_event (GtkWidget* _sender,
                                                               GdkEventCrossing* event,
                                                               gpointer self)
{
	gboolean result;
	result = _spice_slide_widget___lambda7_ ((SpiceSlideWidget*) self, event);
#line 82 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	return result;
#line 378 "SlideWidget.c"
}

static GObject *
spice_slide_widget_constructor (GType type,
                                guint n_construct_properties,
                                GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	SpiceSlideWidget * self;
	GdkEventMask _tmp0_;
	GdkEventMask _tmp1_;
	GtkOverlay* _tmp2_;
	GtkOverlay* _tmp3_;
	GtkButton* settings_button = NULL;
	GtkButton* _tmp4_;
	GtkButton* _tmp5_;
	GtkButton* _tmp6_;
	GdkEventMask _tmp7_;
	GdkEventMask _tmp8_;
	GtkButton* _tmp9_;
	GtkStyleContext* _tmp10_;
	GtkButton* _tmp11_;
	GtkStyleContext* _tmp12_;
	GtkButton* _tmp13_;
	GtkRevealer* _tmp14_;
	GtkRevealer* _tmp15_;
	GtkRevealer* _tmp16_;
	GtkRevealer* _tmp17_;
	GtkRevealer* _tmp18_;
	GtkRevealer* _tmp19_;
	GtkButton* _tmp20_;
	GtkOverlay* _tmp21_;
	GtkOverlay* _tmp22_;
	GtkRevealer* _tmp23_;
	GtkButton* _tmp24_;
	GtkButton* _tmp25_;
#line 48 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	parent_class = G_OBJECT_CLASS (spice_slide_widget_parent_class);
#line 48 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 48 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPICE_TYPE_SLIDE_WIDGET, SpiceSlideWidget);
#line 49 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp0_ = gtk_widget_get_events ((GtkWidget*) self);
#line 49 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp1_ = _tmp0_;
#line 49 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	gtk_widget_set_events ((GtkWidget*) self, _tmp1_ | (GDK_ENTER_NOTIFY_MASK & GDK_LEAVE_NOTIFY_MASK));
#line 51 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp2_ = (GtkOverlay*) gtk_overlay_new ();
#line 51 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	g_object_ref_sink (_tmp2_);
#line 51 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_g_object_unref0 (self->priv->overlay);
#line 51 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	self->priv->overlay = _tmp2_;
#line 52 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp3_ = self->priv->overlay;
#line 52 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	g_object_set ((GtkWidget*) _tmp3_, "margin", 9, NULL);
#line 54 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp4_ = (GtkButton*) gtk_button_new_from_icon_name ("document-properties-symbolic", (GtkIconSize) GTK_ICON_SIZE_BUTTON);
#line 54 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	g_object_ref_sink (_tmp4_);
#line 54 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	settings_button = _tmp4_;
#line 55 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp5_ = settings_button;
#line 55 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp6_ = settings_button;
#line 55 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp7_ = gtk_widget_get_events ((GtkWidget*) _tmp6_);
#line 55 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp8_ = _tmp7_;
#line 55 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	gtk_widget_set_events ((GtkWidget*) _tmp6_, _tmp8_ | (GDK_ENTER_NOTIFY_MASK & GDK_LEAVE_NOTIFY_MASK));
#line 56 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp9_ = settings_button;
#line 56 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp10_ = gtk_widget_get_style_context ((GtkWidget*) _tmp9_);
#line 56 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	gtk_style_context_add_class (_tmp10_, "flat");
#line 57 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp11_ = settings_button;
#line 57 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp12_ = gtk_widget_get_style_context ((GtkWidget*) _tmp11_);
#line 57 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	gtk_style_context_add_class (_tmp12_, "icon-shadow");
#line 58 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp13_ = settings_button;
#line 58 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	gtk_widget_set_can_focus ((GtkWidget*) _tmp13_, FALSE);
#line 60 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp14_ = (GtkRevealer*) gtk_revealer_new ();
#line 60 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	g_object_ref_sink (_tmp14_);
#line 60 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_g_object_unref0 (self->settings_revealer);
#line 60 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	self->settings_revealer = _tmp14_;
#line 61 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp15_ = self->settings_revealer;
#line 61 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	gtk_revealer_set_transition_duration (_tmp15_, (guint) 500);
#line 62 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp16_ = self->settings_revealer;
#line 62 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	gtk_revealer_set_transition_type (_tmp16_, GTK_REVEALER_TRANSITION_TYPE_CROSSFADE);
#line 63 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp17_ = self->settings_revealer;
#line 63 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp17_, GTK_ALIGN_START);
#line 64 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp18_ = self->settings_revealer;
#line 64 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp18_, GTK_ALIGN_START);
#line 65 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp19_ = self->settings_revealer;
#line 65 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp20_ = settings_button;
#line 65 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	gtk_container_add ((GtkContainer*) _tmp19_, (GtkWidget*) _tmp20_);
#line 67 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp21_ = self->priv->overlay;
#line 67 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp21_);
#line 68 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp22_ = self->priv->overlay;
#line 68 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp23_ = self->settings_revealer;
#line 68 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	gtk_overlay_add_overlay (_tmp22_, (GtkWidget*) _tmp23_);
#line 70 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp24_ = settings_button;
#line 70 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	g_signal_connect_object (_tmp24_, "clicked", (GCallback) __spice_slide_widget___lambda4__gtk_button_clicked, self, 0);
#line 72 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_tmp25_ = settings_button;
#line 72 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	g_signal_connect_object ((GtkWidget*) _tmp25_, "enter-notify-event", (GCallback) __spice_slide_widget___lambda5__gtk_widget_enter_notify_event, self, 0);
#line 77 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	g_signal_connect_object ((GtkWidget*) self, "enter-notify-event", (GCallback) __spice_slide_widget___lambda6__gtk_widget_enter_notify_event, self, 0);
#line 82 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	g_signal_connect_object ((GtkWidget*) self, "leave-notify-event", (GCallback) __spice_slide_widget___lambda7__gtk_widget_leave_notify_event, self, 0);
#line 48 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_g_object_unref0 (settings_button);
#line 48 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	return obj;
#line 528 "SlideWidget.c"
}

static void
spice_slide_widget_class_init (SpiceSlideWidgetClass * klass,
                               gpointer klass_data)
{
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	spice_slide_widget_parent_class = g_type_class_peek_parent (klass);
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	g_type_class_adjust_private_offset (klass, &SpiceSlideWidget_private_offset);
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_spice_slide_widget_set_property;
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	G_OBJECT_CLASS (klass)->constructor = spice_slide_widget_constructor;
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	G_OBJECT_CLASS (klass)->finalize = spice_slide_widget_finalize;
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SPICE_SLIDE_WIDGET_PIXBUF_PROPERTY, spice_slide_widget_properties[SPICE_SLIDE_WIDGET_PIXBUF_PROPERTY] = g_param_spec_object ("pixbuf", "pixbuf", "pixbuf", gdk_pixbuf_get_type (), G_PARAM_STATIC_STRINGS | G_PARAM_WRITABLE));
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	spice_slide_widget_signals[SPICE_SLIDE_WIDGET_SETTINGS_REQUESTED_SIGNAL] = g_signal_new ("settings-requested", SPICE_TYPE_SLIDE_WIDGET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 549 "SlideWidget.c"
}

static void
spice_slide_widget_instance_init (SpiceSlideWidget * self,
                                  gpointer klass)
{
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	self->priv = spice_slide_widget_get_instance_private (self);
#line 31 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	self->show_button = TRUE;
#line 560 "SlideWidget.c"
}

static void
spice_slide_widget_finalize (GObject * obj)
{
	SpiceSlideWidget * self;
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPICE_TYPE_SLIDE_WIDGET, SpiceSlideWidget);
#line 33 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_g_object_unref0 (self->priv->overlay);
#line 34 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_g_object_unref0 (self->priv->image);
#line 35 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	_g_object_unref0 (self->settings_revealer);
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	G_OBJECT_CLASS (spice_slide_widget_parent_class)->finalize (obj);
#line 577 "SlideWidget.c"
}

static GType
spice_slide_widget_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (SpiceSlideWidgetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spice_slide_widget_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpiceSlideWidget), 0, (GInstanceInitFunc) spice_slide_widget_instance_init, NULL };
	GType spice_slide_widget_type_id;
	spice_slide_widget_type_id = g_type_register_static (gtk_event_box_get_type (), "SpiceSlideWidget", &g_define_type_info, 0);
	SpiceSlideWidget_private_offset = g_type_add_instance_private (spice_slide_widget_type_id, sizeof (SpiceSlideWidgetPrivate));
	return spice_slide_widget_type_id;
}

GType
spice_slide_widget_get_type (void)
{
	static volatile gsize spice_slide_widget_type_id__once = 0;
	if (g_once_init_enter (&spice_slide_widget_type_id__once)) {
		GType spice_slide_widget_type_id;
		spice_slide_widget_type_id = spice_slide_widget_get_type_once ();
		g_once_init_leave (&spice_slide_widget_type_id__once, spice_slide_widget_type_id);
	}
	return spice_slide_widget_type_id__once;
}

static void
_vala_spice_slide_widget_set_property (GObject * object,
                                       guint property_id,
                                       const GValue * value,
                                       GParamSpec * pspec)
{
	SpiceSlideWidget * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SPICE_TYPE_SLIDE_WIDGET, SpiceSlideWidget);
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
	switch (property_id) {
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
		case SPICE_SLIDE_WIDGET_PIXBUF_PROPERTY:
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
		spice_slide_widget_set_pixbuf (self, g_value_get_object (value));
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
		break;
#line 618 "SlideWidget.c"
		default:
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideWidget.vala"
		break;
#line 624 "SlideWidget.c"
	}
}

