/* CanvasBar.c generated by valac 0.56.18, the Vala compiler
 * generated from CanvasBar.vala, do not modify */

/*
* Copyright (c) 2016 Felipe Escoto (https://github.com/Philip-Scott/Spice-up)
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the
* Free Software Foundation, Inc., 59 Temple Place - Suite 330,
* Boston, MA 02111-1307, USA.
*
* Authored by: Felipe Escoto <felescoto95@hotmail.com>
*/

#include <gtk/gtk.h>
#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <json-glib/json-glib.h>
#include <glib/gi18n-lib.h>

#define SPICE_WIDGETS_CANVAS_TOOLBAR_PATTERNS_DIR "resource:///com/github/philip-scott/spice-up/patterns/"
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define SPICE_WIDGETS_TYPE_TOOLBAR (spice_widgets_toolbar_get_type ())
#define SPICE_WIDGETS_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_WIDGETS_TYPE_TOOLBAR, SpiceWidgetsToolbar))
#define SPICE_WIDGETS_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_WIDGETS_TYPE_TOOLBAR, SpiceWidgetsToolbarClass))
#define SPICE_WIDGETS_IS_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_WIDGETS_TYPE_TOOLBAR))
#define SPICE_WIDGETS_IS_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_WIDGETS_TYPE_TOOLBAR))
#define SPICE_WIDGETS_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_WIDGETS_TYPE_TOOLBAR, SpiceWidgetsToolbarClass))

typedef struct _SpiceWidgetsToolbar SpiceWidgetsToolbar;
typedef struct _SpiceWidgetsToolbarClass SpiceWidgetsToolbarClass;
typedef struct _SpiceWidgetsToolbarPrivate SpiceWidgetsToolbarPrivate;

#define SPICE_TYPE_CANVAS_ITEM (spice_canvas_item_get_type ())
#define SPICE_CANVAS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_CANVAS_ITEM, SpiceCanvasItem))
#define SPICE_CANVAS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_CANVAS_ITEM, SpiceCanvasItemClass))
#define SPICE_IS_CANVAS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_CANVAS_ITEM))
#define SPICE_IS_CANVAS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_CANVAS_ITEM))
#define SPICE_CANVAS_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_CANVAS_ITEM, SpiceCanvasItemClass))

typedef struct _SpiceCanvasItem SpiceCanvasItem;
typedef struct _SpiceCanvasItemClass SpiceCanvasItemClass;

#define SPICE_WIDGETS_TYPE_CANVAS_TOOLBAR (spice_widgets_canvas_toolbar_get_type ())
#define SPICE_WIDGETS_CANVAS_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_WIDGETS_TYPE_CANVAS_TOOLBAR, SpiceWidgetsCanvasToolbar))
#define SPICE_WIDGETS_CANVAS_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_WIDGETS_TYPE_CANVAS_TOOLBAR, SpiceWidgetsCanvasToolbarClass))
#define SPICE_WIDGETS_IS_CANVAS_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_WIDGETS_TYPE_CANVAS_TOOLBAR))
#define SPICE_WIDGETS_IS_CANVAS_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_WIDGETS_TYPE_CANVAS_TOOLBAR))
#define SPICE_WIDGETS_CANVAS_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_WIDGETS_TYPE_CANVAS_TOOLBAR, SpiceWidgetsCanvasToolbarClass))

typedef struct _SpiceWidgetsCanvasToolbar SpiceWidgetsCanvasToolbar;
typedef struct _SpiceWidgetsCanvasToolbarClass SpiceWidgetsCanvasToolbarClass;
typedef struct _SpiceWidgetsCanvasToolbarPrivate SpiceWidgetsCanvasToolbarPrivate;

#define SPICE_TYPE_COLOR_BUTTON (spice_color_button_get_type ())
#define SPICE_COLOR_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_COLOR_BUTTON, SpiceColorButton))
#define SPICE_COLOR_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_COLOR_BUTTON, SpiceColorButtonClass))
#define SPICE_IS_COLOR_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_COLOR_BUTTON))
#define SPICE_IS_COLOR_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_COLOR_BUTTON))
#define SPICE_COLOR_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_COLOR_BUTTON, SpiceColorButtonClass))

typedef struct _SpiceColorButton SpiceColorButton;
typedef struct _SpiceColorButtonClass SpiceColorButtonClass;

#define SPICE_TYPE_COLOR_CHOOSER (spice_color_chooser_get_type ())
#define SPICE_COLOR_CHOOSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_COLOR_CHOOSER, SpiceColorChooser))
#define SPICE_COLOR_CHOOSER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_COLOR_CHOOSER, SpiceColorChooserClass))
#define SPICE_IS_COLOR_CHOOSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_COLOR_CHOOSER))
#define SPICE_IS_COLOR_CHOOSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_COLOR_CHOOSER))
#define SPICE_COLOR_CHOOSER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_COLOR_CHOOSER, SpiceColorChooserClass))

typedef struct _SpiceColorChooser SpiceColorChooser;
typedef struct _SpiceColorChooserClass SpiceColorChooserClass;

#define SPICE_TYPE_ENTRY_COMBO (spice_entry_combo_get_type ())
#define SPICE_ENTRY_COMBO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_ENTRY_COMBO, SpiceEntryCombo))
#define SPICE_ENTRY_COMBO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_ENTRY_COMBO, SpiceEntryComboClass))
#define SPICE_IS_ENTRY_COMBO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_ENTRY_COMBO))
#define SPICE_IS_ENTRY_COMBO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_ENTRY_COMBO))
#define SPICE_ENTRY_COMBO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_ENTRY_COMBO, SpiceEntryComboClass))

typedef struct _SpiceEntryCombo SpiceEntryCombo;
typedef struct _SpiceEntryComboClass SpiceEntryComboClass;

#define SPICE_TYPE_SLIDE_MANAGER (spice_slide_manager_get_type ())
#define SPICE_SLIDE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManager))
#define SPICE_SLIDE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManagerClass))
#define SPICE_IS_SLIDE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_SLIDE_MANAGER))
#define SPICE_IS_SLIDE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_SLIDE_MANAGER))
#define SPICE_SLIDE_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManagerClass))

typedef struct _SpiceSlideManager SpiceSlideManager;
typedef struct _SpiceSlideManagerClass SpiceSlideManagerClass;
enum  {
	SPICE_WIDGETS_CANVAS_TOOLBAR_0_PROPERTY,
	SPICE_WIDGETS_CANVAS_TOOLBAR_NUM_PROPERTIES
};
static GParamSpec* spice_widgets_canvas_toolbar_properties[SPICE_WIDGETS_CANVAS_TOOLBAR_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define SPICE_TYPE_SLIDE (spice_slide_get_type ())
#define SPICE_SLIDE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_SLIDE, SpiceSlide))
#define SPICE_SLIDE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_SLIDE, SpiceSlideClass))
#define SPICE_IS_SLIDE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_SLIDE))
#define SPICE_IS_SLIDE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_SLIDE))
#define SPICE_SLIDE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_SLIDE, SpiceSlideClass))

typedef struct _SpiceSlide SpiceSlide;
typedef struct _SpiceSlideClass SpiceSlideClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _SpiceSlidePrivate SpiceSlidePrivate;

#define SPICE_TYPE_CANVAS (spice_canvas_get_type ())
#define SPICE_CANVAS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_CANVAS, SpiceCanvas))
#define SPICE_CANVAS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_CANVAS, SpiceCanvasClass))
#define SPICE_IS_CANVAS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_CANVAS))
#define SPICE_IS_CANVAS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_CANVAS))
#define SPICE_CANVAS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_CANVAS, SpiceCanvasClass))

typedef struct _SpiceCanvas SpiceCanvas;
typedef struct _SpiceCanvasClass SpiceCanvasClass;

#define SPICE_SERVICES_HISTORY_MANAGER_TYPE_HISTORY_ACTION (spice_services_history_manager_history_action_get_type ())
#define SPICE_SERVICES_HISTORY_MANAGER_HISTORY_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_SERVICES_HISTORY_MANAGER_TYPE_HISTORY_ACTION, SpiceServicesHistoryManagerHistoryAction))
#define SPICE_SERVICES_HISTORY_MANAGER_HISTORY_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_SERVICES_HISTORY_MANAGER_TYPE_HISTORY_ACTION, SpiceServicesHistoryManagerHistoryActionClass))
#define SPICE_SERVICES_HISTORY_MANAGER_IS_HISTORY_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_SERVICES_HISTORY_MANAGER_TYPE_HISTORY_ACTION))
#define SPICE_SERVICES_HISTORY_MANAGER_IS_HISTORY_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_SERVICES_HISTORY_MANAGER_TYPE_HISTORY_ACTION))
#define SPICE_SERVICES_HISTORY_MANAGER_HISTORY_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_SERVICES_HISTORY_MANAGER_TYPE_HISTORY_ACTION, SpiceServicesHistoryManagerHistoryActionClass))

typedef struct _SpiceServicesHistoryManagerHistoryAction SpiceServicesHistoryManagerHistoryAction;
typedef struct _SpiceServicesHistoryManagerHistoryActionClass SpiceServicesHistoryManagerHistoryActionClass;

#define SPICE_TYPE_WINDOW (spice_window_get_type ())
#define SPICE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_WINDOW, SpiceWindow))
#define SPICE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_WINDOW, SpiceWindowClass))
#define SPICE_IS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_WINDOW))
#define SPICE_IS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_WINDOW))
#define SPICE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_WINDOW, SpiceWindowClass))

typedef struct _SpiceWindow SpiceWindow;
typedef struct _SpiceWindowClass SpiceWindowClass;

#define SPICE_SERVICES_TYPE_HISTORY_MANAGER (spice_services_history_manager_get_type ())
#define SPICE_SERVICES_HISTORY_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_SERVICES_TYPE_HISTORY_MANAGER, SpiceServicesHistoryManager))
#define SPICE_SERVICES_HISTORY_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_SERVICES_TYPE_HISTORY_MANAGER, SpiceServicesHistoryManagerClass))
#define SPICE_SERVICES_IS_HISTORY_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_SERVICES_TYPE_HISTORY_MANAGER))
#define SPICE_SERVICES_IS_HISTORY_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_SERVICES_TYPE_HISTORY_MANAGER))
#define SPICE_SERVICES_HISTORY_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_SERVICES_TYPE_HISTORY_MANAGER, SpiceServicesHistoryManagerClass))

typedef struct _SpiceServicesHistoryManager SpiceServicesHistoryManager;
typedef struct _SpiceServicesHistoryManagerClass SpiceServicesHistoryManagerClass;

struct _SpiceWidgetsToolbar {
	GtkBox parent_instance;
	SpiceWidgetsToolbarPrivate * priv;
	gboolean init;
	gboolean selecting;
	SpiceCanvasItem* item;
};

struct _SpiceWidgetsToolbarClass {
	GtkBoxClass parent_class;
	void (*item_selected) (SpiceWidgetsToolbar* self, SpiceCanvasItem* item, gboolean new_item);
	void (*update_properties) (SpiceWidgetsToolbar* self);
};

struct _SpiceWidgetsCanvasToolbar {
	SpiceWidgetsToolbar parent_instance;
	SpiceWidgetsCanvasToolbarPrivate * priv;
};

struct _SpiceWidgetsCanvasToolbarClass {
	SpiceWidgetsToolbarClass parent_class;
};

struct _SpiceWidgetsCanvasToolbarPrivate {
	SpiceColorChooser* canvas_gradient_background;
	SpiceEntryCombo* canvas_pattern;
	SpiceEntryCombo* transition;
	SpiceSlideManager* manager;
};

struct _SpiceSlide {
	GObject parent_instance;
	SpiceSlidePrivate * priv;
	JsonObject* save_data;
	SpiceCanvas* canvas;
	GtkImage* preview;
};

struct _SpiceSlideClass {
	GObjectClass parent_class;
};

static gint SpiceWidgetsCanvasToolbar_private_offset;
static gpointer spice_widgets_canvas_toolbar_parent_class = NULL;

VALA_EXTERN GType spice_widgets_toolbar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceWidgetsToolbar, g_object_unref)
VALA_EXTERN GType spice_canvas_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceCanvasItem, g_object_unref)
VALA_EXTERN GType spice_widgets_canvas_toolbar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceWidgetsCanvasToolbar, g_object_unref)
VALA_EXTERN GType spice_color_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceColorButton, g_object_unref)
VALA_EXTERN GType spice_color_chooser_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceColorChooser, g_object_unref)
VALA_EXTERN GType spice_entry_combo_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceEntryCombo, g_object_unref)
VALA_EXTERN GType spice_slide_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceSlideManager, g_object_unref)
VALA_EXTERN void spice_widgets_toolbar_item_selected (SpiceWidgetsToolbar* self,
                                          SpiceCanvasItem* item,
                                          gboolean new_item);
VALA_EXTERN void spice_widgets_toolbar_update_properties (SpiceWidgetsToolbar* self);
VALA_EXTERN SpiceWidgetsCanvasToolbar* spice_widgets_canvas_toolbar_new (SpiceSlideManager* slide_manager);
VALA_EXTERN SpiceWidgetsCanvasToolbar* spice_widgets_canvas_toolbar_construct (GType object_type,
                                                                   SpiceSlideManager* slide_manager);
VALA_EXTERN SpiceWidgetsToolbar* spice_widgets_toolbar_construct (GType object_type);
static void spice_widgets_canvas_toolbar_real_item_selected (SpiceWidgetsToolbar* base,
                                                      SpiceCanvasItem* item,
                                                      gboolean new_item);
VALA_EXTERN GType spice_slide_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceSlide, g_object_unref)
VALA_EXTERN SpiceSlide* spice_slide_manager_get_current_slide (SpiceSlideManager* self);
VALA_EXTERN GtkStackTransitionType spice_slide_get_transition (SpiceSlide* self);
VALA_EXTERN void spice_entry_combo_set_text (SpiceEntryCombo* self,
                                 const gchar* value);
VALA_EXTERN GType spice_canvas_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceCanvas, g_object_unref)
VALA_EXTERN const gchar* spice_canvas_get_background_color (SpiceCanvas* self);
VALA_EXTERN void spice_color_chooser_set_color (SpiceColorChooser* self,
                                    const gchar* value);
VALA_EXTERN const gchar* spice_canvas_get_background_pattern (SpiceCanvas* self);
static void spice_widgets_canvas_toolbar_real_update_properties (SpiceWidgetsToolbar* base);
VALA_EXTERN const gchar* spice_entry_combo_get_text (SpiceEntryCombo* self);
VALA_EXTERN void spice_slide_set_transition (SpiceSlide* self,
                                 GtkStackTransitionType value);
VALA_EXTERN void spice_canvas_set_background_pattern (SpiceCanvas* self,
                                          const gchar* value);
VALA_EXTERN const gchar* spice_color_chooser_get_color (SpiceColorChooser* self);
VALA_EXTERN void spice_canvas_set_background_color (SpiceCanvas* self,
                                        const gchar* value);
VALA_EXTERN void spice_canvas_style (SpiceCanvas* self);
static GObject * spice_widgets_canvas_toolbar_constructor (GType type,
                                                    guint n_construct_properties,
                                                    GObjectConstructParam * construct_properties);
VALA_EXTERN SpiceColorChooser* spice_color_chooser_new_with_gradient (gboolean use_alpha);
VALA_EXTERN SpiceColorChooser* spice_color_chooser_construct_with_gradient (GType object_type,
                                                                gboolean use_alpha);
static void _spice_widgets_canvas_toolbar___lambda59_ (SpiceWidgetsCanvasToolbar* self,
                                                const gchar* s);
VALA_EXTERN GType spice_services_history_manager_history_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceServicesHistoryManagerHistoryAction, g_object_unref)
VALA_EXTERN SpiceServicesHistoryManagerHistoryAction* spice_services_history_manager_history_action_new_canvas_changed (GType i_type,
                                                                                                            GBoxedCopyFunc i_dup_func,
                                                                                                            GDestroyNotify i_destroy_func,
                                                                                                            GType t_type,
                                                                                                            GBoxedCopyFunc t_dup_func,
                                                                                                            GDestroyNotify t_destroy_func,
                                                                                                            gconstpointer item,
                                                                                                            const gchar* property);
VALA_EXTERN SpiceServicesHistoryManagerHistoryAction* spice_services_history_manager_history_action_construct_canvas_changed (GType object_type,
                                                                                                                  GType i_type,
                                                                                                                  GBoxedCopyFunc i_dup_func,
                                                                                                                  GDestroyNotify i_destroy_func,
                                                                                                                  GType t_type,
                                                                                                                  GBoxedCopyFunc t_dup_func,
                                                                                                                  GDestroyNotify t_destroy_func,
                                                                                                                  gconstpointer item,
                                                                                                                  const gchar* property);
VALA_EXTERN GType spice_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceWindow, g_object_unref)
VALA_EXTERN SpiceWindow* spice_slide_manager_get_window (SpiceSlideManager* self);
VALA_EXTERN GType spice_services_history_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceServicesHistoryManager, g_object_unref)
VALA_EXTERN SpiceServicesHistoryManager* spice_window_get_history_manager (SpiceWindow* self);
VALA_EXTERN void spice_services_history_manager_add_undoable_action (SpiceServicesHistoryManager* self,
                                                         SpiceServicesHistoryManagerHistoryAction* action,
                                                         gboolean force_add);
static void __spice_widgets_canvas_toolbar___lambda59__spice_color_chooser_color_picked (SpiceColorChooser* _sender,
                                                                                  const gchar* color,
                                                                                  gpointer self);
VALA_EXTERN SpiceEntryCombo* spice_entry_combo_new (gboolean strict_signal,
                                        gboolean alphabetize,
                                        gboolean searchable);
VALA_EXTERN SpiceEntryCombo* spice_entry_combo_construct (GType object_type,
                                              gboolean strict_signal,
                                              gboolean alphabetize,
                                              gboolean searchable);
VALA_EXTERN void spice_entry_combo_set_editable (SpiceEntryCombo* self,
                                     gboolean value);
VALA_EXTERN GtkLabel* spice_entry_combo_add_entry (SpiceEntryCombo* self,
                                       const gchar* real,
                                       const gchar* translated);
static void _spice_widgets_canvas_toolbar___lambda60_ (SpiceWidgetsCanvasToolbar* self);
static void __spice_widgets_canvas_toolbar___lambda60__spice_entry_combo_activated (SpiceEntryCombo* _sender,
                                                                             const gchar* data,
                                                                             gpointer self);
static void _spice_widgets_canvas_toolbar___lambda61_ (SpiceWidgetsCanvasToolbar* self);
static void __spice_widgets_canvas_toolbar___lambda61__spice_entry_combo_activated (SpiceEntryCombo* _sender,
                                                                             const gchar* data,
                                                                             gpointer self);
static void spice_widgets_canvas_toolbar_finalize (GObject * obj);
static GType spice_widgets_canvas_toolbar_get_type_once (void);

static inline gpointer
spice_widgets_canvas_toolbar_get_instance_private (SpiceWidgetsCanvasToolbar* self)
{
	return G_STRUCT_MEMBER_P (self, SpiceWidgetsCanvasToolbar_private_offset);
}

SpiceWidgetsCanvasToolbar*
spice_widgets_canvas_toolbar_construct (GType object_type,
                                        SpiceSlideManager* slide_manager)
{
	SpiceWidgetsCanvasToolbar * self = NULL;
#line 30 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	g_return_val_if_fail (slide_manager != NULL, NULL);
#line 30 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	self = (SpiceWidgetsCanvasToolbar*) spice_widgets_toolbar_construct (object_type);
#line 31 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	self->priv->manager = slide_manager;
#line 30 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	return self;
#line 356 "CanvasBar.c"
}

SpiceWidgetsCanvasToolbar*
spice_widgets_canvas_toolbar_new (SpiceSlideManager* slide_manager)
{
#line 30 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	return spice_widgets_canvas_toolbar_construct (SPICE_WIDGETS_TYPE_CANVAS_TOOLBAR, slide_manager);
#line 364 "CanvasBar.c"
}

static void
spice_widgets_canvas_toolbar_real_item_selected (SpiceWidgetsToolbar* base,
                                                 SpiceCanvasItem* item,
                                                 gboolean new_item)
{
	SpiceWidgetsCanvasToolbar * self;
	SpiceEntryCombo* _tmp0_;
	SpiceSlideManager* _tmp1_;
	SpiceSlide* _tmp2_;
	SpiceSlide* _tmp3_;
	GtkStackTransitionType _tmp4_;
	GtkStackTransitionType _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	SpiceColorChooser* _tmp8_;
	SpiceSlideManager* _tmp9_;
	SpiceSlide* _tmp10_;
	SpiceSlide* _tmp11_;
	SpiceCanvas* _tmp12_;
	const gchar* _tmp13_;
	const gchar* _tmp14_;
	SpiceEntryCombo* _tmp15_;
	SpiceSlideManager* _tmp16_;
	SpiceSlide* _tmp17_;
	SpiceSlide* _tmp18_;
	SpiceCanvas* _tmp19_;
	const gchar* _tmp20_;
	const gchar* _tmp21_;
#line 106 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	self = (SpiceWidgetsCanvasToolbar*) base;
#line 107 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	if (new_item) {
#line 108 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
		spice_widgets_toolbar_update_properties ((SpiceWidgetsToolbar*) self);
#line 109 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
		return;
#line 403 "CanvasBar.c"
	}
#line 112 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp0_ = self->priv->transition;
#line 112 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp1_ = self->priv->manager;
#line 112 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp2_ = spice_slide_manager_get_current_slide (_tmp1_);
#line 112 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp3_ = _tmp2_;
#line 112 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp4_ = spice_slide_get_transition (_tmp3_);
#line 112 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp5_ = _tmp4_;
#line 112 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp6_ = g_strdup_printf ("%i", (gint) _tmp5_);
#line 112 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp7_ = _tmp6_;
#line 112 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	spice_entry_combo_set_text (_tmp0_, _tmp7_);
#line 112 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_free0 (_tmp7_);
#line 113 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp8_ = self->priv->canvas_gradient_background;
#line 113 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp9_ = self->priv->manager;
#line 113 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp10_ = spice_slide_manager_get_current_slide (_tmp9_);
#line 113 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp11_ = _tmp10_;
#line 113 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp12_ = _tmp11_->canvas;
#line 113 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp13_ = spice_canvas_get_background_color (_tmp12_);
#line 113 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp14_ = _tmp13_;
#line 113 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	spice_color_chooser_set_color (_tmp8_, _tmp14_);
#line 114 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp15_ = self->priv->canvas_pattern;
#line 114 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp16_ = self->priv->manager;
#line 114 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp17_ = spice_slide_manager_get_current_slide (_tmp16_);
#line 114 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp18_ = _tmp17_;
#line 114 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp19_ = _tmp18_->canvas;
#line 114 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp20_ = spice_canvas_get_background_pattern (_tmp19_);
#line 114 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp21_ = _tmp20_;
#line 114 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	spice_entry_combo_set_text (_tmp15_, _tmp21_);
#line 457 "CanvasBar.c"
}

static void
spice_widgets_canvas_toolbar_real_update_properties (SpiceWidgetsToolbar* base)
{
	SpiceWidgetsCanvasToolbar * self;
	SpiceSlideManager* _tmp0_;
	SpiceSlide* _tmp1_;
	SpiceSlide* _tmp2_;
	SpiceEntryCombo* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	SpiceSlideManager* _tmp6_;
	SpiceSlide* _tmp7_;
	SpiceSlide* _tmp8_;
	SpiceCanvas* _tmp9_;
	SpiceEntryCombo* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	SpiceSlideManager* _tmp13_;
	SpiceSlide* _tmp14_;
	SpiceSlide* _tmp15_;
	SpiceCanvas* _tmp16_;
	SpiceColorChooser* _tmp17_;
	const gchar* _tmp18_;
	const gchar* _tmp19_;
	SpiceSlideManager* _tmp20_;
	SpiceSlide* _tmp21_;
	SpiceSlide* _tmp22_;
	SpiceCanvas* _tmp23_;
#line 117 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	self = (SpiceWidgetsCanvasToolbar*) base;
#line 118 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp0_ = self->priv->manager;
#line 118 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp1_ = spice_slide_manager_get_current_slide (_tmp0_);
#line 118 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp2_ = _tmp1_;
#line 118 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp3_ = self->priv->transition;
#line 118 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp4_ = spice_entry_combo_get_text (_tmp3_);
#line 118 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp5_ = _tmp4_;
#line 118 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	spice_slide_set_transition (_tmp2_, (GtkStackTransitionType) atoi (_tmp5_));
#line 119 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp6_ = self->priv->manager;
#line 119 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp7_ = spice_slide_manager_get_current_slide (_tmp6_);
#line 119 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp8_ = _tmp7_;
#line 119 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp9_ = _tmp8_->canvas;
#line 119 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp10_ = self->priv->canvas_pattern;
#line 119 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp11_ = spice_entry_combo_get_text (_tmp10_);
#line 119 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp12_ = _tmp11_;
#line 119 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	spice_canvas_set_background_pattern (_tmp9_, _tmp12_);
#line 120 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp13_ = self->priv->manager;
#line 120 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp14_ = spice_slide_manager_get_current_slide (_tmp13_);
#line 120 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp15_ = _tmp14_;
#line 120 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp16_ = _tmp15_->canvas;
#line 120 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp17_ = self->priv->canvas_gradient_background;
#line 120 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp18_ = spice_color_chooser_get_color (_tmp17_);
#line 120 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp19_ = _tmp18_;
#line 120 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	spice_canvas_set_background_color (_tmp16_, _tmp19_);
#line 121 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp20_ = self->priv->manager;
#line 121 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp21_ = spice_slide_manager_get_current_slide (_tmp20_);
#line 121 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp22_ = _tmp21_;
#line 121 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp23_ = _tmp22_->canvas;
#line 121 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	spice_canvas_style (_tmp23_);
#line 546 "CanvasBar.c"
}

static void
_spice_widgets_canvas_toolbar___lambda59_ (SpiceWidgetsCanvasToolbar* self,
                                           const gchar* s)
{
	SpiceServicesHistoryManagerHistoryAction* action = NULL;
	SpiceSlideManager* _tmp0_;
	SpiceSlide* _tmp1_;
	SpiceSlide* _tmp2_;
	SpiceCanvas* _tmp3_;
	SpiceServicesHistoryManagerHistoryAction* _tmp4_;
	SpiceSlideManager* _tmp5_;
	SpiceWindow* _tmp6_;
	SpiceWindow* _tmp7_;
	SpiceServicesHistoryManager* _tmp8_;
	SpiceServicesHistoryManager* _tmp9_;
	SpiceServicesHistoryManagerHistoryAction* _tmp10_;
#line 38 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	g_return_if_fail (s != NULL);
#line 39 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	if (((SpiceWidgetsToolbar*) self)->selecting) {
#line 39 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
		return;
#line 571 "CanvasBar.c"
	}
#line 40 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp0_ = self->priv->manager;
#line 40 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp1_ = spice_slide_manager_get_current_slide (_tmp0_);
#line 40 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp2_ = _tmp1_;
#line 40 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp3_ = _tmp2_->canvas;
#line 40 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp4_ = spice_services_history_manager_history_action_new_canvas_changed (SPICE_TYPE_CANVAS, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, _tmp3_, "background-color");
#line 40 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	action = _tmp4_;
#line 41 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp5_ = self->priv->manager;
#line 41 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp6_ = spice_slide_manager_get_window (_tmp5_);
#line 41 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp7_ = _tmp6_;
#line 41 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp8_ = spice_window_get_history_manager (_tmp7_);
#line 41 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp9_ = _tmp8_;
#line 41 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp10_ = action;
#line 41 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	spice_services_history_manager_add_undoable_action (_tmp9_, _tmp10_, FALSE);
#line 42 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	spice_widgets_toolbar_update_properties ((SpiceWidgetsToolbar*) self);
#line 38 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (action);
#line 603 "CanvasBar.c"
}

static void
__spice_widgets_canvas_toolbar___lambda59__spice_color_chooser_color_picked (SpiceColorChooser* _sender,
                                                                             const gchar* color,
                                                                             gpointer self)
{
#line 38 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_spice_widgets_canvas_toolbar___lambda59_ ((SpiceWidgetsCanvasToolbar*) self, color);
#line 613 "CanvasBar.c"
}

static void
_spice_widgets_canvas_toolbar___lambda60_ (SpiceWidgetsCanvasToolbar* self)
{
	SpiceServicesHistoryManagerHistoryAction* action = NULL;
	SpiceSlideManager* _tmp0_;
	SpiceSlide* _tmp1_;
	SpiceSlide* _tmp2_;
	SpiceCanvas* _tmp3_;
	SpiceServicesHistoryManagerHistoryAction* _tmp4_;
	SpiceSlideManager* _tmp5_;
	SpiceWindow* _tmp6_;
	SpiceWindow* _tmp7_;
	SpiceServicesHistoryManager* _tmp8_;
	SpiceServicesHistoryManager* _tmp9_;
	SpiceServicesHistoryManagerHistoryAction* _tmp10_;
#line 71 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp0_ = self->priv->manager;
#line 71 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp1_ = spice_slide_manager_get_current_slide (_tmp0_);
#line 71 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp2_ = _tmp1_;
#line 71 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp3_ = _tmp2_->canvas;
#line 71 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp4_ = spice_services_history_manager_history_action_new_canvas_changed (SPICE_TYPE_CANVAS, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, _tmp3_, "background-pattern");
#line 71 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	action = _tmp4_;
#line 72 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp5_ = self->priv->manager;
#line 72 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp6_ = spice_slide_manager_get_window (_tmp5_);
#line 72 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp7_ = _tmp6_;
#line 72 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp8_ = spice_window_get_history_manager (_tmp7_);
#line 72 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp9_ = _tmp8_;
#line 72 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp10_ = action;
#line 72 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	spice_services_history_manager_add_undoable_action (_tmp9_, _tmp10_, FALSE);
#line 73 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	spice_widgets_toolbar_update_properties ((SpiceWidgetsToolbar*) self);
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (action);
#line 661 "CanvasBar.c"
}

static void
__spice_widgets_canvas_toolbar___lambda60__spice_entry_combo_activated (SpiceEntryCombo* _sender,
                                                                        const gchar* data,
                                                                        gpointer self)
{
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_spice_widgets_canvas_toolbar___lambda60_ ((SpiceWidgetsCanvasToolbar*) self);
#line 671 "CanvasBar.c"
}

static void
_spice_widgets_canvas_toolbar___lambda61_ (SpiceWidgetsCanvasToolbar* self)
{
	SpiceServicesHistoryManagerHistoryAction* action = NULL;
	SpiceSlideManager* _tmp0_;
	SpiceSlide* _tmp1_;
	SpiceSlide* _tmp2_;
	SpiceServicesHistoryManagerHistoryAction* _tmp3_;
	SpiceSlideManager* _tmp4_;
	SpiceWindow* _tmp5_;
	SpiceWindow* _tmp6_;
	SpiceServicesHistoryManager* _tmp7_;
	SpiceServicesHistoryManager* _tmp8_;
	SpiceServicesHistoryManagerHistoryAction* _tmp9_;
#line 96 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp0_ = self->priv->manager;
#line 96 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp1_ = spice_slide_manager_get_current_slide (_tmp0_);
#line 96 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp2_ = _tmp1_;
#line 96 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp3_ = spice_services_history_manager_history_action_new_canvas_changed (SPICE_TYPE_SLIDE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, gtk_stack_transition_type_get_type (), NULL, NULL, _tmp2_, "transition");
#line 96 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	action = _tmp3_;
#line 97 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp4_ = self->priv->manager;
#line 97 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp5_ = spice_slide_manager_get_window (_tmp4_);
#line 97 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp6_ = _tmp5_;
#line 97 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp7_ = spice_window_get_history_manager (_tmp6_);
#line 97 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp8_ = _tmp7_;
#line 97 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp9_ = action;
#line 97 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	spice_services_history_manager_add_undoable_action (_tmp8_, _tmp9_, FALSE);
#line 98 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	spice_widgets_toolbar_update_properties ((SpiceWidgetsToolbar*) self);
#line 95 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (action);
#line 716 "CanvasBar.c"
}

static void
__spice_widgets_canvas_toolbar___lambda61__spice_entry_combo_activated (SpiceEntryCombo* _sender,
                                                                        const gchar* data,
                                                                        gpointer self)
{
#line 95 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_spice_widgets_canvas_toolbar___lambda61_ ((SpiceWidgetsCanvasToolbar*) self);
#line 726 "CanvasBar.c"
}

static GObject *
spice_widgets_canvas_toolbar_constructor (GType type,
                                          guint n_construct_properties,
                                          GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	SpiceWidgetsCanvasToolbar * self;
	SpiceColorChooser* _tmp0_;
	SpiceColorChooser* _tmp1_;
	SpiceColorChooser* _tmp2_;
	SpiceEntryCombo* _tmp3_;
	SpiceEntryCombo* _tmp4_;
	SpiceEntryCombo* _tmp5_;
	SpiceEntryCombo* _tmp6_;
	GtkLabel* _tmp7_;
	GtkLabel* _tmp8_;
	SpiceEntryCombo* _tmp9_;
	GtkLabel* _tmp10_;
	GtkLabel* _tmp11_;
	SpiceEntryCombo* _tmp12_;
	GtkLabel* _tmp13_;
	GtkLabel* _tmp14_;
	SpiceEntryCombo* _tmp15_;
	GtkLabel* _tmp16_;
	GtkLabel* _tmp17_;
	SpiceEntryCombo* _tmp18_;
	GtkLabel* _tmp19_;
	GtkLabel* _tmp20_;
	SpiceEntryCombo* _tmp21_;
	GtkLabel* _tmp22_;
	GtkLabel* _tmp23_;
	SpiceEntryCombo* _tmp24_;
	GtkLabel* _tmp25_;
	GtkLabel* _tmp26_;
	SpiceEntryCombo* _tmp27_;
	GtkLabel* _tmp28_;
	GtkLabel* _tmp29_;
	SpiceEntryCombo* _tmp30_;
	GtkLabel* _tmp31_;
	GtkLabel* _tmp32_;
	SpiceEntryCombo* _tmp33_;
	GtkLabel* _tmp34_;
	GtkLabel* _tmp35_;
	SpiceEntryCombo* _tmp36_;
	GtkLabel* _tmp37_;
	GtkLabel* _tmp38_;
	SpiceEntryCombo* _tmp39_;
	GtkLabel* _tmp40_;
	GtkLabel* _tmp41_;
	SpiceEntryCombo* _tmp42_;
	GtkLabel* _tmp43_;
	GtkLabel* _tmp44_;
	SpiceEntryCombo* _tmp45_;
	GtkLabel* _tmp46_;
	GtkLabel* _tmp47_;
	SpiceEntryCombo* _tmp48_;
	GtkLabel* _tmp49_;
	GtkLabel* _tmp50_;
	SpiceEntryCombo* _tmp51_;
	GtkLabel* _tmp52_;
	GtkLabel* _tmp53_;
	SpiceEntryCombo* _tmp54_;
	GtkLabel* _tmp55_;
	GtkLabel* _tmp56_;
	SpiceEntryCombo* _tmp57_;
	GtkLabel* _tmp58_;
	GtkLabel* _tmp59_;
	SpiceEntryCombo* _tmp60_;
	GtkLabel* _tmp61_;
	GtkLabel* _tmp62_;
	SpiceEntryCombo* _tmp63_;
	GtkLabel* _tmp64_;
	GtkLabel* _tmp65_;
	SpiceEntryCombo* _tmp66_;
	SpiceEntryCombo* _tmp67_;
	SpiceEntryCombo* _tmp68_;
	SpiceEntryCombo* _tmp69_;
	SpiceEntryCombo* _tmp70_;
	gchar* _tmp71_;
	gchar* _tmp72_;
	GtkLabel* _tmp73_;
	GtkLabel* _tmp74_;
	SpiceEntryCombo* _tmp75_;
	gchar* _tmp76_;
	gchar* _tmp77_;
	GtkLabel* _tmp78_;
	GtkLabel* _tmp79_;
	SpiceEntryCombo* _tmp80_;
	gchar* _tmp81_;
	gchar* _tmp82_;
	GtkLabel* _tmp83_;
	GtkLabel* _tmp84_;
	SpiceEntryCombo* _tmp85_;
	gchar* _tmp86_;
	gchar* _tmp87_;
	GtkLabel* _tmp88_;
	GtkLabel* _tmp89_;
	SpiceEntryCombo* _tmp90_;
	gchar* _tmp91_;
	gchar* _tmp92_;
	GtkLabel* _tmp93_;
	GtkLabel* _tmp94_;
	SpiceEntryCombo* _tmp95_;
	gchar* _tmp96_;
	gchar* _tmp97_;
	GtkLabel* _tmp98_;
	GtkLabel* _tmp99_;
	SpiceEntryCombo* _tmp100_;
	gchar* _tmp101_;
	gchar* _tmp102_;
	GtkLabel* _tmp103_;
	GtkLabel* _tmp104_;
	SpiceEntryCombo* _tmp105_;
	gchar* _tmp106_;
	gchar* _tmp107_;
	GtkLabel* _tmp108_;
	GtkLabel* _tmp109_;
	SpiceEntryCombo* _tmp110_;
	gchar* _tmp111_;
	gchar* _tmp112_;
	GtkLabel* _tmp113_;
	GtkLabel* _tmp114_;
	SpiceEntryCombo* _tmp115_;
	gchar* _tmp116_;
	gchar* _tmp117_;
	GtkLabel* _tmp118_;
	GtkLabel* _tmp119_;
	SpiceEntryCombo* _tmp120_;
	gchar* _tmp121_;
	gchar* _tmp122_;
	GtkLabel* _tmp123_;
	GtkLabel* _tmp124_;
	SpiceEntryCombo* _tmp125_;
	gchar* _tmp126_;
	gchar* _tmp127_;
	GtkLabel* _tmp128_;
	GtkLabel* _tmp129_;
	SpiceEntryCombo* _tmp130_;
	gchar* _tmp131_;
	gchar* _tmp132_;
	GtkLabel* _tmp133_;
	GtkLabel* _tmp134_;
	SpiceEntryCombo* _tmp135_;
	gchar* _tmp136_;
	gchar* _tmp137_;
	GtkLabel* _tmp138_;
	GtkLabel* _tmp139_;
	SpiceEntryCombo* _tmp140_;
	SpiceColorChooser* _tmp141_;
	SpiceEntryCombo* _tmp142_;
	SpiceEntryCombo* _tmp143_;
#line 34 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	parent_class = G_OBJECT_CLASS (spice_widgets_canvas_toolbar_parent_class);
#line 34 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 34 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPICE_WIDGETS_TYPE_CANVAS_TOOLBAR, SpiceWidgetsCanvasToolbar);
#line 35 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp0_ = spice_color_chooser_new_with_gradient (FALSE);
#line 35 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	g_object_ref_sink (_tmp0_);
#line 35 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (self->priv->canvas_gradient_background);
#line 35 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	self->priv->canvas_gradient_background = _tmp0_;
#line 36 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp1_ = self->priv->canvas_gradient_background;
#line 36 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp1_, _ ("Background color"));
#line 38 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp2_ = self->priv->canvas_gradient_background;
#line 38 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	g_signal_connect_object (_tmp2_, "color-picked", (GCallback) __spice_widgets_canvas_toolbar___lambda59__spice_color_chooser_color_picked, self, 0);
#line 45 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp3_ = spice_entry_combo_new (TRUE, TRUE, FALSE);
#line 45 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	g_object_ref_sink (_tmp3_);
#line 45 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (self->priv->canvas_pattern);
#line 45 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	self->priv->canvas_pattern = _tmp3_;
#line 46 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp4_ = self->priv->canvas_pattern;
#line 46 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp4_, _ ("Background pattern"));
#line 47 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp5_ = self->priv->canvas_pattern;
#line 47 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	spice_entry_combo_set_editable (_tmp5_, FALSE);
#line 49 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp6_ = self->priv->canvas_pattern;
#line 49 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp7_ = spice_entry_combo_add_entry (_tmp6_, SPICE_WIDGETS_CANVAS_TOOLBAR_PATTERNS_DIR "3px-tile.png", _ ("3px tile"));
#line 49 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp8_ = _tmp7_;
#line 49 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp8_);
#line 50 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp9_ = self->priv->canvas_pattern;
#line 50 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp10_ = spice_entry_combo_add_entry (_tmp9_, SPICE_WIDGETS_CANVAS_TOOLBAR_PATTERNS_DIR "45-degree-fabric-dark.png", _ ("Fabric dark"));
#line 50 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp11_ = _tmp10_;
#line 50 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp11_);
#line 51 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp12_ = self->priv->canvas_pattern;
#line 51 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp13_ = spice_entry_combo_add_entry (_tmp12_, SPICE_WIDGETS_CANVAS_TOOLBAR_PATTERNS_DIR "45-degree-fabric-light.png", _ ("Fabric light"));
#line 51 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp14_ = _tmp13_;
#line 51 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp14_);
#line 52 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp15_ = self->priv->canvas_pattern;
#line 52 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp16_ = spice_entry_combo_add_entry (_tmp15_, SPICE_WIDGETS_CANVAS_TOOLBAR_PATTERNS_DIR "batthern.png", _ ("Batthern"));
#line 52 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp17_ = _tmp16_;
#line 52 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp17_);
#line 53 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp18_ = self->priv->canvas_pattern;
#line 53 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp19_ = spice_entry_combo_add_entry (_tmp18_, SPICE_WIDGETS_CANVAS_TOOLBAR_PATTERNS_DIR "beige-paper.png", _ ("Beige paper"));
#line 53 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp20_ = _tmp19_;
#line 53 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp20_);
#line 54 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp21_ = self->priv->canvas_pattern;
#line 54 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp22_ = spice_entry_combo_add_entry (_tmp21_, SPICE_WIDGETS_CANVAS_TOOLBAR_PATTERNS_DIR "black-linen.png", _ ("Black linen"));
#line 54 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp23_ = _tmp22_;
#line 54 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp23_);
#line 55 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp24_ = self->priv->canvas_pattern;
#line 55 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp25_ = spice_entry_combo_add_entry (_tmp24_, SPICE_WIDGETS_CANVAS_TOOLBAR_PATTERNS_DIR "bright-squares.png", _ ("Bright squares"));
#line 55 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp26_ = _tmp25_;
#line 55 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp26_);
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp27_ = self->priv->canvas_pattern;
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp28_ = spice_entry_combo_add_entry (_tmp27_, SPICE_WIDGETS_CANVAS_TOOLBAR_PATTERNS_DIR "diamond-upholstery.png", _ ("Diamond Upholstery"));
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp29_ = _tmp28_;
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp29_);
#line 57 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp30_ = self->priv->canvas_pattern;
#line 57 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp31_ = spice_entry_combo_add_entry (_tmp30_, SPICE_WIDGETS_CANVAS_TOOLBAR_PATTERNS_DIR "flowers.png", _ ("Flowers"));
#line 57 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp32_ = _tmp31_;
#line 57 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp32_);
#line 58 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp33_ = self->priv->canvas_pattern;
#line 58 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp34_ = spice_entry_combo_add_entry (_tmp33_, SPICE_WIDGETS_CANVAS_TOOLBAR_PATTERNS_DIR "hexellence.png", _ ("Hexellence"));
#line 58 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp35_ = _tmp34_;
#line 58 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp35_);
#line 59 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp36_ = self->priv->canvas_pattern;
#line 59 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp37_ = spice_entry_combo_add_entry (_tmp36_, SPICE_WIDGETS_CANVAS_TOOLBAR_PATTERNS_DIR "gplay.png", _ ("Gplay"));
#line 59 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp38_ = _tmp37_;
#line 59 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp38_);
#line 60 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp39_ = self->priv->canvas_pattern;
#line 60 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp40_ = spice_entry_combo_add_entry (_tmp39_, SPICE_WIDGETS_CANVAS_TOOLBAR_PATTERNS_DIR "inspiration-geometry.png", _ ("Geometry"));
#line 60 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp41_ = _tmp40_;
#line 60 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp41_);
#line 61 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp42_ = self->priv->canvas_pattern;
#line 61 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp43_ = spice_entry_combo_add_entry (_tmp42_, SPICE_WIDGETS_CANVAS_TOOLBAR_PATTERNS_DIR "dark-geometric.png", _ ("Dark geometric"));
#line 61 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp44_ = _tmp43_;
#line 61 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp44_);
#line 62 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp45_ = self->priv->canvas_pattern;
#line 62 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp46_ = spice_entry_combo_add_entry (_tmp45_, SPICE_WIDGETS_CANVAS_TOOLBAR_PATTERNS_DIR "light-wool.png", _ ("Light wool"));
#line 62 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp47_ = _tmp46_;
#line 62 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp47_);
#line 63 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp48_ = self->priv->canvas_pattern;
#line 63 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp49_ = spice_entry_combo_add_entry (_tmp48_, SPICE_WIDGETS_CANVAS_TOOLBAR_PATTERNS_DIR "ps-neutral.png", _ ("Neutral squares"));
#line 63 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp50_ = _tmp49_;
#line 63 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp50_);
#line 64 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp51_ = self->priv->canvas_pattern;
#line 64 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp52_ = spice_entry_combo_add_entry (_tmp51_, SPICE_WIDGETS_CANVAS_TOOLBAR_PATTERNS_DIR "silver-scales.png", _ ("Silver scales"));
#line 64 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp53_ = _tmp52_;
#line 64 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp53_);
#line 65 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp54_ = self->priv->canvas_pattern;
#line 65 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp55_ = spice_entry_combo_add_entry (_tmp54_, SPICE_WIDGETS_CANVAS_TOOLBAR_PATTERNS_DIR "subtle-freckles.png", _ ("Subtle grid"));
#line 65 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp56_ = _tmp55_;
#line 65 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp56_);
#line 66 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp57_ = self->priv->canvas_pattern;
#line 66 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp58_ = spice_entry_combo_add_entry (_tmp57_, SPICE_WIDGETS_CANVAS_TOOLBAR_PATTERNS_DIR "subtle-grey.png", _ ("Subtle squares"));
#line 66 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp59_ = _tmp58_;
#line 66 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp59_);
#line 67 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp60_ = self->priv->canvas_pattern;
#line 67 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp61_ = spice_entry_combo_add_entry (_tmp60_, SPICE_WIDGETS_CANVAS_TOOLBAR_PATTERNS_DIR "xv.png", _ ("XV"));
#line 67 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp62_ = _tmp61_;
#line 67 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp62_);
#line 68 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp63_ = self->priv->canvas_pattern;
#line 68 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp64_ = spice_entry_combo_add_entry (_tmp63_, "", _ (" None"));
#line 68 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp65_ = _tmp64_;
#line 68 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp65_);
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp66_ = self->priv->canvas_pattern;
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	g_signal_connect_object (_tmp66_, "activated", (GCallback) __spice_widgets_canvas_toolbar___lambda60__spice_entry_combo_activated, self, 0);
#line 76 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp67_ = spice_entry_combo_new (TRUE, FALSE, FALSE);
#line 76 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	g_object_ref_sink (_tmp67_);
#line 76 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (self->priv->transition);
#line 76 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	self->priv->transition = _tmp67_;
#line 77 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp68_ = self->priv->transition;
#line 77 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp68_, _ ("Transition"));
#line 78 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp69_ = self->priv->transition;
#line 78 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	spice_entry_combo_set_editable (_tmp69_, FALSE);
#line 80 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp70_ = self->priv->transition;
#line 80 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp71_ = g_strdup_printf ("%i", (gint) GTK_STACK_TRANSITION_TYPE_NONE);
#line 80 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp72_ = _tmp71_;
#line 80 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp73_ = spice_entry_combo_add_entry (_tmp70_, _tmp72_, _ ("No Transition"));
#line 80 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp74_ = _tmp73_;
#line 80 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp74_);
#line 80 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_free0 (_tmp72_);
#line 81 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp75_ = self->priv->transition;
#line 81 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp76_ = g_strdup_printf ("%i", (gint) GTK_STACK_TRANSITION_TYPE_CROSSFADE);
#line 81 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp77_ = _tmp76_;
#line 81 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp78_ = spice_entry_combo_add_entry (_tmp75_, _tmp77_, _ ("Crossfade"));
#line 81 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp79_ = _tmp78_;
#line 81 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp79_);
#line 81 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_free0 (_tmp77_);
#line 82 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp80_ = self->priv->transition;
#line 82 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp81_ = g_strdup_printf ("%i", (gint) GTK_STACK_TRANSITION_TYPE_SLIDE_RIGHT);
#line 82 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp82_ = _tmp81_;
#line 82 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp83_ = spice_entry_combo_add_entry (_tmp80_, _tmp82_, _ ("Slide right"));
#line 82 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp84_ = _tmp83_;
#line 82 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp84_);
#line 82 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_free0 (_tmp82_);
#line 83 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp85_ = self->priv->transition;
#line 83 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp86_ = g_strdup_printf ("%i", (gint) GTK_STACK_TRANSITION_TYPE_SLIDE_LEFT);
#line 83 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp87_ = _tmp86_;
#line 83 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp88_ = spice_entry_combo_add_entry (_tmp85_, _tmp87_, _ ("Slide left"));
#line 83 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp89_ = _tmp88_;
#line 83 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp89_);
#line 83 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_free0 (_tmp87_);
#line 84 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp90_ = self->priv->transition;
#line 84 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp91_ = g_strdup_printf ("%i", (gint) GTK_STACK_TRANSITION_TYPE_SLIDE_UP);
#line 84 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp92_ = _tmp91_;
#line 84 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp93_ = spice_entry_combo_add_entry (_tmp90_, _tmp92_, _ ("Slide up"));
#line 84 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp94_ = _tmp93_;
#line 84 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp94_);
#line 84 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_free0 (_tmp92_);
#line 85 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp95_ = self->priv->transition;
#line 85 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp96_ = g_strdup_printf ("%i", (gint) GTK_STACK_TRANSITION_TYPE_SLIDE_DOWN);
#line 85 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp97_ = _tmp96_;
#line 85 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp98_ = spice_entry_combo_add_entry (_tmp95_, _tmp97_, _ ("Slide down"));
#line 85 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp99_ = _tmp98_;
#line 85 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp99_);
#line 85 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_free0 (_tmp97_);
#line 86 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp100_ = self->priv->transition;
#line 86 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp101_ = g_strdup_printf ("%i", (gint) GTK_STACK_TRANSITION_TYPE_OVER_UP);
#line 86 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp102_ = _tmp101_;
#line 86 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp103_ = spice_entry_combo_add_entry (_tmp100_, _tmp102_, _ ("Cover up"));
#line 86 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp104_ = _tmp103_;
#line 86 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp104_);
#line 86 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_free0 (_tmp102_);
#line 87 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp105_ = self->priv->transition;
#line 87 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp106_ = g_strdup_printf ("%i", (gint) GTK_STACK_TRANSITION_TYPE_OVER_DOWN);
#line 87 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp107_ = _tmp106_;
#line 87 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp108_ = spice_entry_combo_add_entry (_tmp105_, _tmp107_, _ ("Cover down"));
#line 87 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp109_ = _tmp108_;
#line 87 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp109_);
#line 87 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_free0 (_tmp107_);
#line 88 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp110_ = self->priv->transition;
#line 88 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp111_ = g_strdup_printf ("%i", (gint) GTK_STACK_TRANSITION_TYPE_OVER_LEFT);
#line 88 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp112_ = _tmp111_;
#line 88 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp113_ = spice_entry_combo_add_entry (_tmp110_, _tmp112_, _ ("Cover left"));
#line 88 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp114_ = _tmp113_;
#line 88 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp114_);
#line 88 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_free0 (_tmp112_);
#line 89 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp115_ = self->priv->transition;
#line 89 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp116_ = g_strdup_printf ("%i", (gint) GTK_STACK_TRANSITION_TYPE_OVER_RIGHT);
#line 89 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp117_ = _tmp116_;
#line 89 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp118_ = spice_entry_combo_add_entry (_tmp115_, _tmp117_, _ ("Cover right"));
#line 89 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp119_ = _tmp118_;
#line 89 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp119_);
#line 89 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_free0 (_tmp117_);
#line 90 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp120_ = self->priv->transition;
#line 90 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp121_ = g_strdup_printf ("%i", (gint) GTK_STACK_TRANSITION_TYPE_UNDER_UP);
#line 90 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp122_ = _tmp121_;
#line 90 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp123_ = spice_entry_combo_add_entry (_tmp120_, _tmp122_, _ ("Uncover up"));
#line 90 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp124_ = _tmp123_;
#line 90 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp124_);
#line 90 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_free0 (_tmp122_);
#line 91 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp125_ = self->priv->transition;
#line 91 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp126_ = g_strdup_printf ("%i", (gint) GTK_STACK_TRANSITION_TYPE_UNDER_DOWN);
#line 91 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp127_ = _tmp126_;
#line 91 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp128_ = spice_entry_combo_add_entry (_tmp125_, _tmp127_, _ ("Uncover down"));
#line 91 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp129_ = _tmp128_;
#line 91 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp129_);
#line 91 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_free0 (_tmp127_);
#line 92 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp130_ = self->priv->transition;
#line 92 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp131_ = g_strdup_printf ("%i", (gint) GTK_STACK_TRANSITION_TYPE_UNDER_LEFT);
#line 92 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp132_ = _tmp131_;
#line 92 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp133_ = spice_entry_combo_add_entry (_tmp130_, _tmp132_, _ ("Uncover left"));
#line 92 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp134_ = _tmp133_;
#line 92 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp134_);
#line 92 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_free0 (_tmp132_);
#line 93 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp135_ = self->priv->transition;
#line 93 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp136_ = g_strdup_printf ("%i", (gint) GTK_STACK_TRANSITION_TYPE_UNDER_RIGHT);
#line 93 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp137_ = _tmp136_;
#line 93 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp138_ = spice_entry_combo_add_entry (_tmp135_, _tmp137_, _ ("Uncover right"));
#line 93 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp139_ = _tmp138_;
#line 93 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (_tmp139_);
#line 93 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_free0 (_tmp137_);
#line 95 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp140_ = self->priv->transition;
#line 95 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	g_signal_connect_object (_tmp140_, "activated", (GCallback) __spice_widgets_canvas_toolbar___lambda61__spice_entry_combo_activated, self, 0);
#line 101 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp141_ = self->priv->canvas_gradient_background;
#line 101 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp141_);
#line 102 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp142_ = self->priv->canvas_pattern;
#line 102 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp142_);
#line 103 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_tmp143_ = self->priv->transition;
#line 103 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp143_);
#line 34 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	return obj;
#line 1313 "CanvasBar.c"
}

static void
spice_widgets_canvas_toolbar_class_init (SpiceWidgetsCanvasToolbarClass * klass,
                                         gpointer klass_data)
{
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	spice_widgets_canvas_toolbar_parent_class = g_type_class_peek_parent (klass);
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	g_type_class_adjust_private_offset (klass, &SpiceWidgetsCanvasToolbar_private_offset);
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	((SpiceWidgetsToolbarClass *) klass)->item_selected = (void (*) (SpiceWidgetsToolbar*, SpiceCanvasItem*, gboolean)) spice_widgets_canvas_toolbar_real_item_selected;
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	((SpiceWidgetsToolbarClass *) klass)->update_properties = (void (*) (SpiceWidgetsToolbar*)) spice_widgets_canvas_toolbar_real_update_properties;
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	G_OBJECT_CLASS (klass)->constructor = spice_widgets_canvas_toolbar_constructor;
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	G_OBJECT_CLASS (klass)->finalize = spice_widgets_canvas_toolbar_finalize;
#line 1332 "CanvasBar.c"
}

static void
spice_widgets_canvas_toolbar_instance_init (SpiceWidgetsCanvasToolbar * self,
                                            gpointer klass)
{
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	self->priv = spice_widgets_canvas_toolbar_get_instance_private (self);
#line 1341 "CanvasBar.c"
}

static void
spice_widgets_canvas_toolbar_finalize (GObject * obj)
{
	SpiceWidgetsCanvasToolbar * self;
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPICE_WIDGETS_TYPE_CANVAS_TOOLBAR, SpiceWidgetsCanvasToolbar);
#line 25 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (self->priv->canvas_gradient_background);
#line 26 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (self->priv->canvas_pattern);
#line 27 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	_g_object_unref0 (self->priv->transition);
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/CanvasBar.vala"
	G_OBJECT_CLASS (spice_widgets_canvas_toolbar_parent_class)->finalize (obj);
#line 1358 "CanvasBar.c"
}

static GType
spice_widgets_canvas_toolbar_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (SpiceWidgetsCanvasToolbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spice_widgets_canvas_toolbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpiceWidgetsCanvasToolbar), 0, (GInstanceInitFunc) spice_widgets_canvas_toolbar_instance_init, NULL };
	GType spice_widgets_canvas_toolbar_type_id;
	spice_widgets_canvas_toolbar_type_id = g_type_register_static (SPICE_WIDGETS_TYPE_TOOLBAR, "SpiceWidgetsCanvasToolbar", &g_define_type_info, 0);
	SpiceWidgetsCanvasToolbar_private_offset = g_type_add_instance_private (spice_widgets_canvas_toolbar_type_id, sizeof (SpiceWidgetsCanvasToolbarPrivate));
	return spice_widgets_canvas_toolbar_type_id;
}

GType
spice_widgets_canvas_toolbar_get_type (void)
{
	static volatile gsize spice_widgets_canvas_toolbar_type_id__once = 0;
	if (g_once_init_enter (&spice_widgets_canvas_toolbar_type_id__once)) {
		GType spice_widgets_canvas_toolbar_type_id;
		spice_widgets_canvas_toolbar_type_id = spice_widgets_canvas_toolbar_get_type_once ();
		g_once_init_leave (&spice_widgets_canvas_toolbar_type_id__once, spice_widgets_canvas_toolbar_type_id);
	}
	return spice_widgets_canvas_toolbar_type_id__once;
}

