/* EntryCombo.c generated by valac 0.56.18, the Vala compiler
 * generated from EntryCombo.vala, do not modify */

/*
* Copyright (c) 2016 Felipe Escoto (https://github.com/Philip-Scott/Spice-up)
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the
* Free Software Foundation, Inc., 59 Temple Place - Suite 330,
* Boston, MA 02111-1307, USA.
*
* Authored by: Felipe Escoto <felescoto95@hotmail.com>
*/

#include <gtk/gtk.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gee.h>
#include <float.h>
#include <math.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define SPICE_TYPE_ENTRY_COMBO (spice_entry_combo_get_type ())
#define SPICE_ENTRY_COMBO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_ENTRY_COMBO, SpiceEntryCombo))
#define SPICE_ENTRY_COMBO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_ENTRY_COMBO, SpiceEntryComboClass))
#define SPICE_IS_ENTRY_COMBO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_ENTRY_COMBO))
#define SPICE_IS_ENTRY_COMBO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_ENTRY_COMBO))
#define SPICE_ENTRY_COMBO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_ENTRY_COMBO, SpiceEntryComboClass))

typedef struct _SpiceEntryCombo SpiceEntryCombo;
typedef struct _SpiceEntryComboClass SpiceEntryComboClass;
typedef struct _SpiceEntryComboPrivate SpiceEntryComboPrivate;
enum  {
	SPICE_ENTRY_COMBO_0_PROPERTY,
	SPICE_ENTRY_COMBO_TEXT_PROPERTY,
	SPICE_ENTRY_COMBO_MAX_LENGTH_PROPERTY,
	SPICE_ENTRY_COMBO_EDITABLE_PROPERTY,
	SPICE_ENTRY_COMBO_NUM_PROPERTIES
};
static GParamSpec* spice_entry_combo_properties[SPICE_ENTRY_COMBO_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block12Data Block12Data;
typedef struct _Block13Data Block13Data;
enum  {
	SPICE_ENTRY_COMBO_ACTIVATED_SIGNAL,
	SPICE_ENTRY_COMBO_NUM_SIGNALS
};
static guint spice_entry_combo_signals[SPICE_ENTRY_COMBO_NUM_SIGNALS] = {0};

struct _SpiceEntryCombo {
	GtkBox parent_instance;
	SpiceEntryComboPrivate * priv;
};

struct _SpiceEntryComboClass {
	GtkBoxClass parent_class;
};

struct _SpiceEntryComboPrivate {
	gchar* key;
	GtkStack* entry_button_stack;
	GtkScrolledWindow* scroll;
	GtkPopover* popover;
	GtkListBox* listbox;
	GtkEntry* entry;
	GtkButton* button;
	GtkLabel* substitute_label;
	GeeHashMap* row_map;
	GeeHashMap* keys;
	gboolean outsize_set;
	gboolean strict_signal;
};

struct _Block12Data {
	int _ref_count_;
	SpiceEntryCombo* self;
	gboolean strict_signal;
};

struct _Block13Data {
	int _ref_count_;
	Block12Data * _data12_;
	GtkSearchEntry* search_entry;
};

static gint SpiceEntryCombo_private_offset;
static gpointer spice_entry_combo_parent_class = NULL;

VALA_EXTERN GType spice_entry_combo_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceEntryCombo, g_object_unref)
VALA_EXTERN SpiceEntryCombo* spice_entry_combo_new (gboolean strict_signal,
                                        gboolean alphabetize,
                                        gboolean searchable);
VALA_EXTERN SpiceEntryCombo* spice_entry_combo_construct (GType object_type,
                                              gboolean strict_signal,
                                              gboolean alphabetize,
                                              gboolean searchable);
static Block12Data* block12_data_ref (Block12Data* _data12_);
static void block12_data_unref (void * _userdata_);
static void __lambda51_ (SpiceEntryCombo* self);
static void ___lambda51__gtk_button_clicked (GtkButton* _sender,
                                      gpointer self);
static void __lambda52_ (SpiceEntryCombo* self);
static void ___lambda52__gtk_button_clicked (GtkButton* _sender,
                                      gpointer self);
static void __lambda53_ (Block12Data* _data12_);
VALA_EXTERN void spice_entry_combo_set_text (SpiceEntryCombo* self,
                                 const gchar* value);
VALA_EXTERN const gchar* spice_entry_combo_get_text (SpiceEntryCombo* self);
static void ___lambda53__gtk_editable_changed (GtkEditable* _sender,
                                        gpointer self);
static void __lambda54_ (SpiceEntryCombo* self,
                  GtkListBoxRow* row);
static void ___lambda54__gtk_list_box_row_selected (GtkListBox* _sender,
                                             GtkListBoxRow* row,
                                             gpointer self);
static void __lambda55_ (SpiceEntryCombo* self,
                  GtkListBoxRow* row);
static void ___lambda55__gtk_list_box_row_activated (GtkListBox* _sender,
                                              GtkListBoxRow* row,
                                              gpointer self);
static gint ___lambda56_ (SpiceEntryCombo* self,
                   GtkListBoxRow* row1,
                   GtkListBoxRow* row2);
static gint ____lambda56__gtk_list_box_sort_func (GtkListBoxRow* row1,
                                           GtkListBoxRow* row2,
                                           gpointer self);
static Block13Data* block13_data_ref (Block13Data* _data13_);
static void block13_data_unref (void * _userdata_);
static gboolean ___lambda57_ (Block13Data* _data13_,
                       GtkListBoxRow* row);
static gboolean ____lambda57__gtk_list_box_filter_func (GtkListBoxRow* row,
                                                 gpointer self);
static void ___lambda58_ (SpiceEntryCombo* self);
static void ____lambda58__gtk_search_entry_search_changed (GtkSearchEntry* _sender,
                                                    gpointer self);
VALA_EXTERN void spice_entry_combo_clear_all (SpiceEntryCombo* self);
VALA_EXTERN GtkLabel* spice_entry_combo_add_entry (SpiceEntryCombo* self,
                                       const gchar* real,
                                       const gchar* translated);
VALA_EXTERN gint spice_entry_combo_get_max_length (SpiceEntryCombo* self);
VALA_EXTERN void spice_entry_combo_set_max_length (SpiceEntryCombo* self,
                                       gint value);
VALA_EXTERN gboolean spice_entry_combo_get_editable (SpiceEntryCombo* self);
VALA_EXTERN void spice_entry_combo_set_editable (SpiceEntryCombo* self,
                                     gboolean value);
static void spice_entry_combo_finalize (GObject * obj);
static GType spice_entry_combo_get_type_once (void);
static void _vala_spice_entry_combo_get_property (GObject * object,
                                           guint property_id,
                                           GValue * value,
                                           GParamSpec * pspec);
static void _vala_spice_entry_combo_set_property (GObject * object,
                                           guint property_id,
                                           const GValue * value,
                                           GParamSpec * pspec);

static inline gpointer
spice_entry_combo_get_instance_private (SpiceEntryCombo* self)
{
	return G_STRUCT_MEMBER_P (self, SpiceEntryCombo_private_offset);
}

static Block12Data*
block12_data_ref (Block12Data* _data12_)
{
#line 95 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_atomic_int_inc (&_data12_->_ref_count_);
#line 95 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	return _data12_;
#line 202 "EntryCombo.c"
}

static void
block12_data_unref (void * _userdata_)
{
	Block12Data* _data12_;
	_data12_ = (Block12Data*) _userdata_;
#line 95 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	if (g_atomic_int_dec_and_test (&_data12_->_ref_count_)) {
#line 212 "EntryCombo.c"
		SpiceEntryCombo* self;
#line 95 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		self = _data12_->self;
#line 95 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_g_object_unref0 (self);
#line 95 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		g_slice_free (Block12Data, _data12_);
#line 220 "EntryCombo.c"
	}
}

static void
__lambda51_ (SpiceEntryCombo* self)
{
	GtkPopover* _tmp0_;
#line 139 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp0_ = self->priv->popover;
#line 139 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp0_);
#line 232 "EntryCombo.c"
}

static void
___lambda51__gtk_button_clicked (GtkButton* _sender,
                                 gpointer self)
{
#line 138 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	__lambda51_ ((SpiceEntryCombo*) self);
#line 241 "EntryCombo.c"
}

static void
__lambda52_ (SpiceEntryCombo* self)
{
	GtkPopover* _tmp0_;
#line 143 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp0_ = self->priv->popover;
#line 143 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp0_);
#line 252 "EntryCombo.c"
}

static void
___lambda52__gtk_button_clicked (GtkButton* _sender,
                                 gpointer self)
{
#line 142 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	__lambda52_ ((SpiceEntryCombo*) self);
#line 261 "EntryCombo.c"
}

static void
__lambda53_ (Block12Data* _data12_)
{
	SpiceEntryCombo* self;
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gboolean _tmp3_ = FALSE;
#line 146 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self = _data12_->self;
#line 147 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	if (self->priv->outsize_set) {
#line 147 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		return;
#line 278 "EntryCombo.c"
	}
#line 148 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp0_ = self->priv->entry;
#line 148 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 148 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp2_ = _tmp1_;
#line 148 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	spice_entry_combo_set_text (self, _tmp2_);
#line 149 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	if (_data12_->strict_signal) {
#line 290 "EntryCombo.c"
		GeeHashMap* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
#line 149 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp4_ = self->priv->keys;
#line 149 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp5_ = spice_entry_combo_get_text (self);
#line 149 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp6_ = _tmp5_;
#line 149 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp7_ = g_utf8_strdown (_tmp6_, (gssize) -1);
#line 149 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp8_ = _tmp7_;
#line 149 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp3_ = gee_abstract_map_has_key ((GeeAbstractMap*) _tmp4_, _tmp8_);
#line 149 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_g_free0 (_tmp8_);
#line 310 "EntryCombo.c"
	} else {
#line 149 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp3_ = FALSE;
#line 314 "EntryCombo.c"
	}
#line 149 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	if (_tmp3_) {
#line 318 "EntryCombo.c"
		GtkEntry* _tmp9_;
		const gchar* _tmp10_;
		const gchar* _tmp11_;
#line 150 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp9_ = self->priv->entry;
#line 150 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp10_ = gtk_entry_get_text (_tmp9_);
#line 150 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp11_ = _tmp10_;
#line 150 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		g_signal_emit (self, spice_entry_combo_signals[SPICE_ENTRY_COMBO_ACTIVATED_SIGNAL], 0, _tmp11_);
#line 330 "EntryCombo.c"
	} else {
#line 151 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		if (!_data12_->strict_signal) {
#line 334 "EntryCombo.c"
			GtkEntry* _tmp12_;
			const gchar* _tmp13_;
			const gchar* _tmp14_;
#line 152 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
			_tmp12_ = self->priv->entry;
#line 152 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
			_tmp13_ = gtk_entry_get_text (_tmp12_);
#line 152 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
			_tmp14_ = _tmp13_;
#line 152 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
			g_signal_emit (self, spice_entry_combo_signals[SPICE_ENTRY_COMBO_ACTIVATED_SIGNAL], 0, _tmp14_);
#line 346 "EntryCombo.c"
		}
	}
}

static void
___lambda53__gtk_editable_changed (GtkEditable* _sender,
                                   gpointer self)
{
#line 146 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	__lambda53_ (self);
#line 357 "EntryCombo.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 158 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	return self ? g_object_ref (self) : NULL;
#line 365 "EntryCombo.c"
}

static void
__lambda54_ (SpiceEntryCombo* self,
             GtkListBoxRow* row)
{
	GtkLabel* label = NULL;
	GtkWidget* _tmp0_;
	GtkLabel* _tmp1_;
	GeeHashMap* _tmp2_;
	GtkLabel* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gpointer _tmp8_;
	gchar* _tmp9_;
	GtkLabel* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
#line 157 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	if (self->priv->outsize_set) {
#line 157 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		return;
#line 390 "EntryCombo.c"
	}
#line 158 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp0_ = gtk_bin_get_child ((GtkBin*) row);
#line 158 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_label_get_type (), GtkLabel));
#line 158 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	label = _tmp1_;
#line 159 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp2_ = self->priv->keys;
#line 159 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp3_ = label;
#line 159 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp4_ = gtk_label_get_label (_tmp3_);
#line 159 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp5_ = _tmp4_;
#line 159 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp6_ = g_utf8_strdown (_tmp5_, (gssize) -1);
#line 159 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp7_ = _tmp6_;
#line 159 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp8_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp2_, _tmp7_);
#line 159 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp9_ = (gchar*) _tmp8_;
#line 159 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	spice_entry_combo_set_text (self, _tmp9_);
#line 159 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_free0 (_tmp9_);
#line 159 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_free0 (_tmp7_);
#line 161 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp10_ = label;
#line 161 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp11_ = gtk_label_get_label (_tmp10_);
#line 161 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp12_ = _tmp11_;
#line 161 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_signal_emit (self, spice_entry_combo_signals[SPICE_ENTRY_COMBO_ACTIVATED_SIGNAL], 0, _tmp12_);
#line 156 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (label);
#line 430 "EntryCombo.c"
}

static void
___lambda54__gtk_list_box_row_selected (GtkListBox* _sender,
                                        GtkListBoxRow* row,
                                        gpointer self)
{
#line 156 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	__lambda54_ ((SpiceEntryCombo*) self, row);
#line 440 "EntryCombo.c"
}

static void
__lambda55_ (SpiceEntryCombo* self,
             GtkListBoxRow* row)
{
	GtkPopover* _tmp0_;
#line 164 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_return_if_fail (row != NULL);
#line 165 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp0_ = self->priv->popover;
#line 165 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_widget_hide ((GtkWidget*) _tmp0_);
#line 454 "EntryCombo.c"
}

static void
___lambda55__gtk_list_box_row_activated (GtkListBox* _sender,
                                         GtkListBoxRow* row,
                                         gpointer self)
{
#line 164 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	__lambda55_ ((SpiceEntryCombo*) self, row);
#line 464 "EntryCombo.c"
}

static gint
___lambda56_ (SpiceEntryCombo* self,
              GtkListBoxRow* row1,
              GtkListBoxRow* row2)
{
	GCompareFunc _tmp0_;
	GtkWidget* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	GtkWidget* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	gint result;
#line 169 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_return_val_if_fail (row1 != NULL, 0);
#line 169 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_return_val_if_fail (row2 != NULL, 0);
#line 170 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp0_ = ((GCompareFunc) g_strcmp0);
#line 170 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp1_ = gtk_bin_get_child ((GtkBin*) row1);
#line 170 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp2_ = gtk_label_get_label (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_label_get_type (), GtkLabel));
#line 170 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp3_ = _tmp2_;
#line 170 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp4_ = gtk_bin_get_child ((GtkBin*) row2);
#line 170 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp5_ = gtk_label_get_label (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_label_get_type (), GtkLabel));
#line 170 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp6_ = _tmp5_;
#line 170 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	result = _tmp0_ (_tmp3_, _tmp6_);
#line 170 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	return result;
#line 502 "EntryCombo.c"
}

static gint
____lambda56__gtk_list_box_sort_func (GtkListBoxRow* row1,
                                      GtkListBoxRow* row2,
                                      gpointer self)
{
	gint result;
	result = ___lambda56_ ((SpiceEntryCombo*) self, row1, row2);
#line 169 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	return result;
#line 514 "EntryCombo.c"
}

static Block13Data*
block13_data_ref (Block13Data* _data13_)
{
#line 176 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_atomic_int_inc (&_data13_->_ref_count_);
#line 176 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	return _data13_;
#line 524 "EntryCombo.c"
}

static void
block13_data_unref (void * _userdata_)
{
	Block13Data* _data13_;
	_data13_ = (Block13Data*) _userdata_;
#line 176 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	if (g_atomic_int_dec_and_test (&_data13_->_ref_count_)) {
#line 534 "EntryCombo.c"
		SpiceEntryCombo* self;
#line 176 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		self = _data13_->_data12_->self;
#line 176 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_g_object_unref0 (_data13_->search_entry);
#line 176 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		block12_data_unref (_data13_->_data12_);
#line 176 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_data13_->_data12_ = NULL;
#line 176 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		g_slice_free (Block13Data, _data13_);
#line 546 "EntryCombo.c"
	}
}

static gboolean
string_contains (const gchar* self,
                 const gchar* needle)
{
	gchar* _tmp0_;
	gboolean result;
#line 1584 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1584 "glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1585 "glib-2.0.vapi"
	_tmp0_ = strstr ((gchar*) self, (gchar*) needle);
#line 1585 "glib-2.0.vapi"
	result = _tmp0_ != NULL;
#line 1585 "glib-2.0.vapi"
	return result;
#line 566 "EntryCombo.c"
}

static gchar*
string_strip (const gchar* self)
{
	gchar* _result_ = NULL;
	gchar* _tmp0_;
	gchar* result;
#line 1413 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1414 "glib-2.0.vapi"
	_tmp0_ = g_strdup (self);
#line 1414 "glib-2.0.vapi"
	_result_ = _tmp0_;
#line 1415 "glib-2.0.vapi"
	g_strstrip (_result_);
#line 1416 "glib-2.0.vapi"
	result = _result_;
#line 1416 "glib-2.0.vapi"
	return result;
#line 587 "EntryCombo.c"
}

static gboolean
___lambda57_ (Block13Data* _data13_,
              GtkListBoxRow* row)
{
	Block12Data* _data12_;
	SpiceEntryCombo* self;
	GtkWidget* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	GtkSearchEntry* _tmp5_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	gboolean _tmp12_;
	gboolean result;
#line 180 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_data12_ = _data13_->_data12_;
#line 180 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self = _data12_->self;
#line 180 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_return_val_if_fail (row != NULL, FALSE);
#line 181 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp0_ = gtk_bin_get_child ((GtkBin*) row);
#line 181 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp1_ = gtk_label_get_label (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_label_get_type (), GtkLabel));
#line 181 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp2_ = _tmp1_;
#line 181 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp3_ = g_utf8_strdown (_tmp2_, (gssize) -1);
#line 181 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp4_ = _tmp3_;
#line 181 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp5_ = _data13_->search_entry;
#line 181 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp6_ = gtk_entry_get_text ((GtkEntry*) _tmp5_);
#line 181 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp7_ = _tmp6_;
#line 181 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp8_ = g_utf8_strdown (_tmp7_, (gssize) -1);
#line 181 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp9_ = _tmp8_;
#line 181 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp10_ = string_strip (_tmp9_);
#line 181 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp11_ = _tmp10_;
#line 181 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp12_ = string_contains (_tmp4_, _tmp11_);
#line 181 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_free0 (_tmp11_);
#line 181 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_free0 (_tmp9_);
#line 181 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_free0 (_tmp4_);
#line 181 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	result = _tmp12_;
#line 181 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	return result;
#line 652 "EntryCombo.c"
}

static gboolean
____lambda57__gtk_list_box_filter_func (GtkListBoxRow* row,
                                        gpointer self)
{
	gboolean result;
	result = ___lambda57_ (self, row);
#line 180 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	return result;
#line 663 "EntryCombo.c"
}

static void
___lambda58_ (SpiceEntryCombo* self)
{
	GtkListBox* _tmp0_;
#line 185 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp0_ = self->priv->listbox;
#line 185 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_list_box_invalidate_filter (_tmp0_);
#line 674 "EntryCombo.c"
}

static void
____lambda58__gtk_search_entry_search_changed (GtkSearchEntry* _sender,
                                               gpointer self)
{
#line 184 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	___lambda58_ ((SpiceEntryCombo*) self);
#line 683 "EntryCombo.c"
}

SpiceEntryCombo*
spice_entry_combo_construct (GType object_type,
                             gboolean strict_signal,
                             gboolean alphabetize,
                             gboolean searchable)
{
	SpiceEntryCombo * self = NULL;
	Block12Data* _data12_;
	GtkStyleContext* _tmp0_;
	GeeHashMap* _tmp1_;
	GeeHashMap* _tmp2_;
	GtkStack* _tmp3_;
	GtkEntry* _tmp4_ = NULL;
	GtkListBox* _tmp5_;
	GtkListBox* _tmp6_;
	GtkListBox* _tmp7_;
	GtkListBox* _tmp8_;
	GtkLabel* _tmp9_;
	GtkLabel* _tmp10_;
	GtkButton* entry_substitute = NULL;
	GtkButton* _tmp11_ = NULL;
	GtkButton* _tmp12_;
	GtkStyleContext* _tmp13_;
	GtkButton* _tmp14_;
	GtkLabel* _tmp15_;
	GtkButton* _tmp16_;
	GtkButton* _tmp17_;
	GtkStyleContext* _tmp18_;
	GtkButton* _tmp19_;
	GtkWidget* _tmp20_;
	GtkButton* _tmp21_;
	GtkScrolledWindow* _tmp22_;
	GtkScrolledWindow* _tmp23_;
	GtkScrolledWindow* _tmp24_;
	GtkScrolledWindow* _tmp25_;
	GtkListBox* _tmp26_;
	GtkPopover* _tmp27_;
	GtkPopover* _tmp28_;
	GtkStyleContext* _tmp29_;
	GtkButton* _tmp30_;
	GtkButton* _tmp31_;
	GtkEntry* _tmp32_;
	GtkListBox* _tmp33_;
	GtkListBox* _tmp34_;
	GtkBox* popover_content = NULL;
	GtkBox* _tmp36_;
	GtkBox* _tmp43_;
	GtkScrolledWindow* _tmp44_;
	GtkPopover* _tmp45_;
	GtkBox* _tmp46_;
	GtkStack* _tmp47_;
	GtkEntry* _tmp48_;
	GtkStack* _tmp49_;
	GtkButton* _tmp50_;
	GtkStack* _tmp51_;
	GtkButton* _tmp52_;
	GtkStack* _tmp53_;
#line 95 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_data12_ = g_slice_new0 (Block12Data);
#line 95 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_data12_->_ref_count_ = 1;
#line 95 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_data12_->strict_signal = strict_signal;
#line 95 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self = (SpiceEntryCombo*) g_object_new (object_type, NULL);
#line 95 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_data12_->self = g_object_ref (self);
#line 96 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self->priv->strict_signal = _data12_->strict_signal;
#line 97 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp0_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 97 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_style_context_add_class (_tmp0_, "padding-none");
#line 99 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp1_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, gtk_list_box_row_get_type (), (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 99 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (self->priv->row_map);
#line 99 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self->priv->row_map = _tmp1_;
#line 100 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp2_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 100 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (self->priv->keys);
#line 100 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self->priv->keys = _tmp2_;
#line 102 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp3_ = (GtkStack*) gtk_stack_new ();
#line 102 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_ref_sink (_tmp3_);
#line 102 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (self->priv->entry_button_stack);
#line 102 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self->priv->entry_button_stack = _tmp3_;
#line 104 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp4_ = (GtkEntry*) gtk_entry_new ();
#line 104 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_set ((GtkWidget*) _tmp4_, "margin", 3, NULL);
#line 104 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_ref_sink (_tmp4_);
#line 104 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (self->priv->entry);
#line 104 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self->priv->entry = _tmp4_;
#line 108 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp5_ = (GtkListBox*) gtk_list_box_new ();
#line 108 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_ref_sink (_tmp5_);
#line 108 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (self->priv->listbox);
#line 108 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self->priv->listbox = _tmp5_;
#line 109 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp6_ = self->priv->listbox;
#line 109 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp7_ = self->priv->listbox;
#line 109 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp7_, 3);
#line 109 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_widget_set_margin_top ((GtkWidget*) _tmp6_, 3);
#line 110 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp8_ = self->priv->listbox;
#line 110 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_list_box_set_activate_on_single_click (_tmp8_, FALSE);
#line 112 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp9_ = (GtkLabel*) gtk_label_new ("");
#line 112 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_ref_sink (_tmp9_);
#line 112 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (self->priv->substitute_label);
#line 112 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self->priv->substitute_label = _tmp9_;
#line 113 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp10_ = self->priv->substitute_label;
#line 113 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp10_, GTK_ALIGN_START);
#line 115 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp11_ = (GtkButton*) gtk_button_new ();
#line 115 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_widget_set_can_focus ((GtkWidget*) _tmp11_, FALSE);
#line 115 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_set ((GtkWidget*) _tmp11_, "margin", 3, NULL);
#line 115 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_ref_sink (_tmp11_);
#line 115 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	entry_substitute = _tmp11_;
#line 119 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp12_ = entry_substitute;
#line 119 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp13_ = gtk_widget_get_style_context ((GtkWidget*) _tmp12_);
#line 119 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_style_context_add_class (_tmp13_, "flat");
#line 120 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp14_ = entry_substitute;
#line 120 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp15_ = self->priv->substitute_label;
#line 120 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_container_add ((GtkContainer*) _tmp14_, (GtkWidget*) _tmp15_);
#line 122 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp16_ = (GtkButton*) gtk_button_new_from_icon_name ("pan-down-symbolic", (GtkIconSize) GTK_ICON_SIZE_MENU);
#line 122 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_ref_sink (_tmp16_);
#line 122 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (self->priv->button);
#line 122 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self->priv->button = _tmp16_;
#line 123 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp17_ = self->priv->button;
#line 123 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp18_ = gtk_widget_get_style_context ((GtkWidget*) _tmp17_);
#line 123 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_style_context_add_class (_tmp18_, "flat");
#line 124 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp19_ = self->priv->button;
#line 124 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp20_ = gtk_bin_get_child ((GtkBin*) _tmp19_);
#line 124 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_set (_tmp20_, "margin", 3, NULL);
#line 125 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp21_ = self->priv->button;
#line 125 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_widget_set_can_focus ((GtkWidget*) _tmp21_, FALSE);
#line 127 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp22_ = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
#line 127 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_ref_sink (_tmp22_);
#line 127 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (self->priv->scroll);
#line 127 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self->priv->scroll = _tmp22_;
#line 128 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp23_ = self->priv->scroll;
#line 128 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_set (_tmp23_, "hscrollbar-policy", GTK_POLICY_NEVER, NULL);
#line 129 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp24_ = self->priv->scroll;
#line 129 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_set (_tmp24_, "vscrollbar-policy", GTK_POLICY_NEVER, NULL);
#line 130 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp25_ = self->priv->scroll;
#line 130 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp26_ = self->priv->listbox;
#line 130 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_container_add ((GtkContainer*) _tmp25_, (GtkWidget*) _tmp26_);
#line 132 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp27_ = (GtkPopover*) gtk_popover_new ((GtkWidget*) self);
#line 132 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_ref_sink (_tmp27_);
#line 132 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (self->priv->popover);
#line 132 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self->priv->popover = _tmp27_;
#line 133 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp28_ = self->priv->popover;
#line 133 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_popover_set_position (_tmp28_, GTK_POS_BOTTOM);
#line 135 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_orientable_set_orientation ((GtkOrientable*) self, GTK_ORIENTATION_HORIZONTAL);
#line 136 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp29_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 136 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_style_context_add_class (_tmp29_, "frame");
#line 138 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp30_ = self->priv->button;
#line 138 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_signal_connect_object (_tmp30_, "clicked", (GCallback) ___lambda51__gtk_button_clicked, self, 0);
#line 142 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp31_ = entry_substitute;
#line 142 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_signal_connect_object (_tmp31_, "clicked", (GCallback) ___lambda52__gtk_button_clicked, self, 0);
#line 146 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp32_ = self->priv->entry;
#line 146 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_signal_connect_data ((GtkEditable*) _tmp32_, "changed", (GCallback) ___lambda53__gtk_editable_changed, block12_data_ref (_data12_), (GClosureNotify) block12_data_unref, 0);
#line 156 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp33_ = self->priv->listbox;
#line 156 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_signal_connect_object (_tmp33_, "row-selected", (GCallback) ___lambda54__gtk_list_box_row_selected, self, 0);
#line 164 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp34_ = self->priv->listbox;
#line 164 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_signal_connect_object (_tmp34_, "row-activated", (GCallback) ___lambda55__gtk_list_box_row_activated, self, 0);
#line 168 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	if (alphabetize == TRUE) {
#line 929 "EntryCombo.c"
		GtkListBox* _tmp35_;
#line 169 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp35_ = self->priv->listbox;
#line 169 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		gtk_list_box_set_sort_func (_tmp35_, ____lambda56__gtk_list_box_sort_func, g_object_ref (self), g_object_unref);
#line 935 "EntryCombo.c"
	}
#line 174 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp36_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
#line 174 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_ref_sink (_tmp36_);
#line 174 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	popover_content = _tmp36_;
#line 176 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	if (searchable) {
#line 945 "EntryCombo.c"
		Block13Data* _data13_;
		GtkSearchEntry* _tmp37_;
		GtkSearchEntry* _tmp38_;
		GtkListBox* _tmp39_;
		GtkSearchEntry* _tmp40_;
		GtkBox* _tmp41_;
		GtkSearchEntry* _tmp42_;
#line 176 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_data13_ = g_slice_new0 (Block13Data);
#line 176 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_data13_->_ref_count_ = 1;
#line 176 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_data13_->_data12_ = block12_data_ref (_data12_);
#line 177 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp37_ = (GtkSearchEntry*) gtk_search_entry_new ();
#line 177 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		g_object_ref_sink (_tmp37_);
#line 177 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_data13_->search_entry = _tmp37_;
#line 178 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp38_ = _data13_->search_entry;
#line 178 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		g_object_set ((GtkWidget*) _tmp38_, "margin", 6, NULL);
#line 180 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp39_ = self->priv->listbox;
#line 180 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		gtk_list_box_set_filter_func (_tmp39_, ____lambda57__gtk_list_box_filter_func, block13_data_ref (_data13_), block13_data_unref);
#line 184 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp40_ = _data13_->search_entry;
#line 184 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		g_signal_connect_object (_tmp40_, "search-changed", (GCallback) ____lambda58__gtk_search_entry_search_changed, self, 0);
#line 187 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp41_ = popover_content;
#line 187 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp42_ = _data13_->search_entry;
#line 187 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		gtk_container_add ((GtkContainer*) _tmp41_, (GtkWidget*) _tmp42_);
#line 176 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		block13_data_unref (_data13_);
#line 176 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_data13_ = NULL;
#line 987 "EntryCombo.c"
	}
#line 190 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp43_ = popover_content;
#line 190 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp44_ = self->priv->scroll;
#line 190 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_container_add ((GtkContainer*) _tmp43_, (GtkWidget*) _tmp44_);
#line 191 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp45_ = self->priv->popover;
#line 191 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp46_ = popover_content;
#line 191 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_container_add ((GtkContainer*) _tmp45_, (GtkWidget*) _tmp46_);
#line 193 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp47_ = self->priv->entry_button_stack;
#line 193 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp48_ = self->priv->entry;
#line 193 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_stack_add_named (_tmp47_, (GtkWidget*) _tmp48_, "entry");
#line 194 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp49_ = self->priv->entry_button_stack;
#line 194 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp50_ = entry_substitute;
#line 194 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_stack_add_named (_tmp49_, (GtkWidget*) _tmp50_, "button");
#line 196 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp51_ = self->priv->entry_button_stack;
#line 196 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	GTK_CONTAINER_CLASS (spice_entry_combo_parent_class)->add ((GtkContainer*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_box_get_type (), GtkBox), (GtkWidget*) _tmp51_);
#line 197 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp52_ = self->priv->button;
#line 197 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	GTK_CONTAINER_CLASS (spice_entry_combo_parent_class)->add ((GtkContainer*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_box_get_type (), GtkBox), (GtkWidget*) _tmp52_);
#line 198 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 200 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp53_ = self->priv->entry_button_stack;
#line 200 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_stack_set_visible_child_name (_tmp53_, "entry");
#line 95 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (popover_content);
#line 95 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (entry_substitute);
#line 95 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	block12_data_unref (_data12_);
#line 95 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_data12_ = NULL;
#line 95 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	return self;
#line 1037 "EntryCombo.c"
}

SpiceEntryCombo*
spice_entry_combo_new (gboolean strict_signal,
                       gboolean alphabetize,
                       gboolean searchable)
{
#line 95 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	return spice_entry_combo_construct (SPICE_TYPE_ENTRY_COMBO, strict_signal, alphabetize, searchable);
#line 1047 "EntryCombo.c"
}

void
spice_entry_combo_clear_all (SpiceEntryCombo* self)
{
	GeeHashMap* _tmp0_;
	GtkListBox* _tmp1_;
	GList* _tmp2_;
#line 203 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_return_if_fail (self != NULL);
#line 204 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self->priv->outsize_set = TRUE;
#line 205 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, gtk_list_box_row_get_type (), (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 205 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (self->priv->row_map);
#line 205 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self->priv->row_map = _tmp0_;
#line 206 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp1_ = self->priv->listbox;
#line 206 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp2_ = gtk_container_get_children ((GtkContainer*) _tmp1_);
#line 1070 "EntryCombo.c"
	{
		GList* child_collection = NULL;
		GList* child_it = NULL;
#line 206 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		child_collection = _tmp2_;
#line 206 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		for (child_it = child_collection; child_it != NULL; child_it = child_it->next) {
#line 1078 "EntryCombo.c"
			GtkWidget* child = NULL;
#line 206 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
			child = (GtkWidget*) child_it->data;
#line 1082 "EntryCombo.c"
			{
				GtkWidget* _tmp3_;
#line 207 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
				_tmp3_ = child;
#line 207 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, gtk_list_box_row_get_type ())) {
#line 1089 "EntryCombo.c"
					GtkWidget* _tmp4_;
#line 208 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
					_tmp4_ = child;
#line 208 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
					gtk_widget_destroy (_tmp4_);
#line 1095 "EntryCombo.c"
				}
			}
		}
#line 206 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		(child_collection == NULL) ? NULL : (child_collection = (g_list_free (child_collection), NULL));
#line 1101 "EntryCombo.c"
	}
#line 211 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self->priv->outsize_set = FALSE;
#line 1105 "EntryCombo.c"
}

GtkLabel*
spice_entry_combo_add_entry (SpiceEntryCombo* self,
                             const gchar* real,
                             const gchar* translated)
{
	GeeHashMap* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	GtkLabel* label = NULL;
	GtkLabel* _tmp5_;
	GtkLabel* _tmp6_;
	gboolean _tmp7_ = FALSE;
	GtkListBoxRow* row = NULL;
	GtkListBoxRow* _tmp8_;
	GtkListBoxRow* _tmp9_;
	GtkStyleContext* _tmp10_;
	GeeHashMap* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	GtkListBoxRow* _tmp14_;
	GtkListBoxRow* _tmp15_;
	GtkLabel* _tmp16_;
	GtkListBox* _tmp17_;
	GtkListBoxRow* _tmp18_;
	GtkListBox* _tmp19_;
	GtkListBox* _tmp20_;
	GList* _tmp21_;
	GList* _tmp22_;
	gboolean _tmp23_;
	GtkLabel* result;
#line 221 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 221 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_return_val_if_fail (real != NULL, NULL);
#line 222 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	if (translated == NULL) {
#line 222 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		translated = real;
#line 1148 "EntryCombo.c"
	}
#line 224 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp0_ = self->priv->keys;
#line 224 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp1_ = g_utf8_strdown (translated, (gssize) -1);
#line 224 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp2_ = _tmp1_;
#line 224 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp3_ = g_utf8_strdown (real, (gssize) -1);
#line 224 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp4_ = _tmp3_;
#line 224 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp0_, _tmp2_, _tmp4_);
#line 224 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_free0 (_tmp4_);
#line 224 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_free0 (_tmp2_);
#line 226 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp5_ = (GtkLabel*) gtk_label_new (translated);
#line 226 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_ref_sink (_tmp5_);
#line 226 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	label = _tmp5_;
#line 227 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp6_ = label;
#line 227 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_label_set_xalign (_tmp6_, (gfloat) 0);
#line 229 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	if (string_contains (translated, "Noto Sans")) {
#line 229 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp7_ = g_strcmp0 (translated, "Noto Sans") != 0;
#line 1180 "EntryCombo.c"
	} else {
#line 229 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp7_ = FALSE;
#line 1184 "EntryCombo.c"
	}
#line 229 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	if (_tmp7_) {
#line 229 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		result = label;
#line 229 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		return result;
#line 1192 "EntryCombo.c"
	}
#line 231 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp8_ = (GtkListBoxRow*) gtk_list_box_row_new ();
#line 231 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_ref_sink (_tmp8_);
#line 231 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	row = _tmp8_;
#line 232 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp9_ = row;
#line 232 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp10_ = gtk_widget_get_style_context ((GtkWidget*) _tmp9_);
#line 232 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_style_context_add_class (_tmp10_, GTK_STYLE_CLASS_MENUITEM);
#line 233 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp11_ = self->priv->row_map;
#line 233 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp12_ = g_utf8_strdown (real, (gssize) -1);
#line 233 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp13_ = _tmp12_;
#line 233 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp14_ = row;
#line 233 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp11_, _tmp13_, _tmp14_);
#line 233 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_free0 (_tmp13_);
#line 235 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp15_ = row;
#line 235 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp16_ = label;
#line 235 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_container_add ((GtkContainer*) _tmp15_, (GtkWidget*) _tmp16_);
#line 236 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp17_ = self->priv->listbox;
#line 236 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp18_ = row;
#line 236 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_container_add ((GtkContainer*) _tmp17_, (GtkWidget*) _tmp18_);
#line 237 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp19_ = self->priv->listbox;
#line 237 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp19_);
#line 239 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp20_ = self->priv->listbox;
#line 239 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp21_ = gtk_container_get_children ((GtkContainer*) _tmp20_);
#line 239 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp22_ = _tmp21_;
#line 239 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp23_ = g_list_length (_tmp22_) > ((guint) 15);
#line 239 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	(_tmp22_ == NULL) ? NULL : (_tmp22_ = (g_list_free (_tmp22_), NULL));
#line 239 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	if (_tmp23_) {
#line 1246 "EntryCombo.c"
		GtkScrolledWindow* _tmp24_;
		GtkScrolledWindow* _tmp25_;
#line 240 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp24_ = self->priv->scroll;
#line 240 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		g_object_set (_tmp24_, "vscrollbar-policy", GTK_POLICY_AUTOMATIC, NULL);
#line 241 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp25_ = self->priv->scroll;
#line 241 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		g_object_set ((GtkWidget*) _tmp25_, "height-request", 220, NULL);
#line 1257 "EntryCombo.c"
	}
#line 244 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	result = label;
#line 244 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (row);
#line 244 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	return result;
#line 1265 "EntryCombo.c"
}

const gchar*
spice_entry_combo_get_text (SpiceEntryCombo* self)
{
	const gchar* result;
	GeeHashMap* _tmp0_;
	GtkEntry* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gboolean _tmp6_;
#line 28 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 29 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp0_ = self->priv->keys;
#line 29 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp1_ = self->priv->entry;
#line 29 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp2_ = gtk_entry_get_text (_tmp1_);
#line 29 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp3_ = _tmp2_;
#line 29 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp4_ = g_utf8_strdown (_tmp3_, (gssize) -1);
#line 29 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp5_ = _tmp4_;
#line 29 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp6_ = gee_abstract_map_has_key ((GeeAbstractMap*) _tmp0_, _tmp5_);
#line 29 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_free0 (_tmp5_);
#line 29 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	if (_tmp6_) {
#line 1299 "EntryCombo.c"
		GeeHashMap* _tmp7_;
		GtkEntry* _tmp8_;
		const gchar* _tmp9_;
		const gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gpointer _tmp13_;
		const gchar* _tmp14_;
#line 30 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp7_ = self->priv->keys;
#line 30 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp8_ = self->priv->entry;
#line 30 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp9_ = gtk_entry_get_text (_tmp8_);
#line 30 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp10_ = _tmp9_;
#line 30 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp11_ = g_utf8_strdown (_tmp10_, (gssize) -1);
#line 30 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp12_ = _tmp11_;
#line 30 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp13_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp7_, _tmp12_);
#line 30 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_g_free0 (self->priv->key);
#line 30 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		self->priv->key = (gchar*) _tmp13_;
#line 30 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_g_free0 (_tmp12_);
#line 31 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp14_ = self->priv->key;
#line 31 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		result = _tmp14_;
#line 31 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		return result;
#line 1334 "EntryCombo.c"
	} else {
		GtkEntry* _tmp15_;
		const gchar* _tmp16_;
		const gchar* _tmp17_;
#line 33 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp15_ = self->priv->entry;
#line 33 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp16_ = gtk_entry_get_text (_tmp15_);
#line 33 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp17_ = _tmp16_;
#line 33 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		result = _tmp17_;
#line 33 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		return result;
#line 1349 "EntryCombo.c"
	}
}

void
spice_entry_combo_set_text (SpiceEntryCombo* self,
                            const gchar* value)
{
	gchar* new_val = NULL;
	gchar* _tmp0_;
	GeeHashMap* _tmp1_;
	const gchar* _tmp2_;
#line 36 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_return_if_fail (self != NULL);
#line 37 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self->priv->outsize_set = TRUE;
#line 38 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp0_ = g_utf8_strdown (value, (gssize) -1);
#line 38 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	new_val = _tmp0_;
#line 39 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp1_ = self->priv->row_map;
#line 39 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp2_ = new_val;
#line 39 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	if (gee_abstract_map_has_key ((GeeAbstractMap*) _tmp1_, _tmp2_)) {
#line 1375 "EntryCombo.c"
		GtkListBox* _tmp3_;
		GeeHashMap* _tmp4_;
		const gchar* _tmp5_;
		gpointer _tmp6_;
		GtkListBoxRow* _tmp7_;
		GtkEntry* _tmp8_;
		GeeHashMap* _tmp9_;
		const gchar* _tmp10_;
		gpointer _tmp11_;
		GtkListBoxRow* _tmp12_;
		GtkWidget* _tmp13_;
		const gchar* _tmp14_;
		const gchar* _tmp15_;
		GtkLabel* _tmp16_;
		GtkEntry* _tmp17_;
		const gchar* _tmp18_;
		const gchar* _tmp19_;
#line 40 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp3_ = self->priv->listbox;
#line 40 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp4_ = self->priv->row_map;
#line 40 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp5_ = new_val;
#line 40 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp6_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp4_, _tmp5_);
#line 40 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp7_ = (GtkListBoxRow*) _tmp6_;
#line 40 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		gtk_list_box_select_row (_tmp3_, _tmp7_);
#line 40 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_g_object_unref0 (_tmp7_);
#line 41 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp8_ = self->priv->entry;
#line 41 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp9_ = self->priv->row_map;
#line 41 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp10_ = new_val;
#line 41 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp11_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp9_, _tmp10_);
#line 41 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp12_ = (GtkListBoxRow*) _tmp11_;
#line 41 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp13_ = gtk_bin_get_child ((GtkBin*) _tmp12_);
#line 41 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp14_ = gtk_label_get_label (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, gtk_label_get_type (), GtkLabel));
#line 41 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp15_ = _tmp14_;
#line 41 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		gtk_entry_set_text (_tmp8_, _tmp15_);
#line 41 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_g_object_unref0 (_tmp12_);
#line 42 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp16_ = self->priv->substitute_label;
#line 42 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp17_ = self->priv->entry;
#line 42 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp18_ = gtk_entry_get_text (_tmp17_);
#line 42 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp19_ = _tmp18_;
#line 42 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		gtk_label_set_label (_tmp16_, _tmp19_);
#line 1437 "EntryCombo.c"
	} else {
#line 43 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		if (!self->priv->strict_signal) {
#line 1441 "EntryCombo.c"
			GtkListBox* _tmp20_;
			GtkEntry* _tmp21_;
#line 44 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
			_tmp20_ = self->priv->listbox;
#line 44 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
			gtk_list_box_select_row (_tmp20_, NULL);
#line 45 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
			_tmp21_ = self->priv->entry;
#line 45 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
			gtk_entry_set_text (_tmp21_, value);
#line 1452 "EntryCombo.c"
		}
	}
#line 48 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self->priv->outsize_set = FALSE;
#line 36 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_free0 (new_val);
#line 36 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_notify_by_pspec ((GObject *) self, spice_entry_combo_properties[SPICE_ENTRY_COMBO_TEXT_PROPERTY]);
#line 1461 "EntryCombo.c"
}

gint
spice_entry_combo_get_max_length (SpiceEntryCombo* self)
{
	gint result;
	GtkEntry* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
#line 53 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 54 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp0_ = self->priv->entry;
#line 54 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp1_ = gtk_entry_get_max_length (_tmp0_);
#line 54 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp2_ = _tmp1_;
#line 54 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	result = _tmp2_;
#line 54 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	return result;
#line 1483 "EntryCombo.c"
}

void
spice_entry_combo_set_max_length (SpiceEntryCombo* self,
                                  gint value)
{
	GtkEntry* _tmp0_;
	GtkEntry* _tmp1_;
#line 56 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_return_if_fail (self != NULL);
#line 57 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp0_ = self->priv->entry;
#line 57 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_entry_set_max_width_chars (_tmp0_, value + 1);
#line 58 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp1_ = self->priv->entry;
#line 58 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_entry_set_width_chars (_tmp1_, value);
#line 56 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_notify_by_pspec ((GObject *) self, spice_entry_combo_properties[SPICE_ENTRY_COMBO_MAX_LENGTH_PROPERTY]);
#line 1504 "EntryCombo.c"
}

gboolean
spice_entry_combo_get_editable (SpiceEntryCombo* self)
{
	gboolean result;
	GtkEntry* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 63 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 64 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp0_ = self->priv->entry;
#line 64 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_get (_tmp0_, "editable", &_tmp1_, NULL);
#line 64 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp2_ = _tmp1_;
#line 64 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	result = _tmp2_;
#line 64 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	return result;
#line 1526 "EntryCombo.c"
}

void
spice_entry_combo_set_editable (SpiceEntryCombo* self,
                                gboolean value)
{
	GtkEntry* _tmp0_;
#line 66 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_return_if_fail (self != NULL);
#line 67 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_tmp0_ = self->priv->entry;
#line 67 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, value);
#line 69 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	if (value) {
#line 1542 "EntryCombo.c"
		GtkStack* _tmp1_;
#line 70 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp1_ = self->priv->entry_button_stack;
#line 70 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		gtk_stack_set_visible_child_name (_tmp1_, "entry");
#line 1548 "EntryCombo.c"
	} else {
		GtkStack* _tmp2_;
#line 72 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		_tmp2_ = self->priv->entry_button_stack;
#line 72 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		gtk_stack_set_visible_child_name (_tmp2_, "button");
#line 1555 "EntryCombo.c"
	}
#line 66 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_notify_by_pspec ((GObject *) self, spice_entry_combo_properties[SPICE_ENTRY_COMBO_EDITABLE_PROPERTY]);
#line 1559 "EntryCombo.c"
}

static void
spice_entry_combo_base_init (SpiceEntryComboClass * klass)
{
#line 91 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	gtk_widget_class_set_css_name (GTK_WIDGET_CLASS (klass), "button");
#line 1567 "EntryCombo.c"
}

static void
spice_entry_combo_class_init (SpiceEntryComboClass * klass,
                              gpointer klass_data)
{
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	spice_entry_combo_parent_class = g_type_class_peek_parent (klass);
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_type_class_adjust_private_offset (klass, &SpiceEntryCombo_private_offset);
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_spice_entry_combo_get_property;
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_spice_entry_combo_set_property;
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	G_OBJECT_CLASS (klass)->finalize = spice_entry_combo_finalize;
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SPICE_ENTRY_COMBO_TEXT_PROPERTY, spice_entry_combo_properties[SPICE_ENTRY_COMBO_TEXT_PROPERTY] = g_param_spec_string ("text", "text", "text", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SPICE_ENTRY_COMBO_MAX_LENGTH_PROPERTY, spice_entry_combo_properties[SPICE_ENTRY_COMBO_MAX_LENGTH_PROPERTY] = g_param_spec_int ("max-length", "max-length", "max-length", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SPICE_ENTRY_COMBO_EDITABLE_PROPERTY, spice_entry_combo_properties[SPICE_ENTRY_COMBO_EDITABLE_PROPERTY] = g_param_spec_boolean ("editable", "editable", "editable", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	spice_entry_combo_signals[SPICE_ENTRY_COMBO_ACTIVATED_SIGNAL] = g_signal_new ("activated", SPICE_TYPE_ENTRY_COMBO, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
#line 1592 "EntryCombo.c"
}

static void
spice_entry_combo_instance_init (SpiceEntryCombo * self,
                                 gpointer klass)
{
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self->priv = spice_entry_combo_get_instance_private (self);
#line 87 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self->priv->outsize_set = FALSE;
#line 88 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self->priv->strict_signal = FALSE;
#line 1605 "EntryCombo.c"
}

static void
spice_entry_combo_finalize (GObject * obj)
{
	SpiceEntryCombo * self;
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPICE_TYPE_ENTRY_COMBO, SpiceEntryCombo);
#line 25 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_free0 (self->priv->key);
#line 77 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (self->priv->entry_button_stack);
#line 78 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (self->priv->scroll);
#line 79 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (self->priv->popover);
#line 80 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (self->priv->listbox);
#line 81 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (self->priv->entry);
#line 82 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (self->priv->button);
#line 83 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (self->priv->substitute_label);
#line 85 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (self->priv->row_map);
#line 86 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	_g_object_unref0 (self->priv->keys);
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	G_OBJECT_CLASS (spice_entry_combo_parent_class)->finalize (obj);
#line 1636 "EntryCombo.c"
}

static GType
spice_entry_combo_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (SpiceEntryComboClass), (GBaseInitFunc) spice_entry_combo_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spice_entry_combo_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpiceEntryCombo), 0, (GInstanceInitFunc) spice_entry_combo_instance_init, NULL };
	GType spice_entry_combo_type_id;
	spice_entry_combo_type_id = g_type_register_static (gtk_box_get_type (), "SpiceEntryCombo", &g_define_type_info, 0);
	SpiceEntryCombo_private_offset = g_type_add_instance_private (spice_entry_combo_type_id, sizeof (SpiceEntryComboPrivate));
	return spice_entry_combo_type_id;
}

GType
spice_entry_combo_get_type (void)
{
	static volatile gsize spice_entry_combo_type_id__once = 0;
	if (g_once_init_enter (&spice_entry_combo_type_id__once)) {
		GType spice_entry_combo_type_id;
		spice_entry_combo_type_id = spice_entry_combo_get_type_once ();
		g_once_init_leave (&spice_entry_combo_type_id__once, spice_entry_combo_type_id);
	}
	return spice_entry_combo_type_id__once;
}

static void
_vala_spice_entry_combo_get_property (GObject * object,
                                      guint property_id,
                                      GValue * value,
                                      GParamSpec * pspec)
{
	SpiceEntryCombo * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SPICE_TYPE_ENTRY_COMBO, SpiceEntryCombo);
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	switch (property_id) {
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		case SPICE_ENTRY_COMBO_TEXT_PROPERTY:
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		g_value_set_string (value, spice_entry_combo_get_text (self));
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		break;
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		case SPICE_ENTRY_COMBO_MAX_LENGTH_PROPERTY:
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		g_value_set_int (value, spice_entry_combo_get_max_length (self));
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		break;
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		case SPICE_ENTRY_COMBO_EDITABLE_PROPERTY:
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		g_value_set_boolean (value, spice_entry_combo_get_editable (self));
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		break;
#line 1689 "EntryCombo.c"
		default:
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		break;
#line 1695 "EntryCombo.c"
	}
}

static void
_vala_spice_entry_combo_set_property (GObject * object,
                                      guint property_id,
                                      const GValue * value,
                                      GParamSpec * pspec)
{
	SpiceEntryCombo * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SPICE_TYPE_ENTRY_COMBO, SpiceEntryCombo);
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
	switch (property_id) {
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		case SPICE_ENTRY_COMBO_TEXT_PROPERTY:
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		spice_entry_combo_set_text (self, g_value_get_string (value));
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		break;
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		case SPICE_ENTRY_COMBO_MAX_LENGTH_PROPERTY:
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		spice_entry_combo_set_max_length (self, g_value_get_int (value));
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		break;
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		case SPICE_ENTRY_COMBO_EDITABLE_PROPERTY:
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		spice_entry_combo_set_editable (self, g_value_get_boolean (value));
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		break;
#line 1727 "EntryCombo.c"
		default:
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 22 "../Spice-up-1.9.1/src/Widgets/EntryCombo.vala"
		break;
#line 1733 "EntryCombo.c"
	}
}

