/* Headerbar.c generated by valac 0.56.18, the Vala compiler
 * generated from Headerbar.vala, do not modify */

/*
* Copyright (c) 2016 Felipe Escoto (https://github.com/Philip-Scott/Spice-up)
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the
* Free Software Foundation, Inc., 59 Temple Place - Suite 330,
* Boston, MA 02111-1307, USA.
*
* Authored by: Felipe Escoto <felescoto95@hotmail.com>
*/

#include <gtk/gtk.h>
#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>

#define SPICE_WINDOW_ACTION_UNDO "action_undo"
#define SPICE_WINDOW_ACTION_REDO "action_redo"
#define SPICE_WINDOW_ACTION_INSERT_TEXT "action_insert_txt"
#define SPICE_WINDOW_ACTION_INSERT_IMG "action_insert_img"
#define SPICE_WINDOW_ACTION_INSERT_SHAPE "action_insert_shape"
#define SPICE_WINDOW_ACTION_SHOW_WELCOME "show_welcome"
#define SPICE_WINDOW_ACTION_EXPORT "action_export"
#define SPICE_WINDOW_ACTION_PRESENT_START "action_present_start"
#define SPICE_WINDOW_ACTION_NOTES "toggle_notes"
#define SPICE_WINDOW_ACTION_PRESENT_STOP "action_present_stop"
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define SPICE_TYPE_HEADERBAR (spice_headerbar_get_type ())
#define SPICE_HEADERBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_HEADERBAR, SpiceHeaderbar))
#define SPICE_HEADERBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_HEADERBAR, SpiceHeaderbarClass))
#define SPICE_IS_HEADERBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_HEADERBAR))
#define SPICE_IS_HEADERBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_HEADERBAR))
#define SPICE_HEADERBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_HEADERBAR, SpiceHeaderbarClass))

typedef struct _SpiceHeaderbar SpiceHeaderbar;
typedef struct _SpiceHeaderbarClass SpiceHeaderbarClass;
typedef struct _SpiceHeaderbarPrivate SpiceHeaderbarPrivate;

#define SPICE_HEADERBAR_TYPE_HEADERBAR_BUTTON (spice_headerbar_headerbar_button_get_type ())
#define SPICE_HEADERBAR_HEADERBAR_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_HEADERBAR_TYPE_HEADERBAR_BUTTON, SpiceHeaderbarHeaderbarButton))
#define SPICE_HEADERBAR_HEADERBAR_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_HEADERBAR_TYPE_HEADERBAR_BUTTON, SpiceHeaderbarHeaderbarButtonClass))
#define SPICE_HEADERBAR_IS_HEADERBAR_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_HEADERBAR_TYPE_HEADERBAR_BUTTON))
#define SPICE_HEADERBAR_IS_HEADERBAR_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_HEADERBAR_TYPE_HEADERBAR_BUTTON))
#define SPICE_HEADERBAR_HEADERBAR_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_HEADERBAR_TYPE_HEADERBAR_BUTTON, SpiceHeaderbarHeaderbarButtonClass))

typedef struct _SpiceHeaderbarHeaderbarButton SpiceHeaderbarHeaderbarButton;
typedef struct _SpiceHeaderbarHeaderbarButtonClass SpiceHeaderbarHeaderbarButtonClass;

#define SPICE_TYPE_SLIDE_MANAGER (spice_slide_manager_get_type ())
#define SPICE_SLIDE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManager))
#define SPICE_SLIDE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManagerClass))
#define SPICE_IS_SLIDE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_SLIDE_MANAGER))
#define SPICE_IS_SLIDE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_SLIDE_MANAGER))
#define SPICE_SLIDE_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManagerClass))

typedef struct _SpiceSlideManager SpiceSlideManager;
typedef struct _SpiceSlideManagerClass SpiceSlideManagerClass;
enum  {
	SPICE_HEADERBAR_0_PROPERTY,
	SPICE_HEADERBAR_SENSITIVE_PROPERTY,
	SPICE_HEADERBAR_IS_PRESENTING_PROPERTY,
	SPICE_HEADERBAR_NOTES_SHOWN_PROPERTY,
	SPICE_HEADERBAR_NUM_PROPERTIES
};
static GParamSpec* spice_headerbar_properties[SPICE_HEADERBAR_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define SPICE_TYPE_WINDOW (spice_window_get_type ())
#define SPICE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_WINDOW, SpiceWindow))
#define SPICE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_WINDOW, SpiceWindowClass))
#define SPICE_IS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_WINDOW))
#define SPICE_IS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_WINDOW))
#define SPICE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_WINDOW, SpiceWindowClass))

typedef struct _SpiceWindow SpiceWindow;
typedef struct _SpiceWindowClass SpiceWindowClass;

#define SPICE_SERVICES_TYPE_HISTORY_MANAGER (spice_services_history_manager_get_type ())
#define SPICE_SERVICES_HISTORY_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_SERVICES_TYPE_HISTORY_MANAGER, SpiceServicesHistoryManager))
#define SPICE_SERVICES_HISTORY_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_SERVICES_TYPE_HISTORY_MANAGER, SpiceServicesHistoryManagerClass))
#define SPICE_SERVICES_IS_HISTORY_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_SERVICES_TYPE_HISTORY_MANAGER))
#define SPICE_SERVICES_IS_HISTORY_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_SERVICES_TYPE_HISTORY_MANAGER))
#define SPICE_SERVICES_HISTORY_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_SERVICES_TYPE_HISTORY_MANAGER, SpiceServicesHistoryManagerClass))

typedef struct _SpiceServicesHistoryManager SpiceServicesHistoryManager;
typedef struct _SpiceServicesHistoryManagerClass SpiceServicesHistoryManagerClass;
typedef struct _SpiceHeaderbarHeaderbarButtonPrivate SpiceHeaderbarHeaderbarButtonPrivate;
enum  {
	SPICE_HEADERBAR_HEADERBAR_BUTTON_0_PROPERTY,
	SPICE_HEADERBAR_HEADERBAR_BUTTON_NUM_PROPERTIES
};
static GParamSpec* spice_headerbar_headerbar_button_properties[SPICE_HEADERBAR_HEADERBAR_BUTTON_NUM_PROPERTIES];

struct _SpiceHeaderbar {
	GtkHeaderBar parent_instance;
	SpiceHeaderbarPrivate * priv;
};

struct _SpiceHeaderbarClass {
	GtkHeaderBarClass parent_class;
};

struct _SpiceHeaderbarPrivate {
	SpiceHeaderbarHeaderbarButton* undo;
	SpiceHeaderbarHeaderbarButton* redo;
	SpiceHeaderbarHeaderbarButton* text;
	SpiceHeaderbarHeaderbarButton* image;
	SpiceHeaderbarHeaderbarButton* shape;
	SpiceHeaderbarHeaderbarButton* export;
	SpiceHeaderbarHeaderbarButton* show_welcome;
	SpiceHeaderbarHeaderbarButton* present;
	GtkToggleButton* show_notes;
	SpiceSlideManager* slide_manager;
	gboolean notes_state_set;
};

struct _SpiceHeaderbarHeaderbarButton {
	GtkButton parent_instance;
	SpiceHeaderbarHeaderbarButtonPrivate * priv;
};

struct _SpiceHeaderbarHeaderbarButtonClass {
	GtkButtonClass parent_class;
};

static gint SpiceHeaderbar_private_offset;
static gpointer spice_headerbar_parent_class = NULL;
static gpointer spice_headerbar_headerbar_button_parent_class = NULL;

VALA_EXTERN GType spice_headerbar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceHeaderbar, g_object_unref)
VALA_EXTERN GType spice_headerbar_headerbar_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceHeaderbarHeaderbarButton, g_object_unref)
VALA_EXTERN GType spice_slide_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceSlideManager, g_object_unref)
VALA_EXTERN SpiceHeaderbar* spice_headerbar_new (SpiceSlideManager* slide_manager);
VALA_EXTERN SpiceHeaderbar* spice_headerbar_construct (GType object_type,
                                           SpiceSlideManager* slide_manager);
static void spice_headerbar_build_ui (SpiceHeaderbar* self);
static void spice_headerbar_connect_signals (SpiceHeaderbar* self);
VALA_EXTERN gchar* spice_utils_get_accel_tooltip (const gchar* action_name,
                                      const gchar* description);
VALA_EXTERN SpiceHeaderbarHeaderbarButton* spice_headerbar_headerbar_button_new (SpiceHeaderbar* headerbar,
                                                                     const gchar* icon_name,
                                                                     const gchar* description);
VALA_EXTERN SpiceHeaderbarHeaderbarButton* spice_headerbar_headerbar_button_construct (GType object_type,
                                                                           SpiceHeaderbar* headerbar,
                                                                           const gchar* icon_name,
                                                                           const gchar* description);
VALA_EXTERN GType spice_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceWindow, g_object_unref)
VALA_EXTERN SpiceWindow* spice_slide_manager_get_window (SpiceSlideManager* self);
VALA_EXTERN GType spice_services_history_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceServicesHistoryManager, g_object_unref)
VALA_EXTERN SpiceServicesHistoryManager* spice_window_get_history_manager (SpiceWindow* self);
static void __lambda96_ (SpiceHeaderbar* self,
                  gboolean is_empty);
static void ___lambda96__spice_services_history_manager_undo_changed (SpiceServicesHistoryManager* _sender,
                                                               gboolean is_empty,
                                                               gpointer self);
static void __lambda97_ (SpiceHeaderbar* self,
                  gboolean is_empty);
static void ___lambda97__spice_services_history_manager_redo_changed (SpiceServicesHistoryManager* _sender,
                                                               gboolean is_empty,
                                                               gpointer self);
static void __lambda98_ (SpiceHeaderbar* self);
VALA_EXTERN void spice_window_action_undo (SpiceWindow* self);
static void ___lambda98__gtk_button_clicked (GtkButton* _sender,
                                      gpointer self);
static void __lambda99_ (SpiceHeaderbar* self);
VALA_EXTERN void spice_window_action_redo (SpiceWindow* self);
static void ___lambda99__gtk_button_clicked (GtkButton* _sender,
                                      gpointer self);
static void __lambda100_ (SpiceHeaderbar* self);
VALA_EXTERN void spice_window_action_present_toggle (SpiceWindow* self);
static void ___lambda100__gtk_button_clicked (GtkButton* _sender,
                                       gpointer self);
static void __lambda101_ (SpiceHeaderbar* self);
VALA_EXTERN void spice_window_action_toggle_notes (SpiceWindow* self);
static void ___lambda101__gtk_toggle_button_toggled (GtkToggleButton* _sender,
                                              gpointer self);
VALA_EXTERN void spice_window_action_insert_txt (SpiceWindow* self);
static void _spice_window_action_insert_txt_gtk_button_clicked (GtkButton* _sender,
                                                         gpointer self);
VALA_EXTERN void spice_window_action_insert_img (SpiceWindow* self);
static void _spice_window_action_insert_img_gtk_button_clicked (GtkButton* _sender,
                                                         gpointer self);
VALA_EXTERN void spice_window_action_insert_shape (SpiceWindow* self);
static void _spice_window_action_insert_shape_gtk_button_clicked (GtkButton* _sender,
                                                           gpointer self);
VALA_EXTERN void spice_window_show_welcome (SpiceWindow* self);
static void _spice_window_show_welcome_gtk_button_clicked (GtkButton* _sender,
                                                    gpointer self);
VALA_EXTERN void spice_window_action_export (SpiceWindow* self);
static void _spice_window_action_export_gtk_button_clicked (GtkButton* _sender,
                                                     gpointer self);
VALA_EXTERN gboolean spice_headerbar_get_sensitive (SpiceHeaderbar* self);
VALA_EXTERN void spice_headerbar_set_sensitive (SpiceHeaderbar* self,
                                    gboolean value);
VALA_EXTERN void spice_headerbar_set_is_presenting (SpiceHeaderbar* self,
                                        gboolean value);
VALA_EXTERN void spice_headerbar_set_notes_shown (SpiceHeaderbar* self,
                                      gboolean value);
static GType spice_headerbar_headerbar_button_get_type_once (void);
static void spice_headerbar_finalize (GObject * obj);
static GType spice_headerbar_get_type_once (void);
static void _vala_spice_headerbar_get_property (GObject * object,
                                         guint property_id,
                                         GValue * value,
                                         GParamSpec * pspec);
static void _vala_spice_headerbar_set_property (GObject * object,
                                         guint property_id,
                                         const GValue * value,
                                         GParamSpec * pspec);

static inline gpointer
spice_headerbar_get_instance_private (SpiceHeaderbar* self)
{
	return G_STRUCT_MEMBER_P (self, SpiceHeaderbar_private_offset);
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 91 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	return self ? g_object_ref (self) : NULL;
#line 261 "Headerbar.c"
}

SpiceHeaderbar*
spice_headerbar_construct (GType object_type,
                           SpiceSlideManager* slide_manager)
{
	SpiceHeaderbar * self = NULL;
	SpiceSlideManager* _tmp0_;
#line 90 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_return_val_if_fail (slide_manager != NULL, NULL);
#line 90 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	self = (SpiceHeaderbar*) g_object_new (object_type, NULL);
#line 91 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp0_ = _g_object_ref0 (slide_manager);
#line 91 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (self->priv->slide_manager);
#line 91 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	self->priv->slide_manager = _tmp0_;
#line 92 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_header_bar_set_title ((GtkHeaderBar*) self, "Presentation");
#line 93 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_header_bar_set_show_close_button ((GtkHeaderBar*) self, TRUE);
#line 95 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	spice_headerbar_build_ui (self);
#line 96 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	spice_headerbar_connect_signals (self);
#line 90 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	return self;
#line 290 "Headerbar.c"
}

SpiceHeaderbar*
spice_headerbar_new (SpiceSlideManager* slide_manager)
{
#line 90 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	return spice_headerbar_construct (SPICE_TYPE_HEADERBAR, slide_manager);
#line 298 "Headerbar.c"
}

static void
spice_headerbar_build_ui (SpiceHeaderbar* self)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	SpiceHeaderbarHeaderbarButton* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	SpiceHeaderbarHeaderbarButton* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	SpiceHeaderbarHeaderbarButton* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	SpiceHeaderbarHeaderbarButton* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	SpiceHeaderbarHeaderbarButton* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	SpiceHeaderbarHeaderbarButton* _tmp17_;
	SpiceHeaderbarHeaderbarButton* _tmp18_;
	SpiceHeaderbarHeaderbarButton* _tmp19_;
	gchar* _tmp20_;
	gchar* _tmp21_;
	SpiceHeaderbarHeaderbarButton* _tmp22_;
	gchar* _tmp23_;
	gchar* _tmp24_;
	SpiceHeaderbarHeaderbarButton* _tmp25_;
	SpiceHeaderbarHeaderbarButton* _tmp26_;
	GtkStyleContext* _tmp27_;
	GtkToggleButton* _tmp28_;
	GtkToggleButton* _tmp29_;
	GtkImage* show_notes_image = NULL;
	GtkImage* _tmp30_;
	GtkToggleButton* _tmp31_;
	GtkStyleContext* _tmp32_;
	GtkToggleButton* _tmp33_;
	gchar* _tmp34_;
	gchar* _tmp35_;
	GtkToggleButton* _tmp36_;
	GtkGrid* undo_redo_box = NULL;
	GtkGrid* _tmp37_;
	GtkGrid* object_box = NULL;
	GtkGrid* _tmp38_;
	GtkStyleContext* _tmp39_;
	GtkStyleContext* _tmp40_;
	SpiceHeaderbarHeaderbarButton* _tmp41_;
	SpiceHeaderbarHeaderbarButton* _tmp42_;
	SpiceHeaderbarHeaderbarButton* _tmp43_;
	SpiceHeaderbarHeaderbarButton* _tmp44_;
	SpiceHeaderbarHeaderbarButton* _tmp45_;
	SpiceHeaderbarHeaderbarButton* _tmp46_;
	SpiceHeaderbarHeaderbarButton* _tmp47_;
	SpiceHeaderbarHeaderbarButton* _tmp48_;
	GtkToggleButton* _tmp49_;
#line 99 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_return_if_fail (self != NULL);
#line 100 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_header_bar_set_has_subtitle ((GtkHeaderBar*) self, FALSE);
#line 102 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp0_ = spice_utils_get_accel_tooltip (SPICE_WINDOW_ACTION_UNDO, _ ("Undo"));
#line 102 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp1_ = _tmp0_;
#line 102 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp2_ = spice_headerbar_headerbar_button_new (self, "edit-undo-symbolic", _tmp1_);
#line 102 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_ref_sink (_tmp2_);
#line 102 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (self->priv->undo);
#line 102 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	self->priv->undo = _tmp2_;
#line 102 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_free0 (_tmp1_);
#line 103 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp3_ = spice_utils_get_accel_tooltip (SPICE_WINDOW_ACTION_REDO, _ ("Redo"));
#line 103 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp4_ = _tmp3_;
#line 103 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp5_ = spice_headerbar_headerbar_button_new (self, "edit-redo-symbolic", _tmp4_);
#line 103 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_ref_sink (_tmp5_);
#line 103 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (self->priv->redo);
#line 103 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	self->priv->redo = _tmp5_;
#line 103 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_free0 (_tmp4_);
#line 104 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp6_ = spice_utils_get_accel_tooltip (SPICE_WINDOW_ACTION_INSERT_TEXT, _ ("Insert Text Box"));
#line 104 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp7_ = _tmp6_;
#line 104 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp8_ = spice_headerbar_headerbar_button_new (self, "insert-text-symbolic", _tmp7_);
#line 104 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_ref_sink (_tmp8_);
#line 104 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (self->priv->text);
#line 104 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	self->priv->text = _tmp8_;
#line 104 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_free0 (_tmp7_);
#line 105 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp9_ = spice_utils_get_accel_tooltip (SPICE_WINDOW_ACTION_INSERT_IMG, _ ("Insert Image"));
#line 105 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp10_ = _tmp9_;
#line 105 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp11_ = spice_headerbar_headerbar_button_new (self, "insert-image-symbolic", _tmp10_);
#line 105 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_ref_sink (_tmp11_);
#line 105 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (self->priv->image);
#line 105 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	self->priv->image = _tmp11_;
#line 105 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_free0 (_tmp10_);
#line 106 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp12_ = spice_utils_get_accel_tooltip (SPICE_WINDOW_ACTION_INSERT_SHAPE, _ ("Insert Shape"));
#line 106 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp13_ = _tmp12_;
#line 106 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp14_ = spice_headerbar_headerbar_button_new (self, "insert-object-symbolic", _tmp13_);
#line 106 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_ref_sink (_tmp14_);
#line 106 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (self->priv->shape);
#line 106 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	self->priv->shape = _tmp14_;
#line 106 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_free0 (_tmp13_);
#line 107 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp15_ = spice_utils_get_accel_tooltip (SPICE_WINDOW_ACTION_SHOW_WELCOME, _ ("Return to Welcome Screen"));
#line 107 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp16_ = _tmp15_;
#line 107 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp17_ = spice_headerbar_headerbar_button_new (self, "document-open-symbolic", _tmp16_);
#line 107 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_ref_sink (_tmp17_);
#line 107 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (self->priv->show_welcome);
#line 107 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	self->priv->show_welcome = _tmp17_;
#line 107 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_free0 (_tmp16_);
#line 109 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp18_ = self->priv->undo;
#line 109 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp18_, FALSE);
#line 110 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp19_ = self->priv->redo;
#line 110 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp19_, FALSE);
#line 112 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp20_ = spice_utils_get_accel_tooltip (SPICE_WINDOW_ACTION_EXPORT, _ ("Export to PDF"));
#line 112 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp21_ = _tmp20_;
#line 112 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp22_ = spice_headerbar_headerbar_button_new (self, "document-export-symbolic", _tmp21_);
#line 112 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_ref_sink (_tmp22_);
#line 112 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (self->priv->export);
#line 112 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	self->priv->export = _tmp22_;
#line 112 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_free0 (_tmp21_);
#line 113 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp23_ = spice_utils_get_accel_tooltip (SPICE_WINDOW_ACTION_PRESENT_START, _ ("Start Presentation"));
#line 113 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp24_ = _tmp23_;
#line 113 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp25_ = spice_headerbar_headerbar_button_new (self, "media-playback-start-symbolic", _tmp24_);
#line 113 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_ref_sink (_tmp25_);
#line 113 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (self->priv->present);
#line 113 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	self->priv->present = _tmp25_;
#line 113 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_free0 (_tmp24_);
#line 114 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp26_ = self->priv->present;
#line 114 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp27_ = gtk_widget_get_style_context ((GtkWidget*) _tmp26_);
#line 114 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_style_context_add_class (_tmp27_, "suggested-action");
#line 116 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp28_ = (GtkToggleButton*) gtk_toggle_button_new ();
#line 116 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_ref_sink (_tmp28_);
#line 116 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (self->priv->show_notes);
#line 116 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	self->priv->show_notes = _tmp28_;
#line 117 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp29_ = self->priv->show_notes;
#line 117 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_can_focus ((GtkWidget*) _tmp29_, FALSE);
#line 119 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp30_ = (GtkImage*) gtk_image_new_from_icon_name ("accessories-text-editor-symbolic", (GtkIconSize) GTK_ICON_SIZE_BUTTON);
#line 119 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_ref_sink (_tmp30_);
#line 119 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	show_notes_image = _tmp30_;
#line 120 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_set ((GtkWidget*) show_notes_image, "margin", 3, NULL);
#line 122 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp31_ = self->priv->show_notes;
#line 122 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp32_ = gtk_widget_get_style_context ((GtkWidget*) _tmp31_);
#line 122 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_style_context_add_class (_tmp32_, GTK_STYLE_CLASS_RAISED);
#line 123 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp33_ = self->priv->show_notes;
#line 123 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp34_ = spice_utils_get_accel_tooltip (SPICE_WINDOW_ACTION_NOTES, _ ("Presenter Notes"));
#line 123 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp35_ = _tmp34_;
#line 123 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_tooltip_markup ((GtkWidget*) _tmp33_, _tmp35_);
#line 123 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_free0 (_tmp35_);
#line 124 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp36_ = self->priv->show_notes;
#line 124 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_container_add ((GtkContainer*) _tmp36_, (GtkWidget*) show_notes_image);
#line 126 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp37_ = (GtkGrid*) gtk_grid_new ();
#line 126 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_ref_sink (_tmp37_);
#line 126 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	undo_redo_box = _tmp37_;
#line 127 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp38_ = (GtkGrid*) gtk_grid_new ();
#line 127 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_ref_sink (_tmp38_);
#line 127 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	object_box = _tmp38_;
#line 129 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp39_ = gtk_widget_get_style_context ((GtkWidget*) undo_redo_box);
#line 129 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_style_context_add_class (_tmp39_, "linked");
#line 130 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp40_ = gtk_widget_get_style_context ((GtkWidget*) object_box);
#line 130 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_style_context_add_class (_tmp40_, "linked");
#line 132 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp41_ = self->priv->undo;
#line 132 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_container_add ((GtkContainer*) undo_redo_box, (GtkWidget*) _tmp41_);
#line 133 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp42_ = self->priv->redo;
#line 133 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_container_add ((GtkContainer*) undo_redo_box, (GtkWidget*) _tmp42_);
#line 135 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp43_ = self->priv->text;
#line 135 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_container_add ((GtkContainer*) object_box, (GtkWidget*) _tmp43_);
#line 136 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp44_ = self->priv->image;
#line 136 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_container_add ((GtkContainer*) object_box, (GtkWidget*) _tmp44_);
#line 137 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp45_ = self->priv->shape;
#line 137 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_container_add ((GtkContainer*) object_box, (GtkWidget*) _tmp45_);
#line 139 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_header_bar_pack_start ((GtkHeaderBar*) self, (GtkWidget*) undo_redo_box);
#line 140 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_header_bar_pack_start ((GtkHeaderBar*) self, (GtkWidget*) object_box);
#line 142 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp46_ = self->priv->present;
#line 142 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_header_bar_pack_end ((GtkHeaderBar*) self, (GtkWidget*) _tmp46_);
#line 143 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp47_ = self->priv->export;
#line 143 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_header_bar_pack_end ((GtkHeaderBar*) self, (GtkWidget*) _tmp47_);
#line 144 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp48_ = self->priv->show_welcome;
#line 144 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_header_bar_pack_end ((GtkHeaderBar*) self, (GtkWidget*) _tmp48_);
#line 145 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp49_ = self->priv->show_notes;
#line 145 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_header_bar_pack_end ((GtkHeaderBar*) self, (GtkWidget*) _tmp49_);
#line 99 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (object_box);
#line 99 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (undo_redo_box);
#line 99 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (show_notes_image);
#line 593 "Headerbar.c"
}

static void
__lambda96_ (SpiceHeaderbar* self,
             gboolean is_empty)
{
	SpiceHeaderbarHeaderbarButton* _tmp0_;
#line 150 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp0_ = self->priv->undo;
#line 150 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, !is_empty);
#line 605 "Headerbar.c"
}

static void
___lambda96__spice_services_history_manager_undo_changed (SpiceServicesHistoryManager* _sender,
                                                          gboolean is_empty,
                                                          gpointer self)
{
#line 149 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	__lambda96_ ((SpiceHeaderbar*) self, is_empty);
#line 615 "Headerbar.c"
}

static void
__lambda97_ (SpiceHeaderbar* self,
             gboolean is_empty)
{
	SpiceHeaderbarHeaderbarButton* _tmp0_;
#line 154 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp0_ = self->priv->redo;
#line 154 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, !is_empty);
#line 627 "Headerbar.c"
}

static void
___lambda97__spice_services_history_manager_redo_changed (SpiceServicesHistoryManager* _sender,
                                                          gboolean is_empty,
                                                          gpointer self)
{
#line 153 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	__lambda97_ ((SpiceHeaderbar*) self, is_empty);
#line 637 "Headerbar.c"
}

static void
__lambda98_ (SpiceHeaderbar* self)
{
	SpiceSlideManager* _tmp0_;
	SpiceWindow* _tmp1_;
	SpiceWindow* _tmp2_;
#line 158 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp0_ = self->priv->slide_manager;
#line 158 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp1_ = spice_slide_manager_get_window (_tmp0_);
#line 158 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp2_ = _tmp1_;
#line 158 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	spice_window_action_undo (_tmp2_);
#line 654 "Headerbar.c"
}

static void
___lambda98__gtk_button_clicked (GtkButton* _sender,
                                 gpointer self)
{
#line 157 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	__lambda98_ ((SpiceHeaderbar*) self);
#line 663 "Headerbar.c"
}

static void
__lambda99_ (SpiceHeaderbar* self)
{
	SpiceSlideManager* _tmp0_;
	SpiceWindow* _tmp1_;
	SpiceWindow* _tmp2_;
#line 162 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp0_ = self->priv->slide_manager;
#line 162 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp1_ = spice_slide_manager_get_window (_tmp0_);
#line 162 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp2_ = _tmp1_;
#line 162 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	spice_window_action_redo (_tmp2_);
#line 680 "Headerbar.c"
}

static void
___lambda99__gtk_button_clicked (GtkButton* _sender,
                                 gpointer self)
{
#line 161 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	__lambda99_ ((SpiceHeaderbar*) self);
#line 689 "Headerbar.c"
}

static void
__lambda100_ (SpiceHeaderbar* self)
{
	SpiceSlideManager* _tmp0_;
	SpiceWindow* _tmp1_;
	SpiceWindow* _tmp2_;
#line 166 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp0_ = self->priv->slide_manager;
#line 166 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp1_ = spice_slide_manager_get_window (_tmp0_);
#line 166 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp2_ = _tmp1_;
#line 166 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	spice_window_action_present_toggle (_tmp2_);
#line 706 "Headerbar.c"
}

static void
___lambda100__gtk_button_clicked (GtkButton* _sender,
                                  gpointer self)
{
#line 165 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	__lambda100_ ((SpiceHeaderbar*) self);
#line 715 "Headerbar.c"
}

static void
__lambda101_ (SpiceHeaderbar* self)
{
#line 170 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	if (!self->priv->notes_state_set) {
#line 723 "Headerbar.c"
		SpiceSlideManager* _tmp0_;
		SpiceWindow* _tmp1_;
		SpiceWindow* _tmp2_;
#line 171 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		_tmp0_ = self->priv->slide_manager;
#line 171 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		_tmp1_ = spice_slide_manager_get_window (_tmp0_);
#line 171 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		_tmp2_ = _tmp1_;
#line 171 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		spice_window_action_toggle_notes (_tmp2_);
#line 735 "Headerbar.c"
	}
}

static void
___lambda101__gtk_toggle_button_toggled (GtkToggleButton* _sender,
                                         gpointer self)
{
#line 169 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	__lambda101_ ((SpiceHeaderbar*) self);
#line 745 "Headerbar.c"
}

static void
_spice_window_action_insert_txt_gtk_button_clicked (GtkButton* _sender,
                                                    gpointer self)
{
#line 175 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	spice_window_action_insert_txt ((SpiceWindow*) self);
#line 754 "Headerbar.c"
}

static void
_spice_window_action_insert_img_gtk_button_clicked (GtkButton* _sender,
                                                    gpointer self)
{
#line 176 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	spice_window_action_insert_img ((SpiceWindow*) self);
#line 763 "Headerbar.c"
}

static void
_spice_window_action_insert_shape_gtk_button_clicked (GtkButton* _sender,
                                                      gpointer self)
{
#line 177 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	spice_window_action_insert_shape ((SpiceWindow*) self);
#line 772 "Headerbar.c"
}

static void
_spice_window_show_welcome_gtk_button_clicked (GtkButton* _sender,
                                               gpointer self)
{
#line 178 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	spice_window_show_welcome ((SpiceWindow*) self);
#line 781 "Headerbar.c"
}

static void
_spice_window_action_export_gtk_button_clicked (GtkButton* _sender,
                                                gpointer self)
{
#line 179 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	spice_window_action_export ((SpiceWindow*) self);
#line 790 "Headerbar.c"
}

static void
spice_headerbar_connect_signals (SpiceHeaderbar* self)
{
	SpiceSlideManager* _tmp0_;
	SpiceWindow* _tmp1_;
	SpiceWindow* _tmp2_;
	SpiceServicesHistoryManager* _tmp3_;
	SpiceServicesHistoryManager* _tmp4_;
	SpiceSlideManager* _tmp5_;
	SpiceWindow* _tmp6_;
	SpiceWindow* _tmp7_;
	SpiceServicesHistoryManager* _tmp8_;
	SpiceServicesHistoryManager* _tmp9_;
	SpiceHeaderbarHeaderbarButton* _tmp10_;
	SpiceHeaderbarHeaderbarButton* _tmp11_;
	SpiceHeaderbarHeaderbarButton* _tmp12_;
	GtkToggleButton* _tmp13_;
	SpiceHeaderbarHeaderbarButton* _tmp14_;
	SpiceSlideManager* _tmp15_;
	SpiceWindow* _tmp16_;
	SpiceWindow* _tmp17_;
	SpiceHeaderbarHeaderbarButton* _tmp18_;
	SpiceSlideManager* _tmp19_;
	SpiceWindow* _tmp20_;
	SpiceWindow* _tmp21_;
	SpiceHeaderbarHeaderbarButton* _tmp22_;
	SpiceSlideManager* _tmp23_;
	SpiceWindow* _tmp24_;
	SpiceWindow* _tmp25_;
	SpiceHeaderbarHeaderbarButton* _tmp26_;
	SpiceSlideManager* _tmp27_;
	SpiceWindow* _tmp28_;
	SpiceWindow* _tmp29_;
	SpiceHeaderbarHeaderbarButton* _tmp30_;
	SpiceSlideManager* _tmp31_;
	SpiceWindow* _tmp32_;
	SpiceWindow* _tmp33_;
#line 148 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_return_if_fail (self != NULL);
#line 149 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp0_ = self->priv->slide_manager;
#line 149 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp1_ = spice_slide_manager_get_window (_tmp0_);
#line 149 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp2_ = _tmp1_;
#line 149 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp3_ = spice_window_get_history_manager (_tmp2_);
#line 149 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp4_ = _tmp3_;
#line 149 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_signal_connect_object (_tmp4_, "undo-changed", (GCallback) ___lambda96__spice_services_history_manager_undo_changed, self, 0);
#line 153 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp5_ = self->priv->slide_manager;
#line 153 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp6_ = spice_slide_manager_get_window (_tmp5_);
#line 153 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp7_ = _tmp6_;
#line 153 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp8_ = spice_window_get_history_manager (_tmp7_);
#line 153 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp9_ = _tmp8_;
#line 153 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_signal_connect_object (_tmp9_, "redo-changed", (GCallback) ___lambda97__spice_services_history_manager_redo_changed, self, 0);
#line 157 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp10_ = self->priv->undo;
#line 157 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_signal_connect_object ((GtkButton*) _tmp10_, "clicked", (GCallback) ___lambda98__gtk_button_clicked, self, 0);
#line 161 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp11_ = self->priv->redo;
#line 161 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_signal_connect_object ((GtkButton*) _tmp11_, "clicked", (GCallback) ___lambda99__gtk_button_clicked, self, 0);
#line 165 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp12_ = self->priv->present;
#line 165 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_signal_connect_object ((GtkButton*) _tmp12_, "clicked", (GCallback) ___lambda100__gtk_button_clicked, self, 0);
#line 169 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp13_ = self->priv->show_notes;
#line 169 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_signal_connect_object (_tmp13_, "toggled", (GCallback) ___lambda101__gtk_toggle_button_toggled, self, 0);
#line 175 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp14_ = self->priv->text;
#line 175 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp15_ = self->priv->slide_manager;
#line 175 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp16_ = spice_slide_manager_get_window (_tmp15_);
#line 175 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp17_ = _tmp16_;
#line 175 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_signal_connect_object ((GtkButton*) _tmp14_, "clicked", (GCallback) _spice_window_action_insert_txt_gtk_button_clicked, _tmp17_, 0);
#line 176 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp18_ = self->priv->image;
#line 176 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp19_ = self->priv->slide_manager;
#line 176 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp20_ = spice_slide_manager_get_window (_tmp19_);
#line 176 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp21_ = _tmp20_;
#line 176 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_signal_connect_object ((GtkButton*) _tmp18_, "clicked", (GCallback) _spice_window_action_insert_img_gtk_button_clicked, _tmp21_, 0);
#line 177 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp22_ = self->priv->shape;
#line 177 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp23_ = self->priv->slide_manager;
#line 177 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp24_ = spice_slide_manager_get_window (_tmp23_);
#line 177 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp25_ = _tmp24_;
#line 177 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_signal_connect_object ((GtkButton*) _tmp22_, "clicked", (GCallback) _spice_window_action_insert_shape_gtk_button_clicked, _tmp25_, 0);
#line 178 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp26_ = self->priv->show_welcome;
#line 178 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp27_ = self->priv->slide_manager;
#line 178 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp28_ = spice_slide_manager_get_window (_tmp27_);
#line 178 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp29_ = _tmp28_;
#line 178 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_signal_connect_object ((GtkButton*) _tmp26_, "clicked", (GCallback) _spice_window_show_welcome_gtk_button_clicked, _tmp29_, 0);
#line 179 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp30_ = self->priv->export;
#line 179 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp31_ = self->priv->slide_manager;
#line 179 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp32_ = spice_slide_manager_get_window (_tmp31_);
#line 179 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp33_ = _tmp32_;
#line 179 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_signal_connect_object ((GtkButton*) _tmp30_, "clicked", (GCallback) _spice_window_action_export_gtk_button_clicked, _tmp33_, 0);
#line 922 "Headerbar.c"
}

gboolean
spice_headerbar_get_sensitive (SpiceHeaderbar* self)
{
	gboolean result;
	SpiceHeaderbarHeaderbarButton* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 37 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 38 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp0_ = self->priv->present;
#line 38 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp1_ = gtk_widget_get_sensitive ((GtkWidget*) _tmp0_);
#line 38 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp2_ = _tmp1_;
#line 38 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	result = _tmp2_;
#line 38 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	return result;
#line 944 "Headerbar.c"
}

void
spice_headerbar_set_sensitive (SpiceHeaderbar* self,
                               gboolean value)
{
	SpiceHeaderbarHeaderbarButton* _tmp0_;
	SpiceHeaderbarHeaderbarButton* _tmp1_;
	SpiceHeaderbarHeaderbarButton* _tmp2_;
	SpiceHeaderbarHeaderbarButton* _tmp3_;
	SpiceHeaderbarHeaderbarButton* _tmp4_;
	SpiceHeaderbarHeaderbarButton* _tmp5_;
	SpiceHeaderbarHeaderbarButton* _tmp6_;
	SpiceHeaderbarHeaderbarButton* _tmp7_;
	GtkToggleButton* _tmp8_;
#line 40 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_return_if_fail (self != NULL);
#line 41 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp0_ = self->priv->text;
#line 41 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, value);
#line 42 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp1_ = self->priv->undo;
#line 42 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp1_, FALSE);
#line 43 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp2_ = self->priv->redo;
#line 43 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp2_, FALSE);
#line 44 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp3_ = self->priv->shape;
#line 44 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp3_, value);
#line 45 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp4_ = self->priv->image;
#line 45 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp4_, value);
#line 46 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp5_ = self->priv->export;
#line 46 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp5_, value);
#line 47 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp6_ = self->priv->present;
#line 47 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp6_, value);
#line 48 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp7_ = self->priv->show_welcome;
#line 48 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp7_, value);
#line 49 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp8_ = self->priv->show_notes;
#line 49 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp8_, value);
#line 40 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_notify_by_pspec ((GObject *) self, spice_headerbar_properties[SPICE_HEADERBAR_SENSITIVE_PROPERTY]);
#line 1000 "Headerbar.c"
}

void
spice_headerbar_set_is_presenting (SpiceHeaderbar* self,
                                   gboolean value)
{
	SpiceHeaderbarHeaderbarButton* _tmp0_;
	SpiceHeaderbarHeaderbarButton* _tmp1_;
	SpiceHeaderbarHeaderbarButton* _tmp2_;
	SpiceHeaderbarHeaderbarButton* _tmp3_;
	SpiceHeaderbarHeaderbarButton* _tmp4_;
	SpiceHeaderbarHeaderbarButton* _tmp5_;
	SpiceHeaderbarHeaderbarButton* _tmp6_;
	GtkToggleButton* _tmp7_;
	SpiceHeaderbarHeaderbarButton* _tmp8_;
	SpiceHeaderbarHeaderbarButton* _tmp9_;
	SpiceHeaderbarHeaderbarButton* _tmp10_;
	SpiceHeaderbarHeaderbarButton* _tmp11_;
	SpiceHeaderbarHeaderbarButton* _tmp12_;
	SpiceHeaderbarHeaderbarButton* _tmp13_;
	SpiceHeaderbarHeaderbarButton* _tmp14_;
	GtkToggleButton* _tmp15_;
	gchar* _tmp16_ = NULL;
	SpiceHeaderbarHeaderbarButton* _tmp19_;
#line 54 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_return_if_fail (self != NULL);
#line 55 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp0_ = self->priv->text;
#line 55 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp0_, !value);
#line 56 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp1_ = self->priv->undo;
#line 56 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp1_, !value);
#line 57 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp2_ = self->priv->redo;
#line 57 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp2_, !value);
#line 58 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp3_ = self->priv->shape;
#line 58 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp3_, !value);
#line 59 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp4_ = self->priv->image;
#line 59 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp4_, !value);
#line 60 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp5_ = self->priv->export;
#line 60 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp5_, !value);
#line 61 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp6_ = self->priv->show_welcome;
#line 61 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp6_, !value);
#line 62 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp7_ = self->priv->show_notes;
#line 62 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp7_, !value);
#line 64 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp8_ = self->priv->text;
#line 64 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_no_show_all ((GtkWidget*) _tmp8_, value);
#line 65 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp9_ = self->priv->undo;
#line 65 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_no_show_all ((GtkWidget*) _tmp9_, value);
#line 66 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp10_ = self->priv->redo;
#line 66 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_no_show_all ((GtkWidget*) _tmp10_, value);
#line 67 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp11_ = self->priv->shape;
#line 67 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_no_show_all ((GtkWidget*) _tmp11_, value);
#line 68 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp12_ = self->priv->image;
#line 68 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_no_show_all ((GtkWidget*) _tmp12_, value);
#line 69 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp13_ = self->priv->export;
#line 69 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_no_show_all ((GtkWidget*) _tmp13_, value);
#line 70 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp14_ = self->priv->show_welcome;
#line 70 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_no_show_all ((GtkWidget*) _tmp14_, value);
#line 71 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp15_ = self->priv->show_notes;
#line 71 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_no_show_all ((GtkWidget*) _tmp15_, value);
#line 73 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	if (value) {
#line 1093 "Headerbar.c"
		gchar* _tmp17_;
#line 74 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		_tmp17_ = spice_utils_get_accel_tooltip (SPICE_WINDOW_ACTION_PRESENT_STOP, _ ("Stop Presentation"));
#line 74 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		_g_free0 (_tmp16_);
#line 74 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		_tmp16_ = _tmp17_;
#line 1101 "Headerbar.c"
	} else {
		gchar* _tmp18_;
#line 75 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		_tmp18_ = spice_utils_get_accel_tooltip (SPICE_WINDOW_ACTION_PRESENT_START, _ ("Start Presentation"));
#line 75 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		_g_free0 (_tmp16_);
#line 75 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		_tmp16_ = _tmp18_;
#line 1110 "Headerbar.c"
	}
#line 73 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp19_ = self->priv->present;
#line 73 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_tooltip_markup ((GtkWidget*) _tmp19_, _tmp16_);
#line 54 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_free0 (_tmp16_);
#line 54 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_notify_by_pspec ((GObject *) self, spice_headerbar_properties[SPICE_HEADERBAR_IS_PRESENTING_PROPERTY]);
#line 1120 "Headerbar.c"
}

void
spice_headerbar_set_notes_shown (SpiceHeaderbar* self,
                                 gboolean value)
{
	GtkToggleButton* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 81 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_return_if_fail (self != NULL);
#line 82 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp0_ = self->priv->show_notes;
#line 82 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp1_ = gtk_toggle_button_get_active (_tmp0_);
#line 82 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp2_ = _tmp1_;
#line 82 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	if (value != _tmp2_) {
#line 1140 "Headerbar.c"
		GtkToggleButton* _tmp3_;
#line 83 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		self->priv->notes_state_set = TRUE;
#line 84 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		_tmp3_ = self->priv->show_notes;
#line 84 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		gtk_toggle_button_set_active (_tmp3_, value);
#line 85 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		self->priv->notes_state_set = FALSE;
#line 1150 "Headerbar.c"
	}
#line 81 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_notify_by_pspec ((GObject *) self, spice_headerbar_properties[SPICE_HEADERBAR_NOTES_SHOWN_PROPERTY]);
#line 1154 "Headerbar.c"
}

SpiceHeaderbarHeaderbarButton*
spice_headerbar_headerbar_button_construct (GType object_type,
                                            SpiceHeaderbar* headerbar,
                                            const gchar* icon_name,
                                            const gchar* description)
{
	SpiceHeaderbarHeaderbarButton * self = NULL;
	GtkImage* image = NULL;
	GtkImage* _tmp0_;
	GtkStyleContext* _tmp1_;
#line 184 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_return_val_if_fail (headerbar != NULL, NULL);
#line 184 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_return_val_if_fail (icon_name != NULL, NULL);
#line 184 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_return_val_if_fail (description != NULL, NULL);
#line 184 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	self = (SpiceHeaderbarHeaderbarButton*) g_object_new (object_type, NULL);
#line 185 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_can_focus ((GtkWidget*) self, FALSE);
#line 187 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp0_ = (GtkImage*) gtk_image_new_from_icon_name (icon_name, (GtkIconSize) GTK_ICON_SIZE_BUTTON);
#line 187 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_ref_sink (_tmp0_);
#line 187 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	image = _tmp0_;
#line 188 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_set ((GtkWidget*) image, "margin", 3, NULL);
#line 190 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_tmp1_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 190 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_style_context_add_class (_tmp1_, GTK_STYLE_CLASS_RAISED);
#line 191 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_widget_set_tooltip_markup ((GtkWidget*) self, description);
#line 192 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) image);
#line 184 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (image);
#line 184 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	return self;
#line 1197 "Headerbar.c"
}

SpiceHeaderbarHeaderbarButton*
spice_headerbar_headerbar_button_new (SpiceHeaderbar* headerbar,
                                      const gchar* icon_name,
                                      const gchar* description)
{
#line 184 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	return spice_headerbar_headerbar_button_construct (SPICE_HEADERBAR_TYPE_HEADERBAR_BUTTON, headerbar, icon_name, description);
#line 1207 "Headerbar.c"
}

static void
spice_headerbar_headerbar_button_class_init (SpiceHeaderbarHeaderbarButtonClass * klass,
                                             gpointer klass_data)
{
#line 182 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	spice_headerbar_headerbar_button_parent_class = g_type_class_peek_parent (klass);
#line 1216 "Headerbar.c"
}

static void
spice_headerbar_headerbar_button_instance_init (SpiceHeaderbarHeaderbarButton * self,
                                                gpointer klass)
{
}

static GType
spice_headerbar_headerbar_button_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (SpiceHeaderbarHeaderbarButtonClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spice_headerbar_headerbar_button_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpiceHeaderbarHeaderbarButton), 0, (GInstanceInitFunc) spice_headerbar_headerbar_button_instance_init, NULL };
	GType spice_headerbar_headerbar_button_type_id;
	spice_headerbar_headerbar_button_type_id = g_type_register_static (gtk_button_get_type (), "SpiceHeaderbarHeaderbarButton", &g_define_type_info, 0);
	return spice_headerbar_headerbar_button_type_id;
}

GType
spice_headerbar_headerbar_button_get_type (void)
{
	static volatile gsize spice_headerbar_headerbar_button_type_id__once = 0;
	if (g_once_init_enter (&spice_headerbar_headerbar_button_type_id__once)) {
		GType spice_headerbar_headerbar_button_type_id;
		spice_headerbar_headerbar_button_type_id = spice_headerbar_headerbar_button_get_type_once ();
		g_once_init_leave (&spice_headerbar_headerbar_button_type_id__once, spice_headerbar_headerbar_button_type_id);
	}
	return spice_headerbar_headerbar_button_type_id__once;
}

static void
spice_headerbar_class_init (SpiceHeaderbarClass * klass,
                            gpointer klass_data)
{
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	spice_headerbar_parent_class = g_type_class_peek_parent (klass);
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_type_class_adjust_private_offset (klass, &SpiceHeaderbar_private_offset);
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_spice_headerbar_get_property;
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_spice_headerbar_set_property;
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	G_OBJECT_CLASS (klass)->finalize = spice_headerbar_finalize;
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SPICE_HEADERBAR_SENSITIVE_PROPERTY, spice_headerbar_properties[SPICE_HEADERBAR_SENSITIVE_PROPERTY] = g_param_spec_boolean ("sensitive", "sensitive", "sensitive", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SPICE_HEADERBAR_IS_PRESENTING_PROPERTY, spice_headerbar_properties[SPICE_HEADERBAR_IS_PRESENTING_PROPERTY] = g_param_spec_boolean ("is-presenting", "is-presenting", "is-presenting", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_WRITABLE));
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SPICE_HEADERBAR_NOTES_SHOWN_PROPERTY, spice_headerbar_properties[SPICE_HEADERBAR_NOTES_SHOWN_PROPERTY] = g_param_spec_boolean ("notes-shown", "notes-shown", "notes-shown", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_WRITABLE));
#line 1266 "Headerbar.c"
}

static void
spice_headerbar_instance_init (SpiceHeaderbar * self,
                               gpointer klass)
{
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	self->priv = spice_headerbar_get_instance_private (self);
#line 79 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	self->priv->notes_state_set = FALSE;
#line 1277 "Headerbar.c"
}

static void
spice_headerbar_finalize (GObject * obj)
{
	SpiceHeaderbar * self;
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPICE_TYPE_HEADERBAR, SpiceHeaderbar);
#line 23 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (self->priv->undo);
#line 24 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (self->priv->redo);
#line 25 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (self->priv->text);
#line 26 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (self->priv->image);
#line 27 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (self->priv->shape);
#line 28 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (self->priv->export);
#line 29 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (self->priv->show_welcome);
#line 30 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (self->priv->present);
#line 32 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (self->priv->show_notes);
#line 34 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	_g_object_unref0 (self->priv->slide_manager);
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	G_OBJECT_CLASS (spice_headerbar_parent_class)->finalize (obj);
#line 1308 "Headerbar.c"
}

static GType
spice_headerbar_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (SpiceHeaderbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spice_headerbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpiceHeaderbar), 0, (GInstanceInitFunc) spice_headerbar_instance_init, NULL };
	GType spice_headerbar_type_id;
	spice_headerbar_type_id = g_type_register_static (gtk_header_bar_get_type (), "SpiceHeaderbar", &g_define_type_info, 0);
	SpiceHeaderbar_private_offset = g_type_add_instance_private (spice_headerbar_type_id, sizeof (SpiceHeaderbarPrivate));
	return spice_headerbar_type_id;
}

GType
spice_headerbar_get_type (void)
{
	static volatile gsize spice_headerbar_type_id__once = 0;
	if (g_once_init_enter (&spice_headerbar_type_id__once)) {
		GType spice_headerbar_type_id;
		spice_headerbar_type_id = spice_headerbar_get_type_once ();
		g_once_init_leave (&spice_headerbar_type_id__once, spice_headerbar_type_id);
	}
	return spice_headerbar_type_id__once;
}

static void
_vala_spice_headerbar_get_property (GObject * object,
                                    guint property_id,
                                    GValue * value,
                                    GParamSpec * pspec)
{
	SpiceHeaderbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SPICE_TYPE_HEADERBAR, SpiceHeaderbar);
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	switch (property_id) {
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		case SPICE_HEADERBAR_SENSITIVE_PROPERTY:
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		g_value_set_boolean (value, spice_headerbar_get_sensitive (self));
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		break;
#line 1349 "Headerbar.c"
		default:
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		break;
#line 1355 "Headerbar.c"
	}
}

static void
_vala_spice_headerbar_set_property (GObject * object,
                                    guint property_id,
                                    const GValue * value,
                                    GParamSpec * pspec)
{
	SpiceHeaderbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SPICE_TYPE_HEADERBAR, SpiceHeaderbar);
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
	switch (property_id) {
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		case SPICE_HEADERBAR_SENSITIVE_PROPERTY:
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		spice_headerbar_set_sensitive (self, g_value_get_boolean (value));
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		break;
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		case SPICE_HEADERBAR_IS_PRESENTING_PROPERTY:
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		spice_headerbar_set_is_presenting (self, g_value_get_boolean (value));
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		break;
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		case SPICE_HEADERBAR_NOTES_SHOWN_PROPERTY:
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		spice_headerbar_set_notes_shown (self, g_value_get_boolean (value));
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		break;
#line 1387 "Headerbar.c"
		default:
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 22 "../Spice-up-1.9.1/src/Widgets/Headerbar.vala"
		break;
#line 1393 "Headerbar.c"
	}
}

