/* SlideList.c generated by valac 0.56.18, the Vala compiler
 * generated from SlideList.vala, do not modify */

/*
* Copyright (c) 2016 Felipe Escoto (https://github.com/Philip-Scott/Spice-up)
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the
* Free Software Foundation, Inc., 59 Temple Place - Suite 330,
* Boston, MA 02111-1307, USA.
*
* Authored by: Felipe Escoto <felescoto95@hotmail.com>
*/

#include <gtk/gtk.h>
#include <glib-object.h>
#include <glib.h>
#include <gdk/gdk.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <float.h>
#include <math.h>
#include <gee.h>

#define SPICE_SLIDE_LIST_SLIDE_LIST_ROW_STYLE_CSS "\n" \
"            .list-row:active {\n" \
"                opacity: 0.90;\n" \
"            }\n" \
"        "
#define SPICE_WINDOW_ACTION_NEW_SLIDE "action_new_slide"
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define SPICE_TYPE_SLIDE_LIST (spice_slide_list_get_type ())
#define SPICE_SLIDE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_SLIDE_LIST, SpiceSlideList))
#define SPICE_SLIDE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_SLIDE_LIST, SpiceSlideListClass))
#define SPICE_IS_SLIDE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_SLIDE_LIST))
#define SPICE_IS_SLIDE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_SLIDE_LIST))
#define SPICE_SLIDE_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_SLIDE_LIST, SpiceSlideListClass))

typedef struct _SpiceSlideList SpiceSlideList;
typedef struct _SpiceSlideListClass SpiceSlideListClass;
typedef struct _SpiceSlideListPrivate SpiceSlideListPrivate;

#define SPICE_TYPE_SLIDE_MANAGER (spice_slide_manager_get_type ())
#define SPICE_SLIDE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManager))
#define SPICE_SLIDE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManagerClass))
#define SPICE_IS_SLIDE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_SLIDE_MANAGER))
#define SPICE_IS_SLIDE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_SLIDE_MANAGER))
#define SPICE_SLIDE_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManagerClass))

typedef struct _SpiceSlideManager SpiceSlideManager;
typedef struct _SpiceSlideManagerClass SpiceSlideManagerClass;
enum  {
	SPICE_SLIDE_LIST_0_PROPERTY,
	SPICE_SLIDE_LIST_MANAGER_PROPERTY,
	SPICE_SLIDE_LIST_NUM_PROPERTIES
};
static GParamSpec* spice_slide_list_properties[SPICE_SLIDE_LIST_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define SPICE_TYPE_SLIDE (spice_slide_get_type ())
#define SPICE_SLIDE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_SLIDE, SpiceSlide))
#define SPICE_SLIDE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_SLIDE, SpiceSlideClass))
#define SPICE_IS_SLIDE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_SLIDE))
#define SPICE_IS_SLIDE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_SLIDE))
#define SPICE_SLIDE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_SLIDE, SpiceSlideClass))

typedef struct _SpiceSlide SpiceSlide;
typedef struct _SpiceSlideClass SpiceSlideClass;

#define SPICE_SLIDE_LIST_TYPE_SLIDE_LIST_ROW (spice_slide_list_slide_list_row_get_type ())
#define SPICE_SLIDE_LIST_SLIDE_LIST_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_SLIDE_LIST_TYPE_SLIDE_LIST_ROW, SpiceSlideListSlideListRow))
#define SPICE_SLIDE_LIST_SLIDE_LIST_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_SLIDE_LIST_TYPE_SLIDE_LIST_ROW, SpiceSlideListSlideListRowClass))
#define SPICE_SLIDE_LIST_IS_SLIDE_LIST_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_SLIDE_LIST_TYPE_SLIDE_LIST_ROW))
#define SPICE_SLIDE_LIST_IS_SLIDE_LIST_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_SLIDE_LIST_TYPE_SLIDE_LIST_ROW))
#define SPICE_SLIDE_LIST_SLIDE_LIST_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_SLIDE_LIST_TYPE_SLIDE_LIST_ROW, SpiceSlideListSlideListRowClass))

typedef struct _SpiceSlideListSlideListRow SpiceSlideListSlideListRow;
typedef struct _SpiceSlideListSlideListRowClass SpiceSlideListSlideListRowClass;
typedef struct _SpiceSlideListSlideListRowPrivate SpiceSlideListSlideListRowPrivate;

#define SPICE_TYPE_SLIDE_WIDGET (spice_slide_widget_get_type ())
#define SPICE_SLIDE_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_SLIDE_WIDGET, SpiceSlideWidget))
#define SPICE_SLIDE_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_SLIDE_WIDGET, SpiceSlideWidgetClass))
#define SPICE_IS_SLIDE_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_SLIDE_WIDGET))
#define SPICE_IS_SLIDE_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_SLIDE_WIDGET))
#define SPICE_SLIDE_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_SLIDE_WIDGET, SpiceSlideWidgetClass))

typedef struct _SpiceSlideWidget SpiceSlideWidget;
typedef struct _SpiceSlideWidgetClass SpiceSlideWidgetClass;
enum  {
	SPICE_SLIDE_LIST_SLIDE_LIST_ROW_0_PROPERTY,
	SPICE_SLIDE_LIST_SLIDE_LIST_ROW_NUM_PROPERTIES
};
static GParamSpec* spice_slide_list_slide_list_row_properties[SPICE_SLIDE_LIST_SLIDE_LIST_ROW_NUM_PROPERTIES];
typedef struct _Block14Data Block14Data;
#define _g_free0(var) (var = (g_free (var), NULL))

struct _SpiceSlideList {
	GtkGrid parent_instance;
	SpiceSlideListPrivate * priv;
};

struct _SpiceSlideListClass {
	GtkGridClass parent_class;
};

struct _SpiceSlideListPrivate {
	SpiceSlideManager* _manager;
	GtkListBox* slides_list;
};

struct _SpiceSlideListSlideListRow {
	GtkListBoxRow parent_instance;
	SpiceSlideListSlideListRowPrivate * priv;
	SpiceSlide* slide;
};

struct _SpiceSlideListSlideListRowClass {
	GtkListBoxRowClass parent_class;
};

struct _SpiceSlideListSlideListRowPrivate {
	SpiceSlideManager* manager;
	SpiceSlideWidget* slide_widget;
};

struct _Block14Data {
	int _ref_count_;
	SpiceSlideListSlideListRow* self;
	GtkMenu* menu;
};

static gint SpiceSlideList_private_offset;
static gpointer spice_slide_list_parent_class = NULL;
VALA_EXTERN gint spice_slide_list_WIDTH;
gint spice_slide_list_WIDTH = 200;
VALA_EXTERN gint spice_slide_list_HEIGHT;
gint spice_slide_list_HEIGHT = 150;
static gint SpiceSlideListSlideListRow_private_offset;
static gpointer spice_slide_list_slide_list_row_parent_class = NULL;

VALA_EXTERN GType spice_slide_list_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceSlideList, g_object_unref)
VALA_EXTERN GType spice_slide_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceSlideManager, g_object_unref)
VALA_EXTERN SpiceSlideList* spice_slide_list_new (SpiceSlideManager* manager);
VALA_EXTERN SpiceSlideList* spice_slide_list_construct (GType object_type,
                                            SpiceSlideManager* manager);
VALA_EXTERN GType spice_slide_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceSlide, g_object_unref)
static GType spice_slide_list_slide_list_row_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceSlideListSlideListRow, g_object_unref)
static SpiceSlideListSlideListRow* spice_slide_list_add_slide (SpiceSlideList* self,
                                                        SpiceSlide* slide);
VALA_EXTERN SpiceSlideManager* spice_slide_list_get_manager (SpiceSlideList* self);
static SpiceSlideListSlideListRow* spice_slide_list_slide_list_row_new (SpiceSlide* slide,
                                                                 SpiceSlideManager* manager);
static SpiceSlideListSlideListRow* spice_slide_list_slide_list_row_construct (GType object_type,
                                                                       SpiceSlide* slide,
                                                                       SpiceSlideManager* manager);
static void spice_slide_list_set_manager (SpiceSlideList* self,
                                   SpiceSlideManager* value);
VALA_EXTERN GType spice_slide_widget_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceSlideWidget, g_object_unref)
VALA_EXTERN SpiceSlideWidget* spice_slide_widget_new_from_slide (SpiceSlide* slide);
VALA_EXTERN SpiceSlideWidget* spice_slide_widget_construct_from_slide (GType object_type,
                                                           SpiceSlide* slide);
static void __lambda11_ (SpiceSlideListSlideListRow* self);
static void spice_slide_list_slide_list_row_show_rightclick_menu (SpiceSlideListSlideListRow* self);
static void ___lambda11__spice_slide_widget_settings_requested (SpiceSlideWidget* _sender,
                                                         gpointer self);
static void __lambda84_ (SpiceSlideListSlideListRow* self,
                  gboolean val);
static void ___lambda84__spice_slide_visible_changed (SpiceSlide* _sender,
                                               gboolean val,
                                               gpointer self);
VALA_EXTERN void spice_utils_set_style (GtkWidget* widget,
                            const gchar* css);
static Block14Data* block14_data_ref (Block14Data* _data14_);
static void block14_data_unref (void * _userdata_);
static void __lambda12_ (SpiceSlideListSlideListRow* self);
VALA_EXTERN void spice_clipboard_cut (SpiceSlideManager* manager,
                          GObject* object);
static void ___lambda12__gtk_menu_item_activate (GtkMenuItem* _sender,
                                          gpointer self);
static void __lambda77_ (SpiceSlideListSlideListRow* self);
VALA_EXTERN void spice_clipboard_copy (SpiceSlideManager* manager,
                           GObject* object);
static void ___lambda77__gtk_menu_item_activate (GtkMenuItem* _sender,
                                          gpointer self);
static void __lambda78_ (SpiceSlideListSlideListRow* self);
VALA_EXTERN void spice_clipboard_paste (SpiceSlideManager* manager);
static void ___lambda78__gtk_menu_item_activate (GtkMenuItem* _sender,
                                          gpointer self);
static void __lambda79_ (SpiceSlideListSlideListRow* self);
VALA_EXTERN void spice_clipboard_delete (GObject* object);
static void ___lambda79__gtk_menu_item_activate (GtkMenuItem* _sender,
                                          gpointer self);
static void __lambda80_ (SpiceSlideListSlideListRow* self);
VALA_EXTERN void spice_utils_new_slide (SpiceSlideManager* manager);
static void ___lambda80__gtk_menu_item_activate (GtkMenuItem* _sender,
                                          gpointer self);
static void __lambda81_ (SpiceSlideListSlideListRow* self);
VALA_EXTERN void spice_clipboard_duplicate (SpiceSlideManager* manager,
                                GObject* object);
static void ___lambda81__gtk_menu_item_activate (GtkMenuItem* _sender,
                                          gpointer self);
static void __lambda82_ (SpiceSlideListSlideListRow* self);
VALA_EXTERN void spice_slide_manager_set_preview_slide (SpiceSlideManager* self,
                                            SpiceSlide* value);
static void ___lambda82__gtk_menu_item_activate (GtkMenuItem* _sender,
                                          gpointer self);
static void __lambda83_ (Block14Data* _data14_);
static void ___lambda83__gtk_menu_shell_selection_done (GtkMenuShell* _sender,
                                                 gpointer self);
static gboolean spice_slide_list_slide_list_row_real_button_press_event (GtkWidget* base,
                                                                  GdkEventButton* event);
static void spice_slide_list_slide_list_row_finalize (GObject * obj);
static GType spice_slide_list_slide_list_row_get_type_once (void);
static GObject * spice_slide_list_constructor (GType type,
                                        guint n_construct_properties,
                                        GObjectConstructParam * construct_properties);
VALA_EXTERN gchar* spice_utils_get_accel_tooltip (const gchar* action_name,
                                      const gchar* description);
static void _spice_slide_list___lambda85_ (SpiceSlideList* self,
                                    GtkListBoxRow* row);
VALA_EXTERN void spice_slide_manager_set_current_slide (SpiceSlideManager* self,
                                            SpiceSlide* value);
static void __spice_slide_list___lambda85__gtk_list_box_row_selected (GtkListBox* _sender,
                                                               GtkListBoxRow* row,
                                                               gpointer self);
static void _spice_slide_list___lambda86_ (SpiceSlideList* self,
                                    SpiceSlide* slide);
static void __spice_slide_list___lambda86__spice_slide_manager_new_slide_created (SpiceSlideManager* _sender,
                                                                           SpiceSlide* slide,
                                                                           gpointer self);
static void _spice_slide_list___lambda87_ (SpiceSlideList* self);
static void __spice_slide_list___lambda87__spice_slide_manager_slides_sorted (SpiceSlideManager* _sender,
                                                                       gpointer self);
static void _spice_slide_list___lambda88_ (SpiceSlideList* self,
                                    SpiceSlide* selected);
static void __spice_slide_list___lambda88__spice_slide_manager_current_slide_changed (SpiceSlideManager* _sender,
                                                                               SpiceSlide* slide,
                                                                               gpointer self);
static void _spice_slide_list___lambda89_ (SpiceSlideList* self);
static void __spice_slide_list___lambda89__spice_slide_manager_reseted (SpiceSlideManager* _sender,
                                                                 gpointer self);
static gint _spice_slide_list___lambda90_ (SpiceSlideList* self,
                                    GtkListBoxRow* row1,
                                    GtkListBoxRow* row2);
VALA_EXTERN GeeArrayList* spice_slide_manager_get_slides (SpiceSlideManager* self);
static gint __spice_slide_list___lambda90__gtk_list_box_sort_func (GtkListBoxRow* row1,
                                                            GtkListBoxRow* row2,
                                                            gpointer self);
static void _spice_slide_list___lambda91_ (SpiceSlideList* self);
static void __spice_slide_list___lambda91__gtk_button_clicked (GtkButton* _sender,
                                                        gpointer self);
static void spice_slide_list_finalize (GObject * obj);
static GType spice_slide_list_get_type_once (void);
static void _vala_spice_slide_list_get_property (GObject * object,
                                          guint property_id,
                                          GValue * value,
                                          GParamSpec * pspec);
static void _vala_spice_slide_list_set_property (GObject * object,
                                          guint property_id,
                                          const GValue * value,
                                          GParamSpec * pspec);

static inline gpointer
spice_slide_list_get_instance_private (SpiceSlideList* self)
{
	return G_STRUCT_MEMBER_P (self, SpiceSlideList_private_offset);
}

SpiceSlideList*
spice_slide_list_construct (GType object_type,
                            SpiceSlideManager* manager)
{
	SpiceSlideList * self = NULL;
#line 30 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_return_val_if_fail (manager != NULL, NULL);
#line 31 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	self = (SpiceSlideList*) g_object_new (object_type, "manager", manager, NULL);
#line 30 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	return self;
#line 311 "SlideList.c"
}

SpiceSlideList*
spice_slide_list_new (SpiceSlideManager* manager)
{
#line 30 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	return spice_slide_list_construct (SPICE_TYPE_SLIDE_LIST, manager);
#line 319 "SlideList.c"
}

static SpiceSlideListSlideListRow*
spice_slide_list_add_slide (SpiceSlideList* self,
                            SpiceSlide* slide)
{
	SpiceSlideListSlideListRow* slide_row = NULL;
	SpiceSlideManager* _tmp0_;
	SpiceSlideListSlideListRow* _tmp1_;
	GtkStyleContext* _tmp2_;
	GtkListBox* _tmp3_;
	GtkListBox* _tmp4_;
	SpiceSlideListSlideListRow* result;
#line 121 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 121 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_return_val_if_fail (slide != NULL, NULL);
#line 122 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp0_ = self->priv->_manager;
#line 122 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp1_ = spice_slide_list_slide_list_row_new (slide, _tmp0_);
#line 122 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_object_ref_sink (_tmp1_);
#line 122 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	slide_row = _tmp1_;
#line 124 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp2_ = gtk_widget_get_style_context ((GtkWidget*) slide_row);
#line 124 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_style_context_add_class (_tmp2_, "slide");
#line 126 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp3_ = self->priv->slides_list;
#line 126 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_container_add ((GtkContainer*) _tmp3_, (GtkWidget*) slide_row);
#line 127 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp4_ = self->priv->slides_list;
#line 127 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp4_);
#line 129 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	result = slide_row;
#line 129 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	return result;
#line 361 "SlideList.c"
}

SpiceSlideManager*
spice_slide_list_get_manager (SpiceSlideList* self)
{
	SpiceSlideManager* result;
	SpiceSlideManager* _tmp0_;
#line 23 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 23 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp0_ = self->priv->_manager;
#line 23 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	result = _tmp0_;
#line 23 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	return result;
#line 377 "SlideList.c"
}

static void
spice_slide_list_set_manager (SpiceSlideList* self,
                              SpiceSlideManager* value)
{
	SpiceSlideManager* old_value;
#line 23 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_return_if_fail (self != NULL);
#line 23 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	old_value = spice_slide_list_get_manager (self);
#line 23 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	if (old_value != value) {
#line 23 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		self->priv->_manager = value;
#line 23 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		g_object_notify_by_pspec ((GObject *) self, spice_slide_list_properties[SPICE_SLIDE_LIST_MANAGER_PROPERTY]);
#line 395 "SlideList.c"
	}
}

static inline gpointer
spice_slide_list_slide_list_row_get_instance_private (SpiceSlideListSlideListRow* self)
{
	return G_STRUCT_MEMBER_P (self, SpiceSlideListSlideListRow_private_offset);
}

static void
__lambda11_ (SpiceSlideListSlideListRow* self)
{
#line 151 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	spice_slide_list_slide_list_row_show_rightclick_menu (self);
#line 410 "SlideList.c"
}

static void
___lambda11__spice_slide_widget_settings_requested (SpiceSlideWidget* _sender,
                                                    gpointer self)
{
#line 150 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	__lambda11_ ((SpiceSlideListSlideListRow*) self);
#line 419 "SlideList.c"
}

static void
__lambda84_ (SpiceSlideListSlideListRow* self,
             gboolean val)
{
#line 159 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_widget_set_visible ((GtkWidget*) self, val);
#line 160 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_widget_set_no_show_all ((GtkWidget*) self, !val);
#line 162 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 432 "SlideList.c"
}

static void
___lambda84__spice_slide_visible_changed (SpiceSlide* _sender,
                                          gboolean val,
                                          gpointer self)
{
#line 158 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	__lambda84_ ((SpiceSlideListSlideListRow*) self, val);
#line 442 "SlideList.c"
}

static SpiceSlideListSlideListRow*
spice_slide_list_slide_list_row_construct (GType object_type,
                                           SpiceSlide* slide,
                                           SpiceSlideManager* manager)
{
	SpiceSlideListSlideListRow * self = NULL;
	SpiceSlideWidget* _tmp0_;
	SpiceSlideWidget* _tmp1_;
	SpiceSlideWidget* _tmp2_;
#line 144 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_return_val_if_fail (slide != NULL, NULL);
#line 144 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_return_val_if_fail (manager != NULL, NULL);
#line 144 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	self = (SpiceSlideListSlideListRow*) g_object_new (object_type, NULL);
#line 145 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	self->slide = slide;
#line 146 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	self->priv->manager = manager;
#line 148 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp0_ = spice_slide_widget_new_from_slide (slide);
#line 148 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_object_ref_sink (_tmp0_);
#line 148 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_g_object_unref0 (self->priv->slide_widget);
#line 148 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	self->priv->slide_widget = _tmp0_;
#line 150 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp1_ = self->priv->slide_widget;
#line 150 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_signal_connect_object (_tmp1_, "settings-requested", (GCallback) ___lambda11__spice_slide_widget_settings_requested, self, 0);
#line 154 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp2_ = self->priv->slide_widget;
#line 154 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp2_);
#line 156 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_widget_set_size_request ((GtkWidget*) self, spice_slide_list_WIDTH - 24, spice_slide_list_HEIGHT - 24);
#line 158 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_signal_connect_object (slide, "visible-changed", (GCallback) ___lambda84__spice_slide_visible_changed, self, 0);
#line 165 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	spice_utils_set_style ((GtkWidget*) self, SPICE_SLIDE_LIST_SLIDE_LIST_ROW_STYLE_CSS);
#line 144 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	return self;
#line 488 "SlideList.c"
}

static SpiceSlideListSlideListRow*
spice_slide_list_slide_list_row_new (SpiceSlide* slide,
                                     SpiceSlideManager* manager)
{
#line 144 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	return spice_slide_list_slide_list_row_construct (SPICE_SLIDE_LIST_TYPE_SLIDE_LIST_ROW, slide, manager);
#line 497 "SlideList.c"
}

static Block14Data*
block14_data_ref (Block14Data* _data14_)
{
#line 168 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_atomic_int_inc (&_data14_->_ref_count_);
#line 168 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	return _data14_;
#line 507 "SlideList.c"
}

static void
block14_data_unref (void * _userdata_)
{
	Block14Data* _data14_;
	_data14_ = (Block14Data*) _userdata_;
#line 168 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	if (g_atomic_int_dec_and_test (&_data14_->_ref_count_)) {
#line 517 "SlideList.c"
		SpiceSlideListSlideListRow* self;
#line 168 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		self = _data14_->self;
#line 168 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		_g_object_unref0 (_data14_->menu);
#line 168 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		_g_object_unref0 (self);
#line 168 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		g_slice_free (Block14Data, _data14_);
#line 527 "SlideList.c"
	}
}

static void
__lambda12_ (SpiceSlideListSlideListRow* self)
{
	SpiceSlideManager* _tmp0_;
	SpiceSlide* _tmp1_;
#line 182 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp0_ = self->priv->manager;
#line 182 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp1_ = self->slide;
#line 182 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	spice_clipboard_cut (_tmp0_, (GObject*) _tmp1_);
#line 542 "SlideList.c"
}

static void
___lambda12__gtk_menu_item_activate (GtkMenuItem* _sender,
                                     gpointer self)
{
#line 181 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	__lambda12_ ((SpiceSlideListSlideListRow*) self);
#line 551 "SlideList.c"
}

static void
__lambda77_ (SpiceSlideListSlideListRow* self)
{
	SpiceSlideManager* _tmp0_;
	SpiceSlide* _tmp1_;
#line 186 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp0_ = self->priv->manager;
#line 186 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp1_ = self->slide;
#line 186 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	spice_clipboard_copy (_tmp0_, (GObject*) _tmp1_);
#line 565 "SlideList.c"
}

static void
___lambda77__gtk_menu_item_activate (GtkMenuItem* _sender,
                                     gpointer self)
{
#line 185 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	__lambda77_ ((SpiceSlideListSlideListRow*) self);
#line 574 "SlideList.c"
}

static void
__lambda78_ (SpiceSlideListSlideListRow* self)
{
	SpiceSlideManager* _tmp0_;
#line 190 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp0_ = self->priv->manager;
#line 190 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	spice_clipboard_paste (_tmp0_);
#line 585 "SlideList.c"
}

static void
___lambda78__gtk_menu_item_activate (GtkMenuItem* _sender,
                                     gpointer self)
{
#line 189 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	__lambda78_ ((SpiceSlideListSlideListRow*) self);
#line 594 "SlideList.c"
}

static void
__lambda79_ (SpiceSlideListSlideListRow* self)
{
	SpiceSlide* _tmp0_;
#line 194 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp0_ = self->slide;
#line 194 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	spice_clipboard_delete ((GObject*) _tmp0_);
#line 605 "SlideList.c"
}

static void
___lambda79__gtk_menu_item_activate (GtkMenuItem* _sender,
                                     gpointer self)
{
#line 193 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	__lambda79_ ((SpiceSlideListSlideListRow*) self);
#line 614 "SlideList.c"
}

static void
__lambda80_ (SpiceSlideListSlideListRow* self)
{
	SpiceSlideManager* _tmp0_;
#line 198 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp0_ = self->priv->manager;
#line 198 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	spice_utils_new_slide (_tmp0_);
#line 625 "SlideList.c"
}

static void
___lambda80__gtk_menu_item_activate (GtkMenuItem* _sender,
                                     gpointer self)
{
#line 197 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	__lambda80_ ((SpiceSlideListSlideListRow*) self);
#line 634 "SlideList.c"
}

static void
__lambda81_ (SpiceSlideListSlideListRow* self)
{
	SpiceSlideManager* _tmp0_;
	SpiceSlide* _tmp1_;
#line 202 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp0_ = self->priv->manager;
#line 202 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp1_ = self->slide;
#line 202 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	spice_clipboard_duplicate (_tmp0_, (GObject*) _tmp1_);
#line 648 "SlideList.c"
}

static void
___lambda81__gtk_menu_item_activate (GtkMenuItem* _sender,
                                     gpointer self)
{
#line 201 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	__lambda81_ ((SpiceSlideListSlideListRow*) self);
#line 657 "SlideList.c"
}

static void
__lambda82_ (SpiceSlideListSlideListRow* self)
{
	SpiceSlideManager* _tmp0_;
	SpiceSlide* _tmp1_;
#line 206 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp0_ = self->priv->manager;
#line 206 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp1_ = self->slide;
#line 206 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	spice_slide_manager_set_preview_slide (_tmp0_, _tmp1_);
#line 671 "SlideList.c"
}

static void
___lambda82__gtk_menu_item_activate (GtkMenuItem* _sender,
                                     gpointer self)
{
#line 205 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	__lambda82_ ((SpiceSlideListSlideListRow*) self);
#line 680 "SlideList.c"
}

static void
__lambda83_ (Block14Data* _data14_)
{
	SpiceSlideListSlideListRow* self;
#line 222 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	self = _data14_->self;
#line 223 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_menu_detach (_data14_->menu);
#line 224 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_widget_destroy ((GtkWidget*) _data14_->menu);
#line 693 "SlideList.c"
}

static void
___lambda83__gtk_menu_shell_selection_done (GtkMenuShell* _sender,
                                            gpointer self)
{
#line 222 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	__lambda83_ (self);
#line 702 "SlideList.c"
}

static void
spice_slide_list_slide_list_row_show_rightclick_menu (SpiceSlideListSlideListRow* self)
{
	Block14Data* _data14_;
	GtkMenu* _tmp0_;
	GtkMenuItem* cut = NULL;
	GtkMenuItem* _tmp1_;
	GtkMenuItem* copy = NULL;
	GtkMenuItem* _tmp2_;
	GtkMenuItem* paste = NULL;
	GtkMenuItem* _tmp3_;
	GtkMenuItem* delete_slide = NULL;
	GtkMenuItem* _tmp4_;
	GtkMenuItem* new_slide = NULL;
	GtkMenuItem* _tmp5_;
	GtkMenuItem* duplicate_slide = NULL;
	GtkMenuItem* _tmp6_;
	GtkMenuItem* set_as_preview = NULL;
	GtkMenuItem* _tmp7_;
	GtkSeparatorMenuItem* _tmp8_;
	GtkSeparatorMenuItem* _tmp9_;
	GtkSeparatorMenuItem* _tmp10_;
	GtkSeparatorMenuItem* _tmp11_;
#line 168 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_return_if_fail (self != NULL);
#line 168 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_data14_ = g_slice_new0 (Block14Data);
#line 168 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_data14_->_ref_count_ = 1;
#line 168 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_data14_->self = g_object_ref (self);
#line 169 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp0_ = (GtkMenu*) gtk_menu_new ();
#line 169 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_object_ref_sink (_tmp0_);
#line 169 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_data14_->menu = _tmp0_;
#line 171 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp1_ = (GtkMenuItem*) gtk_menu_item_new_with_label (_ ("Cut"));
#line 171 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_object_ref_sink (_tmp1_);
#line 171 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	cut = _tmp1_;
#line 172 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp2_ = (GtkMenuItem*) gtk_menu_item_new_with_label (_ ("Copy"));
#line 172 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_object_ref_sink (_tmp2_);
#line 172 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	copy = _tmp2_;
#line 173 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp3_ = (GtkMenuItem*) gtk_menu_item_new_with_label (_ ("Paste"));
#line 173 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_object_ref_sink (_tmp3_);
#line 173 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	paste = _tmp3_;
#line 174 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp4_ = (GtkMenuItem*) gtk_menu_item_new_with_label (_ ("Delete"));
#line 174 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_object_ref_sink (_tmp4_);
#line 174 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	delete_slide = _tmp4_;
#line 176 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp5_ = (GtkMenuItem*) gtk_menu_item_new_with_label (_ ("New Slide"));
#line 176 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_object_ref_sink (_tmp5_);
#line 176 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	new_slide = _tmp5_;
#line 178 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp6_ = (GtkMenuItem*) gtk_menu_item_new_with_label (_ ("Duplicate Slide"));
#line 178 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_object_ref_sink (_tmp6_);
#line 178 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	duplicate_slide = _tmp6_;
#line 179 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp7_ = (GtkMenuItem*) gtk_menu_item_new_with_label (_ ("Set as File Preview"));
#line 179 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_object_ref_sink (_tmp7_);
#line 179 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	set_as_preview = _tmp7_;
#line 181 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_signal_connect_object (cut, "activate", (GCallback) ___lambda12__gtk_menu_item_activate, self, 0);
#line 185 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_signal_connect_object (copy, "activate", (GCallback) ___lambda77__gtk_menu_item_activate, self, 0);
#line 189 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_signal_connect_object (paste, "activate", (GCallback) ___lambda78__gtk_menu_item_activate, self, 0);
#line 193 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_signal_connect_object (delete_slide, "activate", (GCallback) ___lambda79__gtk_menu_item_activate, self, 0);
#line 197 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_signal_connect_object (new_slide, "activate", (GCallback) ___lambda80__gtk_menu_item_activate, self, 0);
#line 201 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_signal_connect_object (duplicate_slide, "activate", (GCallback) ___lambda81__gtk_menu_item_activate, self, 0);
#line 205 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_signal_connect_object (set_as_preview, "activate", (GCallback) ___lambda82__gtk_menu_item_activate, self, 0);
#line 209 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_container_add ((GtkContainer*) _data14_->menu, (GtkWidget*) cut);
#line 210 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_container_add ((GtkContainer*) _data14_->menu, (GtkWidget*) copy);
#line 211 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_container_add ((GtkContainer*) _data14_->menu, (GtkWidget*) paste);
#line 212 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_container_add ((GtkContainer*) _data14_->menu, (GtkWidget*) delete_slide);
#line 213 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp8_ = (GtkSeparatorMenuItem*) gtk_separator_menu_item_new ();
#line 213 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_object_ref_sink (_tmp8_);
#line 213 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp9_ = _tmp8_;
#line 213 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_container_add ((GtkContainer*) _data14_->menu, (GtkWidget*) _tmp9_);
#line 213 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_g_object_unref0 (_tmp9_);
#line 214 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_container_add ((GtkContainer*) _data14_->menu, (GtkWidget*) new_slide);
#line 215 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_container_add ((GtkContainer*) _data14_->menu, (GtkWidget*) duplicate_slide);
#line 216 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp10_ = (GtkSeparatorMenuItem*) gtk_separator_menu_item_new ();
#line 216 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_object_ref_sink (_tmp10_);
#line 216 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp11_ = _tmp10_;
#line 216 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_container_add ((GtkContainer*) _data14_->menu, (GtkWidget*) _tmp11_);
#line 216 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_g_object_unref0 (_tmp11_);
#line 217 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_container_add ((GtkContainer*) _data14_->menu, (GtkWidget*) set_as_preview);
#line 219 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_menu_attach_to_widget (_data14_->menu, (GtkWidget*) self, NULL);
#line 220 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_widget_show_all ((GtkWidget*) _data14_->menu);
#line 222 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_signal_connect_data ((GtkMenuShell*) _data14_->menu, "selection-done", (GCallback) ___lambda83__gtk_menu_shell_selection_done, block14_data_ref (_data14_), (GClosureNotify) block14_data_unref, 0);
#line 227 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_menu_popup_at_widget (_data14_->menu, (GtkWidget*) self, GDK_GRAVITY_CENTER, GDK_GRAVITY_CENTER, NULL);
#line 168 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_g_object_unref0 (set_as_preview);
#line 168 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_g_object_unref0 (duplicate_slide);
#line 168 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_g_object_unref0 (new_slide);
#line 168 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_g_object_unref0 (delete_slide);
#line 168 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_g_object_unref0 (paste);
#line 168 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_g_object_unref0 (copy);
#line 168 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_g_object_unref0 (cut);
#line 168 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	block14_data_unref (_data14_);
#line 168 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_data14_ = NULL;
#line 858 "SlideList.c"
}

static gboolean
spice_slide_list_slide_list_row_real_button_press_event (GtkWidget* base,
                                                         GdkEventButton* event)
{
	SpiceSlideListSlideListRow * self;
	gboolean result;
#line 230 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	self = (SpiceSlideListSlideListRow*) base;
#line 230 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 231 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_signal_emit_by_name ((GtkListBoxRow*) self, "activate");
#line 233 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	if (event->button == ((guint) 3)) {
#line 234 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		spice_slide_list_slide_list_row_show_rightclick_menu (self);
#line 877 "SlideList.c"
	}
#line 237 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	result = FALSE;
#line 237 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	return result;
#line 883 "SlideList.c"
}

static void
spice_slide_list_slide_list_row_class_init (SpiceSlideListSlideListRowClass * klass,
                                            gpointer klass_data)
{
#line 132 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	spice_slide_list_slide_list_row_parent_class = g_type_class_peek_parent (klass);
#line 132 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_type_class_adjust_private_offset (klass, &SpiceSlideListSlideListRow_private_offset);
#line 132 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	((GtkWidgetClass *) klass)->button_press_event = (gboolean (*) (GtkWidget*, GdkEventButton*)) spice_slide_list_slide_list_row_real_button_press_event;
#line 132 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	G_OBJECT_CLASS (klass)->finalize = spice_slide_list_slide_list_row_finalize;
#line 898 "SlideList.c"
}

static void
spice_slide_list_slide_list_row_instance_init (SpiceSlideListSlideListRow * self,
                                               gpointer klass)
{
#line 132 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	self->priv = spice_slide_list_slide_list_row_get_instance_private (self);
#line 907 "SlideList.c"
}

static void
spice_slide_list_slide_list_row_finalize (GObject * obj)
{
	SpiceSlideListSlideListRow * self;
#line 132 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPICE_SLIDE_LIST_TYPE_SLIDE_LIST_ROW, SpiceSlideListSlideListRow);
#line 136 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_g_object_unref0 (self->priv->slide_widget);
#line 132 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	G_OBJECT_CLASS (spice_slide_list_slide_list_row_parent_class)->finalize (obj);
#line 920 "SlideList.c"
}

static GType
spice_slide_list_slide_list_row_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (SpiceSlideListSlideListRowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spice_slide_list_slide_list_row_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpiceSlideListSlideListRow), 0, (GInstanceInitFunc) spice_slide_list_slide_list_row_instance_init, NULL };
	GType spice_slide_list_slide_list_row_type_id;
	spice_slide_list_slide_list_row_type_id = g_type_register_static (gtk_list_box_row_get_type (), "SpiceSlideListSlideListRow", &g_define_type_info, 0);
	SpiceSlideListSlideListRow_private_offset = g_type_add_instance_private (spice_slide_list_slide_list_row_type_id, sizeof (SpiceSlideListSlideListRowPrivate));
	return spice_slide_list_slide_list_row_type_id;
}

static GType
spice_slide_list_slide_list_row_get_type (void)
{
	static volatile gsize spice_slide_list_slide_list_row_type_id__once = 0;
	if (g_once_init_enter (&spice_slide_list_slide_list_row_type_id__once)) {
		GType spice_slide_list_slide_list_row_type_id;
		spice_slide_list_slide_list_row_type_id = spice_slide_list_slide_list_row_get_type_once ();
		g_once_init_leave (&spice_slide_list_slide_list_row_type_id__once, spice_slide_list_slide_list_row_type_id);
	}
	return spice_slide_list_slide_list_row_type_id__once;
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 72 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	return self ? g_object_ref (self) : NULL;
#line 950 "SlideList.c"
}

static void
_spice_slide_list___lambda85_ (SpiceSlideList* self,
                               GtkListBoxRow* row)
{
#line 71 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	if (SPICE_SLIDE_LIST_IS_SLIDE_LIST_ROW (row)) {
#line 959 "SlideList.c"
		SpiceSlideListSlideListRow* slide = NULL;
		SpiceSlideListSlideListRow* _tmp0_;
		SpiceSlideManager* _tmp1_;
		SpiceSlideListSlideListRow* _tmp2_;
		SpiceSlide* _tmp3_;
#line 72 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		_tmp0_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (row, SPICE_SLIDE_LIST_TYPE_SLIDE_LIST_ROW, SpiceSlideListSlideListRow));
#line 72 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		slide = _tmp0_;
#line 73 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		_tmp1_ = self->priv->_manager;
#line 73 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		_tmp2_ = slide;
#line 73 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		_tmp3_ = _tmp2_->slide;
#line 73 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		spice_slide_manager_set_current_slide (_tmp1_, _tmp3_);
#line 71 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		_g_object_unref0 (slide);
#line 979 "SlideList.c"
	}
}

static void
__spice_slide_list___lambda85__gtk_list_box_row_selected (GtkListBox* _sender,
                                                          GtkListBoxRow* row,
                                                          gpointer self)
{
#line 70 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_spice_slide_list___lambda85_ ((SpiceSlideList*) self, row);
#line 990 "SlideList.c"
}

static void
_spice_slide_list___lambda86_ (SpiceSlideList* self,
                               SpiceSlide* slide)
{
	SpiceSlideListSlideListRow* _tmp0_;
	SpiceSlideListSlideListRow* _tmp1_;
#line 77 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_return_if_fail (slide != NULL);
#line 78 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp0_ = spice_slide_list_add_slide (self, slide);
#line 78 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp1_ = _tmp0_;
#line 78 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_g_object_unref0 (_tmp1_);
#line 1007 "SlideList.c"
}

static void
__spice_slide_list___lambda86__spice_slide_manager_new_slide_created (SpiceSlideManager* _sender,
                                                                      SpiceSlide* slide,
                                                                      gpointer self)
{
#line 77 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_spice_slide_list___lambda86_ ((SpiceSlideList*) self, slide);
#line 1017 "SlideList.c"
}

static void
_spice_slide_list___lambda87_ (SpiceSlideList* self)
{
	GtkListBox* _tmp0_;
#line 82 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp0_ = self->priv->slides_list;
#line 82 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_list_box_invalidate_sort (_tmp0_);
#line 1028 "SlideList.c"
}

static void
__spice_slide_list___lambda87__spice_slide_manager_slides_sorted (SpiceSlideManager* _sender,
                                                                  gpointer self)
{
#line 81 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_spice_slide_list___lambda87_ ((SpiceSlideList*) self);
#line 1037 "SlideList.c"
}

static void
_spice_slide_list___lambda88_ (SpiceSlideList* self,
                               SpiceSlide* selected)
{
	GtkListBox* _tmp0_;
	GList* _tmp1_;
#line 85 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_return_if_fail (selected != NULL);
#line 86 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp0_ = self->priv->slides_list;
#line 86 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp1_ = gtk_container_get_children ((GtkContainer*) _tmp0_);
#line 1052 "SlideList.c"
	{
		GList* row_collection = NULL;
		GList* row_it = NULL;
#line 86 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		row_collection = _tmp1_;
#line 86 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		for (row_it = row_collection; row_it != NULL; row_it = row_it->next) {
#line 1060 "SlideList.c"
			GtkWidget* row = NULL;
#line 86 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
			row = (GtkWidget*) row_it->data;
#line 1064 "SlideList.c"
			{
				GtkWidget* _tmp2_;
#line 87 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
				_tmp2_ = row;
#line 87 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
				if (SPICE_SLIDE_LIST_IS_SLIDE_LIST_ROW (_tmp2_)) {
#line 1071 "SlideList.c"
					SpiceSlideListSlideListRow* preview = NULL;
					GtkWidget* _tmp3_;
					SpiceSlideListSlideListRow* _tmp4_;
					SpiceSlideListSlideListRow* _tmp5_;
					SpiceSlide* _tmp6_;
#line 88 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
					_tmp3_ = row;
#line 88 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
					_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, SPICE_SLIDE_LIST_TYPE_SLIDE_LIST_ROW, SpiceSlideListSlideListRow));
#line 88 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
					preview = _tmp4_;
#line 89 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
					_tmp5_ = preview;
#line 89 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
					_tmp6_ = _tmp5_->slide;
#line 89 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
					if (_tmp6_ == selected) {
#line 1089 "SlideList.c"
						GtkListBox* _tmp7_;
						SpiceSlideListSlideListRow* _tmp8_;
#line 90 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
						_tmp7_ = self->priv->slides_list;
#line 90 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
						_tmp8_ = preview;
#line 90 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
						gtk_list_box_select_row (_tmp7_, (GtkListBoxRow*) _tmp8_);
#line 91 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
						_g_object_unref0 (preview);
#line 91 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
						break;
#line 1102 "SlideList.c"
					}
#line 87 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
					_g_object_unref0 (preview);
#line 1106 "SlideList.c"
				}
			}
		}
#line 86 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		(row_collection == NULL) ? NULL : (row_collection = (g_list_free (row_collection), NULL));
#line 1112 "SlideList.c"
	}
}

static void
__spice_slide_list___lambda88__spice_slide_manager_current_slide_changed (SpiceSlideManager* _sender,
                                                                          SpiceSlide* slide,
                                                                          gpointer self)
{
#line 85 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_spice_slide_list___lambda88_ ((SpiceSlideList*) self, slide);
#line 1123 "SlideList.c"
}

static void
_spice_slide_list___lambda89_ (SpiceSlideList* self)
{
	GtkListBox* _tmp0_;
	GList* _tmp1_;
#line 98 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp0_ = self->priv->slides_list;
#line 98 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp1_ = gtk_container_get_children ((GtkContainer*) _tmp0_);
#line 1135 "SlideList.c"
	{
		GList* row_collection = NULL;
		GList* row_it = NULL;
#line 98 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		row_collection = _tmp1_;
#line 98 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		for (row_it = row_collection; row_it != NULL; row_it = row_it->next) {
#line 1143 "SlideList.c"
			GtkWidget* row = NULL;
#line 98 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
			row = (GtkWidget*) row_it->data;
#line 1147 "SlideList.c"
			{
				GtkWidget* _tmp2_;
#line 99 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
				_tmp2_ = row;
#line 99 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
				gtk_widget_destroy (_tmp2_);
#line 1154 "SlideList.c"
			}
		}
#line 98 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		(row_collection == NULL) ? NULL : (row_collection = (g_list_free (row_collection), NULL));
#line 1159 "SlideList.c"
	}
}

static void
__spice_slide_list___lambda89__spice_slide_manager_reseted (SpiceSlideManager* _sender,
                                                            gpointer self)
{
#line 97 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_spice_slide_list___lambda89_ ((SpiceSlideList*) self);
#line 1169 "SlideList.c"
}

static gint
_spice_slide_list___lambda90_ (SpiceSlideList* self,
                               GtkListBoxRow* row1,
                               GtkListBoxRow* row2)
{
	gint slide1 = 0;
	SpiceSlideManager* _tmp0_;
	GeeArrayList* _tmp1_;
	GeeArrayList* _tmp2_;
	SpiceSlide* _tmp3_;
	gint slide2 = 0;
	SpiceSlideManager* _tmp4_;
	GeeArrayList* _tmp5_;
	GeeArrayList* _tmp6_;
	SpiceSlide* _tmp7_;
	gint result;
#line 103 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_return_val_if_fail (row1 != NULL, 0);
#line 103 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_return_val_if_fail (row2 != NULL, 0);
#line 104 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp0_ = self->priv->_manager;
#line 104 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp1_ = spice_slide_manager_get_slides (_tmp0_);
#line 104 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp2_ = _tmp1_;
#line 104 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_CAST (row1, SPICE_SLIDE_LIST_TYPE_SLIDE_LIST_ROW, SpiceSlideListSlideListRow)->slide;
#line 104 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	slide1 = gee_abstract_list_index_of ((GeeAbstractList*) _tmp2_, _tmp3_);
#line 105 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp4_ = self->priv->_manager;
#line 105 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp5_ = spice_slide_manager_get_slides (_tmp4_);
#line 105 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp6_ = _tmp5_;
#line 105 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp7_ = G_TYPE_CHECK_INSTANCE_CAST (row2, SPICE_SLIDE_LIST_TYPE_SLIDE_LIST_ROW, SpiceSlideListSlideListRow)->slide;
#line 105 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	slide2 = gee_abstract_list_index_of ((GeeAbstractList*) _tmp6_, _tmp7_);
#line 107 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	if (slide1 < slide2) {
#line 107 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		result = -1;
#line 107 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		return result;
#line 1218 "SlideList.c"
	} else {
#line 108 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		if (slide2 < slide1) {
#line 108 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
			result = 1;
#line 108 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
			return result;
#line 1226 "SlideList.c"
		} else {
#line 109 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
			result = 0;
#line 109 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
			return result;
#line 1232 "SlideList.c"
		}
	}
}

static gint
__spice_slide_list___lambda90__gtk_list_box_sort_func (GtkListBoxRow* row1,
                                                       GtkListBoxRow* row2,
                                                       gpointer self)
{
	gint result;
	result = _spice_slide_list___lambda90_ ((SpiceSlideList*) self, row1, row2);
#line 103 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	return result;
#line 1246 "SlideList.c"
}

static void
_spice_slide_list___lambda91_ (SpiceSlideList* self)
{
	SpiceSlideManager* _tmp0_;
#line 113 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp0_ = self->priv->_manager;
#line 113 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	spice_utils_new_slide (_tmp0_);
#line 1257 "SlideList.c"
}

static void
__spice_slide_list___lambda91__gtk_button_clicked (GtkButton* _sender,
                                                   gpointer self)
{
#line 112 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_spice_slide_list___lambda91_ ((SpiceSlideList*) self);
#line 1266 "SlideList.c"
}

static GObject *
spice_slide_list_constructor (GType type,
                              guint n_construct_properties,
                              GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	SpiceSlideList * self;
	GtkStyleContext* _tmp0_;
	GtkListBox* _tmp1_ = NULL;
	GtkScrolledWindow* scrollbox = NULL;
	GtkScrolledWindow* _tmp2_ = NULL;
	GtkScrolledWindow* _tmp3_;
	GtkListBox* _tmp4_;
	GtkButton* new_slide_button = NULL;
	GtkImage* _tmp5_;
	gchar* _tmp6_;
	GtkButton* _tmp7_ = NULL;
	GtkButton* _tmp8_;
	GtkStyleContext* _tmp9_;
	GtkActionBar* actionbar = NULL;
	GtkActionBar* _tmp10_;
	GtkActionBar* _tmp11_;
	GtkStyleContext* _tmp12_;
	GtkActionBar* _tmp13_;
	GtkButton* _tmp14_;
	GtkScrolledWindow* _tmp15_;
	GtkActionBar* _tmp16_;
	GtkListBox* _tmp17_;
	SpiceSlideManager* _tmp18_;
	SpiceSlideManager* _tmp19_;
	SpiceSlideManager* _tmp20_;
	SpiceSlideManager* _tmp21_;
	GtkListBox* _tmp22_;
	GtkButton* _tmp23_;
#line 34 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	parent_class = G_OBJECT_CLASS (spice_slide_list_parent_class);
#line 34 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 34 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPICE_TYPE_SLIDE_LIST, SpiceSlideList);
#line 35 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_orientable_set_orientation ((GtkOrientable*) self, GTK_ORIENTATION_VERTICAL);
#line 36 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp0_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 36 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_style_context_add_class (_tmp0_, "slide-list");
#line 38 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp1_ = (GtkListBox*) gtk_list_box_new ();
#line 38 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_widget_set_vexpand ((GtkWidget*) _tmp1_, TRUE);
#line 38 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_object_ref_sink (_tmp1_);
#line 38 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_g_object_unref0 (self->priv->slides_list);
#line 38 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	self->priv->slides_list = _tmp1_;
#line 42 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp2_ = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
#line 42 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_object_set (_tmp2_, "hscrollbar-policy", GTK_POLICY_NEVER, NULL);
#line 42 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_object_ref_sink (_tmp2_);
#line 42 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	scrollbox = _tmp2_;
#line 45 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp3_ = scrollbox;
#line 45 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp4_ = self->priv->slides_list;
#line 45 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_container_add ((GtkContainer*) _tmp3_, (GtkWidget*) _tmp4_);
#line 47 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp5_ = (GtkImage*) gtk_image_new_from_icon_name ("list-add-symbolic", (GtkIconSize) GTK_ICON_SIZE_MENU);
#line 47 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_object_ref_sink (_tmp5_);
#line 47 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp6_ = spice_utils_get_accel_tooltip (SPICE_WINDOW_ACTION_NEW_SLIDE, "");
#line 47 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp7_ = (GtkButton*) gtk_button_new_with_label (_ ("Add a Slide"));
#line 47 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_button_set_always_show_image (_tmp7_, TRUE);
#line 47 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_widget_set_margin_top ((GtkWidget*) _tmp7_, 3);
#line 47 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp7_, 3);
#line 47 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_widget_set_hexpand ((GtkWidget*) _tmp7_, TRUE);
#line 47 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_button_set_image (_tmp7_, (GtkWidget*) _tmp5_);
#line 47 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_g_object_unref0 (_tmp5_);
#line 47 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_widget_set_tooltip_markup ((GtkWidget*) _tmp7_, _tmp6_);
#line 47 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_g_free0 (_tmp6_);
#line 47 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_object_set (_tmp7_, "xalign", (gfloat) 0, NULL);
#line 47 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_object_ref_sink (_tmp7_);
#line 47 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	new_slide_button = _tmp7_;
#line 57 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp8_ = new_slide_button;
#line 57 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp9_ = gtk_widget_get_style_context ((GtkWidget*) _tmp8_);
#line 57 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_style_context_add_class (_tmp9_, GTK_STYLE_CLASS_FLAT);
#line 59 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp10_ = (GtkActionBar*) gtk_action_bar_new ();
#line 59 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_object_ref_sink (_tmp10_);
#line 59 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	actionbar = _tmp10_;
#line 60 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp11_ = actionbar;
#line 60 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp12_ = gtk_widget_get_style_context ((GtkWidget*) _tmp11_);
#line 60 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_style_context_add_class (_tmp12_, GTK_STYLE_CLASS_FLAT);
#line 61 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp13_ = actionbar;
#line 61 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp14_ = new_slide_button;
#line 61 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_container_add ((GtkContainer*) _tmp13_, (GtkWidget*) _tmp14_);
#line 63 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp15_ = scrollbox;
#line 63 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp15_);
#line 64 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp16_ = actionbar;
#line 64 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp16_);
#line 68 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_widget_set_hexpand ((GtkWidget*) self, FALSE);
#line 70 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp17_ = self->priv->slides_list;
#line 70 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_signal_connect_object (_tmp17_, "row-selected", (GCallback) __spice_slide_list___lambda85__gtk_list_box_row_selected, self, 0);
#line 77 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp18_ = self->priv->_manager;
#line 77 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_signal_connect_object (_tmp18_, "new-slide-created", (GCallback) __spice_slide_list___lambda86__spice_slide_manager_new_slide_created, self, 0);
#line 81 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp19_ = self->priv->_manager;
#line 81 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_signal_connect_object (_tmp19_, "slides-sorted", (GCallback) __spice_slide_list___lambda87__spice_slide_manager_slides_sorted, self, 0);
#line 85 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp20_ = self->priv->_manager;
#line 85 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_signal_connect_object (_tmp20_, "current-slide-changed", (GCallback) __spice_slide_list___lambda88__spice_slide_manager_current_slide_changed, self, 0);
#line 97 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp21_ = self->priv->_manager;
#line 97 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_signal_connect_object (_tmp21_, "reseted", (GCallback) __spice_slide_list___lambda89__spice_slide_manager_reseted, self, 0);
#line 103 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp22_ = self->priv->slides_list;
#line 103 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	gtk_list_box_set_sort_func (_tmp22_, __spice_slide_list___lambda90__gtk_list_box_sort_func, g_object_ref (self), g_object_unref);
#line 112 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_tmp23_ = new_slide_button;
#line 112 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_signal_connect_object (_tmp23_, "clicked", (GCallback) __spice_slide_list___lambda91__gtk_button_clicked, self, 0);
#line 1432 "SlideList.c"
	{
		GeeArrayList* _slide_list = NULL;
		SpiceSlideManager* _tmp24_;
		GeeArrayList* _tmp25_;
		GeeArrayList* _tmp26_;
		gint _slide_size = 0;
		GeeArrayList* _tmp27_;
		gint _tmp28_;
		gint _tmp29_;
		gint _slide_index = 0;
#line 116 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		_tmp24_ = self->priv->_manager;
#line 116 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		_tmp25_ = spice_slide_manager_get_slides (_tmp24_);
#line 116 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		_tmp26_ = _tmp25_;
#line 116 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		_slide_list = _tmp26_;
#line 116 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		_tmp27_ = _slide_list;
#line 116 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		_tmp28_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp27_);
#line 116 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		_tmp29_ = _tmp28_;
#line 116 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		_slide_size = _tmp29_;
#line 116 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		_slide_index = -1;
#line 116 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		while (TRUE) {
#line 1463 "SlideList.c"
			gint _tmp30_;
			gint _tmp31_;
			SpiceSlide* slide = NULL;
			GeeArrayList* _tmp32_;
			gpointer _tmp33_;
			SpiceSlide* _tmp34_;
			SpiceSlideListSlideListRow* _tmp35_;
			SpiceSlideListSlideListRow* _tmp36_;
#line 116 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
			_slide_index = _slide_index + 1;
#line 116 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
			_tmp30_ = _slide_index;
#line 116 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
			_tmp31_ = _slide_size;
#line 116 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
			if (!(_tmp30_ < _tmp31_)) {
#line 116 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
				break;
#line 1482 "SlideList.c"
			}
#line 116 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
			_tmp32_ = _slide_list;
#line 116 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
			_tmp33_ = gee_abstract_list_get ((GeeAbstractList*) _tmp32_, _slide_index);
#line 116 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
			slide = (SpiceSlide*) _tmp33_;
#line 117 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
			_tmp34_ = slide;
#line 117 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
			_tmp35_ = spice_slide_list_add_slide (self, _tmp34_);
#line 117 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
			_tmp36_ = _tmp35_;
#line 117 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
			_g_object_unref0 (_tmp36_);
#line 116 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
			_g_object_unref0 (slide);
#line 1500 "SlideList.c"
		}
	}
#line 34 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_g_object_unref0 (actionbar);
#line 34 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_g_object_unref0 (new_slide_button);
#line 34 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_g_object_unref0 (scrollbox);
#line 34 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	return obj;
#line 1511 "SlideList.c"
}

static void
spice_slide_list_class_init (SpiceSlideListClass * klass,
                             gpointer klass_data)
{
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	spice_slide_list_parent_class = g_type_class_peek_parent (klass);
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_type_class_adjust_private_offset (klass, &SpiceSlideList_private_offset);
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_spice_slide_list_get_property;
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_spice_slide_list_set_property;
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	G_OBJECT_CLASS (klass)->constructor = spice_slide_list_constructor;
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	G_OBJECT_CLASS (klass)->finalize = spice_slide_list_finalize;
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SPICE_SLIDE_LIST_MANAGER_PROPERTY, spice_slide_list_properties[SPICE_SLIDE_LIST_MANAGER_PROPERTY] = g_param_spec_object ("manager", "manager", "manager", SPICE_TYPE_SLIDE_MANAGER, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 1532 "SlideList.c"
}

static void
spice_slide_list_instance_init (SpiceSlideList * self,
                                gpointer klass)
{
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	self->priv = spice_slide_list_get_instance_private (self);
#line 1541 "SlideList.c"
}

static void
spice_slide_list_finalize (GObject * obj)
{
	SpiceSlideList * self;
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPICE_TYPE_SLIDE_LIST, SpiceSlideList);
#line 28 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	_g_object_unref0 (self->priv->slides_list);
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	G_OBJECT_CLASS (spice_slide_list_parent_class)->finalize (obj);
#line 1554 "SlideList.c"
}

static GType
spice_slide_list_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (SpiceSlideListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spice_slide_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpiceSlideList), 0, (GInstanceInitFunc) spice_slide_list_instance_init, NULL };
	GType spice_slide_list_type_id;
	spice_slide_list_type_id = g_type_register_static (gtk_grid_get_type (), "SpiceSlideList", &g_define_type_info, 0);
	SpiceSlideList_private_offset = g_type_add_instance_private (spice_slide_list_type_id, sizeof (SpiceSlideListPrivate));
	return spice_slide_list_type_id;
}

GType
spice_slide_list_get_type (void)
{
	static volatile gsize spice_slide_list_type_id__once = 0;
	if (g_once_init_enter (&spice_slide_list_type_id__once)) {
		GType spice_slide_list_type_id;
		spice_slide_list_type_id = spice_slide_list_get_type_once ();
		g_once_init_leave (&spice_slide_list_type_id__once, spice_slide_list_type_id);
	}
	return spice_slide_list_type_id__once;
}

static void
_vala_spice_slide_list_get_property (GObject * object,
                                     guint property_id,
                                     GValue * value,
                                     GParamSpec * pspec)
{
	SpiceSlideList * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SPICE_TYPE_SLIDE_LIST, SpiceSlideList);
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	switch (property_id) {
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		case SPICE_SLIDE_LIST_MANAGER_PROPERTY:
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		g_value_set_object (value, spice_slide_list_get_manager (self));
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		break;
#line 1595 "SlideList.c"
		default:
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		break;
#line 1601 "SlideList.c"
	}
}

static void
_vala_spice_slide_list_set_property (GObject * object,
                                     guint property_id,
                                     const GValue * value,
                                     GParamSpec * pspec)
{
	SpiceSlideList * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SPICE_TYPE_SLIDE_LIST, SpiceSlideList);
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
	switch (property_id) {
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		case SPICE_SLIDE_LIST_MANAGER_PROPERTY:
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		spice_slide_list_set_manager (self, g_value_get_object (value));
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		break;
#line 1621 "SlideList.c"
		default:
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 22 "../Spice-up-1.9.1/src/Widgets/SlideList.vala"
		break;
#line 1627 "SlideList.c"
	}
}

