/* input-type.c generated by valac 0.56.18, the Vala compiler
 * generated from input-type.vala, do not modify */

/*
 * Copyright 2016 Megh Parikh
 *
 * This file is part of LibGamepad.
 *
 * LibGamepad is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * LibGamepad is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib-object.h>
#include <glib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

typedef enum  {
	LIB_GAMEPAD_INPUT_TYPE_AXIS,
	LIB_GAMEPAD_INPUT_TYPE_BUTTON,
	LIB_GAMEPAD_INPUT_TYPE_INVALID
} LibGamepadInputType;

#define LIB_GAMEPAD_TYPE_INPUT_TYPE (lib_gamepad_input_type_get_type ())

VALA_EXTERN GType lib_gamepad_input_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint lib_gamepad_input_type_length (void);

guint
lib_gamepad_input_type_length (void)
{
	guint result;
#line 26 "../Spice-up-1.9.1/src/Services/libgamepad/input-type.vala"
	result = (guint) (LIB_GAMEPAD_INPUT_TYPE_INVALID + 1);
#line 26 "../Spice-up-1.9.1/src/Services/libgamepad/input-type.vala"
	return result;
#line 64 "input-type.c"
}

static GType
lib_gamepad_input_type_get_type_once (void)
{
	static const GEnumValue values[] = {{LIB_GAMEPAD_INPUT_TYPE_AXIS, "LIB_GAMEPAD_INPUT_TYPE_AXIS", "axis"}, {LIB_GAMEPAD_INPUT_TYPE_BUTTON, "LIB_GAMEPAD_INPUT_TYPE_BUTTON", "button"}, {LIB_GAMEPAD_INPUT_TYPE_INVALID, "LIB_GAMEPAD_INPUT_TYPE_INVALID", "invalid"}, {0, NULL, NULL}};
	GType lib_gamepad_input_type_type_id;
	lib_gamepad_input_type_type_id = g_enum_register_static ("LibGamepadInputType", values);
	return lib_gamepad_input_type_type_id;
}

GType
lib_gamepad_input_type_get_type (void)
{
	static volatile gsize lib_gamepad_input_type_type_id__once = 0;
	if (g_once_init_enter (&lib_gamepad_input_type_type_id__once)) {
		GType lib_gamepad_input_type_type_id;
		lib_gamepad_input_type_type_id = lib_gamepad_input_type_get_type_once ();
		g_once_init_leave (&lib_gamepad_input_type_type_id__once, lib_gamepad_input_type_type_id);
	}
	return lib_gamepad_input_type_type_id__once;
}

