/* ShapeBar.c generated by valac 0.56.18, the Vala compiler
 * generated from ShapeBar.vala, do not modify */

/*
* Copyright (c) 2016 Felipe Escoto (https://github.com/Philip-Scott/Spice-up)
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the
* Free Software Foundation, Inc., 59 Temple Place - Suite 330,
* Boston, MA 02111-1307, USA.
*
* Authored by: Felipe Escoto <felescoto95@hotmail.com>
*/

#include <gtk/gtk.h>
#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <float.h>
#include <math.h>
#include <glib/gi18n-lib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define SPICE_WIDGETS_TYPE_TOOLBAR (spice_widgets_toolbar_get_type ())
#define SPICE_WIDGETS_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_WIDGETS_TYPE_TOOLBAR, SpiceWidgetsToolbar))
#define SPICE_WIDGETS_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_WIDGETS_TYPE_TOOLBAR, SpiceWidgetsToolbarClass))
#define SPICE_WIDGETS_IS_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_WIDGETS_TYPE_TOOLBAR))
#define SPICE_WIDGETS_IS_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_WIDGETS_TYPE_TOOLBAR))
#define SPICE_WIDGETS_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_WIDGETS_TYPE_TOOLBAR, SpiceWidgetsToolbarClass))

typedef struct _SpiceWidgetsToolbar SpiceWidgetsToolbar;
typedef struct _SpiceWidgetsToolbarClass SpiceWidgetsToolbarClass;
typedef struct _SpiceWidgetsToolbarPrivate SpiceWidgetsToolbarPrivate;

#define SPICE_TYPE_CANVAS_ITEM (spice_canvas_item_get_type ())
#define SPICE_CANVAS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_CANVAS_ITEM, SpiceCanvasItem))
#define SPICE_CANVAS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_CANVAS_ITEM, SpiceCanvasItemClass))
#define SPICE_IS_CANVAS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_CANVAS_ITEM))
#define SPICE_IS_CANVAS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_CANVAS_ITEM))
#define SPICE_CANVAS_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_CANVAS_ITEM, SpiceCanvasItemClass))

typedef struct _SpiceCanvasItem SpiceCanvasItem;
typedef struct _SpiceCanvasItemClass SpiceCanvasItemClass;

#define SPICE_WIDGETS_TYPE_SHAPE_TOOLBAR (spice_widgets_shape_toolbar_get_type ())
#define SPICE_WIDGETS_SHAPE_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_WIDGETS_TYPE_SHAPE_TOOLBAR, SpiceWidgetsShapeToolbar))
#define SPICE_WIDGETS_SHAPE_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_WIDGETS_TYPE_SHAPE_TOOLBAR, SpiceWidgetsShapeToolbarClass))
#define SPICE_WIDGETS_IS_SHAPE_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_WIDGETS_TYPE_SHAPE_TOOLBAR))
#define SPICE_WIDGETS_IS_SHAPE_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_WIDGETS_TYPE_SHAPE_TOOLBAR))
#define SPICE_WIDGETS_SHAPE_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_WIDGETS_TYPE_SHAPE_TOOLBAR, SpiceWidgetsShapeToolbarClass))

typedef struct _SpiceWidgetsShapeToolbar SpiceWidgetsShapeToolbar;
typedef struct _SpiceWidgetsShapeToolbarClass SpiceWidgetsShapeToolbarClass;
typedef struct _SpiceWidgetsShapeToolbarPrivate SpiceWidgetsShapeToolbarPrivate;

#define SPICE_TYPE_COLOR_BUTTON (spice_color_button_get_type ())
#define SPICE_COLOR_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_COLOR_BUTTON, SpiceColorButton))
#define SPICE_COLOR_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_COLOR_BUTTON, SpiceColorButtonClass))
#define SPICE_IS_COLOR_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_COLOR_BUTTON))
#define SPICE_IS_COLOR_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_COLOR_BUTTON))
#define SPICE_COLOR_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_COLOR_BUTTON, SpiceColorButtonClass))

typedef struct _SpiceColorButton SpiceColorButton;
typedef struct _SpiceColorButtonClass SpiceColorButtonClass;

#define SPICE_TYPE_COLOR_CHOOSER (spice_color_chooser_get_type ())
#define SPICE_COLOR_CHOOSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_COLOR_CHOOSER, SpiceColorChooser))
#define SPICE_COLOR_CHOOSER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_COLOR_CHOOSER, SpiceColorChooserClass))
#define SPICE_IS_COLOR_CHOOSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_COLOR_CHOOSER))
#define SPICE_IS_COLOR_CHOOSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_COLOR_CHOOSER))
#define SPICE_COLOR_CHOOSER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_COLOR_CHOOSER, SpiceColorChooserClass))

typedef struct _SpiceColorChooser SpiceColorChooser;
typedef struct _SpiceColorChooserClass SpiceColorChooserClass;

#define SPICE_TYPE_SLIDE_MANAGER (spice_slide_manager_get_type ())
#define SPICE_SLIDE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManager))
#define SPICE_SLIDE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManagerClass))
#define SPICE_IS_SLIDE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_SLIDE_MANAGER))
#define SPICE_IS_SLIDE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_SLIDE_MANAGER))
#define SPICE_SLIDE_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManagerClass))

typedef struct _SpiceSlideManager SpiceSlideManager;
typedef struct _SpiceSlideManagerClass SpiceSlideManagerClass;
enum  {
	SPICE_WIDGETS_SHAPE_TOOLBAR_0_PROPERTY,
	SPICE_WIDGETS_SHAPE_TOOLBAR_NUM_PROPERTIES
};
static GParamSpec* spice_widgets_shape_toolbar_properties[SPICE_WIDGETS_SHAPE_TOOLBAR_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define SPICE_TYPE_COLOR_ITEM (spice_color_item_get_type ())
#define SPICE_COLOR_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_COLOR_ITEM, SpiceColorItem))
#define SPICE_COLOR_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_COLOR_ITEM, SpiceColorItemClass))
#define SPICE_IS_COLOR_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_COLOR_ITEM))
#define SPICE_IS_COLOR_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_COLOR_ITEM))
#define SPICE_COLOR_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_COLOR_ITEM, SpiceColorItemClass))

typedef struct _SpiceColorItem SpiceColorItem;
typedef struct _SpiceColorItemClass SpiceColorItemClass;
typedef struct _Block24Data Block24Data;

#define SPICE_SERVICES_HISTORY_MANAGER_TYPE_HISTORY_ACTION (spice_services_history_manager_history_action_get_type ())
#define SPICE_SERVICES_HISTORY_MANAGER_HISTORY_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_SERVICES_HISTORY_MANAGER_TYPE_HISTORY_ACTION, SpiceServicesHistoryManagerHistoryAction))
#define SPICE_SERVICES_HISTORY_MANAGER_HISTORY_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_SERVICES_HISTORY_MANAGER_TYPE_HISTORY_ACTION, SpiceServicesHistoryManagerHistoryActionClass))
#define SPICE_SERVICES_HISTORY_MANAGER_IS_HISTORY_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_SERVICES_HISTORY_MANAGER_TYPE_HISTORY_ACTION))
#define SPICE_SERVICES_HISTORY_MANAGER_IS_HISTORY_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_SERVICES_HISTORY_MANAGER_TYPE_HISTORY_ACTION))
#define SPICE_SERVICES_HISTORY_MANAGER_HISTORY_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_SERVICES_HISTORY_MANAGER_TYPE_HISTORY_ACTION, SpiceServicesHistoryManagerHistoryActionClass))

typedef struct _SpiceServicesHistoryManagerHistoryAction SpiceServicesHistoryManagerHistoryAction;
typedef struct _SpiceServicesHistoryManagerHistoryActionClass SpiceServicesHistoryManagerHistoryActionClass;

#define SPICE_TYPE_WINDOW (spice_window_get_type ())
#define SPICE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_WINDOW, SpiceWindow))
#define SPICE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_WINDOW, SpiceWindowClass))
#define SPICE_IS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_WINDOW))
#define SPICE_IS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_WINDOW))
#define SPICE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_WINDOW, SpiceWindowClass))

typedef struct _SpiceWindow SpiceWindow;
typedef struct _SpiceWindowClass SpiceWindowClass;

#define SPICE_SERVICES_TYPE_HISTORY_MANAGER (spice_services_history_manager_get_type ())
#define SPICE_SERVICES_HISTORY_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_SERVICES_TYPE_HISTORY_MANAGER, SpiceServicesHistoryManager))
#define SPICE_SERVICES_HISTORY_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_SERVICES_TYPE_HISTORY_MANAGER, SpiceServicesHistoryManagerClass))
#define SPICE_SERVICES_IS_HISTORY_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_SERVICES_TYPE_HISTORY_MANAGER))
#define SPICE_SERVICES_IS_HISTORY_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_SERVICES_TYPE_HISTORY_MANAGER))
#define SPICE_SERVICES_HISTORY_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_SERVICES_TYPE_HISTORY_MANAGER, SpiceServicesHistoryManagerClass))

typedef struct _SpiceServicesHistoryManager SpiceServicesHistoryManager;
typedef struct _SpiceServicesHistoryManagerClass SpiceServicesHistoryManagerClass;

struct _SpiceWidgetsToolbar {
	GtkBox parent_instance;
	SpiceWidgetsToolbarPrivate * priv;
	gboolean init;
	gboolean selecting;
	SpiceCanvasItem* item;
};

struct _SpiceWidgetsToolbarClass {
	GtkBoxClass parent_class;
	void (*item_selected) (SpiceWidgetsToolbar* self, SpiceCanvasItem* item, gboolean new_item);
	void (*update_properties) (SpiceWidgetsToolbar* self);
};

struct _SpiceWidgetsShapeToolbar {
	SpiceWidgetsToolbar parent_instance;
	SpiceWidgetsShapeToolbarPrivate * priv;
};

struct _SpiceWidgetsShapeToolbarClass {
	SpiceWidgetsToolbarClass parent_class;
};

struct _SpiceWidgetsShapeToolbarPrivate {
	SpiceColorChooser* background_color_button;
	GtkScale* border_radius;
	SpiceSlideManager* manager;
};

struct _Block24Data {
	int _ref_count_;
	SpiceWidgetsShapeToolbar* self;
	GtkPopover* border_radius_popover;
};

static gint SpiceWidgetsShapeToolbar_private_offset;
static gpointer spice_widgets_shape_toolbar_parent_class = NULL;

VALA_EXTERN GType spice_widgets_toolbar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceWidgetsToolbar, g_object_unref)
VALA_EXTERN GType spice_canvas_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceCanvasItem, g_object_unref)
VALA_EXTERN GType spice_widgets_shape_toolbar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceWidgetsShapeToolbar, g_object_unref)
VALA_EXTERN GType spice_color_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceColorButton, g_object_unref)
VALA_EXTERN GType spice_color_chooser_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceColorChooser, g_object_unref)
VALA_EXTERN GType spice_slide_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceSlideManager, g_object_unref)
VALA_EXTERN void spice_widgets_toolbar_item_selected (SpiceWidgetsToolbar* self,
                                          SpiceCanvasItem* item,
                                          gboolean new_item);
VALA_EXTERN void spice_widgets_toolbar_update_properties (SpiceWidgetsToolbar* self);
VALA_EXTERN SpiceWidgetsShapeToolbar* spice_widgets_shape_toolbar_new (SpiceSlideManager* slide_manager);
VALA_EXTERN SpiceWidgetsShapeToolbar* spice_widgets_shape_toolbar_construct (GType object_type,
                                                                 SpiceSlideManager* slide_manager);
VALA_EXTERN SpiceWidgetsToolbar* spice_widgets_toolbar_construct (GType object_type);
static void spice_widgets_shape_toolbar_real_item_selected (SpiceWidgetsToolbar* base,
                                                     SpiceCanvasItem* _item,
                                                     gboolean new_item);
VALA_EXTERN GType spice_color_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceColorItem, g_object_unref)
VALA_EXTERN const gchar* spice_color_item_get_background_color (SpiceColorItem* self);
VALA_EXTERN void spice_color_chooser_set_color (SpiceColorChooser* self,
                                    const gchar* value);
VALA_EXTERN gint spice_color_item_get_border_radius (SpiceColorItem* self);
static void spice_widgets_shape_toolbar_real_update_properties (SpiceWidgetsToolbar* base);
VALA_EXTERN const gchar* spice_color_chooser_get_color (SpiceColorChooser* self);
VALA_EXTERN void spice_color_item_set_background_color (SpiceColorItem* self,
                                            const gchar* value);
VALA_EXTERN void spice_color_item_set_border_radius (SpiceColorItem* self,
                                         gint value);
VALA_EXTERN void spice_canvas_item_style (SpiceCanvasItem* self);
static GObject * spice_widgets_shape_toolbar_constructor (GType type,
                                                   guint n_construct_properties,
                                                   GObjectConstructParam * construct_properties);
static Block24Data* block24_data_ref (Block24Data* _data24_);
static void block24_data_unref (void * _userdata_);
static void _spice_widgets_shape_toolbar___lambda111_ (Block24Data* _data24_);
static void __spice_widgets_shape_toolbar___lambda111__gtk_button_clicked (GtkButton* _sender,
                                                                    gpointer self);
static void _spice_widgets_shape_toolbar___lambda112_ (SpiceWidgetsShapeToolbar* self);
VALA_EXTERN GType spice_services_history_manager_history_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceServicesHistoryManagerHistoryAction, g_object_unref)
VALA_EXTERN SpiceServicesHistoryManagerHistoryAction* spice_services_history_manager_history_action_new_item_changed (GType i_type,
                                                                                                          GBoxedCopyFunc i_dup_func,
                                                                                                          GDestroyNotify i_destroy_func,
                                                                                                          GType t_type,
                                                                                                          GBoxedCopyFunc t_dup_func,
                                                                                                          GDestroyNotify t_destroy_func,
                                                                                                          gconstpointer item,
                                                                                                          const gchar* property);
VALA_EXTERN SpiceServicesHistoryManagerHistoryAction* spice_services_history_manager_history_action_construct_item_changed (GType object_type,
                                                                                                                GType i_type,
                                                                                                                GBoxedCopyFunc i_dup_func,
                                                                                                                GDestroyNotify i_destroy_func,
                                                                                                                GType t_type,
                                                                                                                GBoxedCopyFunc t_dup_func,
                                                                                                                GDestroyNotify t_destroy_func,
                                                                                                                gconstpointer item,
                                                                                                                const gchar* property);
VALA_EXTERN GType spice_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceWindow, g_object_unref)
VALA_EXTERN SpiceWindow* spice_slide_manager_get_window (SpiceSlideManager* self);
VALA_EXTERN GType spice_services_history_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceServicesHistoryManager, g_object_unref)
VALA_EXTERN SpiceServicesHistoryManager* spice_window_get_history_manager (SpiceWindow* self);
VALA_EXTERN void spice_services_history_manager_add_undoable_action (SpiceServicesHistoryManager* self,
                                                         SpiceServicesHistoryManagerHistoryAction* action,
                                                         gboolean force_add);
static void __spice_widgets_shape_toolbar___lambda112__gtk_range_value_changed (GtkRange* _sender,
                                                                         gpointer self);
VALA_EXTERN SpiceColorChooser* spice_color_chooser_new_with_gradient (gboolean use_alpha);
VALA_EXTERN SpiceColorChooser* spice_color_chooser_construct_with_gradient (GType object_type,
                                                                gboolean use_alpha);
static void _spice_widgets_shape_toolbar___lambda113_ (SpiceWidgetsShapeToolbar* self,
                                                const gchar* color);
static void __spice_widgets_shape_toolbar___lambda113__spice_color_chooser_color_picked (SpiceColorChooser* _sender,
                                                                                  const gchar* color,
                                                                                  gpointer self);
static void spice_widgets_shape_toolbar_finalize (GObject * obj);
static GType spice_widgets_shape_toolbar_get_type_once (void);

static inline gpointer
spice_widgets_shape_toolbar_get_instance_private (SpiceWidgetsShapeToolbar* self)
{
	return G_STRUCT_MEMBER_P (self, SpiceWidgetsShapeToolbar_private_offset);
}

SpiceWidgetsShapeToolbar*
spice_widgets_shape_toolbar_construct (GType object_type,
                                       SpiceSlideManager* slide_manager)
{
	SpiceWidgetsShapeToolbar * self = NULL;
#line 28 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	g_return_val_if_fail (slide_manager != NULL, NULL);
#line 28 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	self = (SpiceWidgetsShapeToolbar*) spice_widgets_toolbar_construct (object_type);
#line 29 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	self->priv->manager = slide_manager;
#line 28 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	return self;
#line 305 "ShapeBar.c"
}

SpiceWidgetsShapeToolbar*
spice_widgets_shape_toolbar_new (SpiceSlideManager* slide_manager)
{
#line 28 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	return spice_widgets_shape_toolbar_construct (SPICE_WIDGETS_TYPE_SHAPE_TOOLBAR, slide_manager);
#line 313 "ShapeBar.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 79 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	return self ? g_object_ref (self) : NULL;
#line 321 "ShapeBar.c"
}

static void
spice_widgets_shape_toolbar_real_item_selected (SpiceWidgetsToolbar* base,
                                                SpiceCanvasItem* _item,
                                                gboolean new_item)
{
	SpiceWidgetsShapeToolbar * self;
	SpiceColorItem* item = NULL;
	SpiceColorItem* _tmp0_;
	SpiceColorChooser* _tmp1_;
	SpiceColorItem* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	GtkScale* _tmp5_;
	SpiceColorItem* _tmp6_;
	gint _tmp7_;
	gint _tmp8_;
#line 74 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	self = (SpiceWidgetsShapeToolbar*) base;
#line 75 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	if (new_item) {
#line 76 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
		spice_widgets_toolbar_update_properties ((SpiceWidgetsToolbar*) self);
#line 77 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
		return;
#line 348 "ShapeBar.c"
	}
#line 79 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp0_ = _g_object_ref0 (SPICE_IS_COLOR_ITEM (_item) ? ((SpiceColorItem*) _item) : NULL);
#line 79 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	item = _tmp0_;
#line 81 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp1_ = self->priv->background_color_button;
#line 81 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp2_ = item;
#line 81 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp3_ = spice_color_item_get_background_color (_tmp2_);
#line 81 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp4_ = _tmp3_;
#line 81 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	spice_color_chooser_set_color (_tmp1_, _tmp4_);
#line 82 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp5_ = self->priv->border_radius;
#line 82 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp6_ = item;
#line 82 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp7_ = spice_color_item_get_border_radius (_tmp6_);
#line 82 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp8_ = _tmp7_;
#line 82 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	gtk_range_set_value ((GtkRange*) _tmp5_, (gdouble) _tmp8_);
#line 74 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_g_object_unref0 (item);
#line 376 "ShapeBar.c"
}

static void
spice_widgets_shape_toolbar_real_update_properties (SpiceWidgetsToolbar* base)
{
	SpiceWidgetsShapeToolbar * self;
	SpiceColorItem* color = NULL;
	SpiceCanvasItem* _tmp0_;
	SpiceColorItem* _tmp1_;
	SpiceColorChooser* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	GtkScale* _tmp5_;
	SpiceCanvasItem* _tmp6_;
#line 85 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	self = (SpiceWidgetsShapeToolbar*) base;
#line 86 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp0_ = ((SpiceWidgetsToolbar*) self)->item;
#line 86 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPICE_TYPE_COLOR_ITEM, SpiceColorItem));
#line 86 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	color = _tmp1_;
#line 87 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp2_ = self->priv->background_color_button;
#line 87 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp3_ = spice_color_chooser_get_color (_tmp2_);
#line 87 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp4_ = _tmp3_;
#line 87 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	spice_color_item_set_background_color (color, _tmp4_);
#line 89 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp5_ = self->priv->border_radius;
#line 89 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	spice_color_item_set_border_radius (color, (gint) gtk_range_get_value ((GtkRange*) _tmp5_));
#line 91 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp6_ = ((SpiceWidgetsToolbar*) self)->item;
#line 91 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	spice_canvas_item_style (_tmp6_);
#line 85 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_g_object_unref0 (color);
#line 417 "ShapeBar.c"
}

static Block24Data*
block24_data_ref (Block24Data* _data24_)
{
#line 32 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	g_atomic_int_inc (&_data24_->_ref_count_);
#line 32 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	return _data24_;
#line 427 "ShapeBar.c"
}

static void
block24_data_unref (void * _userdata_)
{
	Block24Data* _data24_;
	_data24_ = (Block24Data*) _userdata_;
#line 32 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	if (g_atomic_int_dec_and_test (&_data24_->_ref_count_)) {
#line 437 "ShapeBar.c"
		SpiceWidgetsShapeToolbar* self;
#line 32 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
		self = _data24_->self;
#line 32 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
		_g_object_unref0 (_data24_->border_radius_popover);
#line 32 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
		_g_object_unref0 (self);
#line 32 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
		g_slice_free (Block24Data, _data24_);
#line 447 "ShapeBar.c"
	}
}

static void
_spice_widgets_shape_toolbar___lambda111_ (Block24Data* _data24_)
{
	SpiceWidgetsShapeToolbar* self;
	GtkPopover* _tmp0_;
	GtkPopover* _tmp1_;
#line 50 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	self = _data24_->self;
#line 51 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp0_ = _data24_->border_radius_popover;
#line 51 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	gtk_widget_show ((GtkWidget*) _tmp0_);
#line 52 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp1_ = _data24_->border_radius_popover;
#line 52 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp1_);
#line 467 "ShapeBar.c"
}

static void
__spice_widgets_shape_toolbar___lambda111__gtk_button_clicked (GtkButton* _sender,
                                                               gpointer self)
{
#line 50 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_spice_widgets_shape_toolbar___lambda111_ (self);
#line 476 "ShapeBar.c"
}

static void
_spice_widgets_shape_toolbar___lambda112_ (SpiceWidgetsShapeToolbar* self)
{
	SpiceServicesHistoryManagerHistoryAction* action = NULL;
	SpiceCanvasItem* _tmp0_;
	SpiceServicesHistoryManagerHistoryAction* _tmp1_;
	SpiceSlideManager* _tmp2_;
	SpiceWindow* _tmp3_;
	SpiceWindow* _tmp4_;
	SpiceServicesHistoryManager* _tmp5_;
	SpiceServicesHistoryManager* _tmp6_;
	SpiceServicesHistoryManagerHistoryAction* _tmp7_;
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp0_ = ((SpiceWidgetsToolbar*) self)->item;
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp1_ = spice_services_history_manager_history_action_new_item_changed (SPICE_TYPE_COLOR_ITEM, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, G_TYPE_INT, NULL, NULL, SPICE_IS_COLOR_ITEM (_tmp0_) ? ((SpiceColorItem*) _tmp0_) : NULL, "border-radius");
#line 56 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	action = _tmp1_;
#line 57 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp2_ = self->priv->manager;
#line 57 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp3_ = spice_slide_manager_get_window (_tmp2_);
#line 57 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp4_ = _tmp3_;
#line 57 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp5_ = spice_window_get_history_manager (_tmp4_);
#line 57 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp6_ = _tmp5_;
#line 57 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp7_ = action;
#line 57 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	spice_services_history_manager_add_undoable_action (_tmp6_, _tmp7_, FALSE);
#line 58 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	spice_widgets_toolbar_update_properties ((SpiceWidgetsToolbar*) self);
#line 55 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_g_object_unref0 (action);
#line 515 "ShapeBar.c"
}

static void
__spice_widgets_shape_toolbar___lambda112__gtk_range_value_changed (GtkRange* _sender,
                                                                    gpointer self)
{
#line 55 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_spice_widgets_shape_toolbar___lambda112_ ((SpiceWidgetsShapeToolbar*) self);
#line 524 "ShapeBar.c"
}

static void
_spice_widgets_shape_toolbar___lambda113_ (SpiceWidgetsShapeToolbar* self,
                                           const gchar* color)
{
	SpiceServicesHistoryManagerHistoryAction* action = NULL;
	SpiceCanvasItem* _tmp0_;
	SpiceServicesHistoryManagerHistoryAction* _tmp1_;
	SpiceSlideManager* _tmp2_;
	SpiceWindow* _tmp3_;
	SpiceWindow* _tmp4_;
	SpiceServicesHistoryManager* _tmp5_;
	SpiceServicesHistoryManager* _tmp6_;
	SpiceServicesHistoryManagerHistoryAction* _tmp7_;
#line 64 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	g_return_if_fail (color != NULL);
#line 65 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp0_ = ((SpiceWidgetsToolbar*) self)->item;
#line 65 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp1_ = spice_services_history_manager_history_action_new_item_changed (SPICE_TYPE_COLOR_ITEM, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, SPICE_IS_COLOR_ITEM (_tmp0_) ? ((SpiceColorItem*) _tmp0_) : NULL, "background-color");
#line 65 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	action = _tmp1_;
#line 66 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp2_ = self->priv->manager;
#line 66 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp3_ = spice_slide_manager_get_window (_tmp2_);
#line 66 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp4_ = _tmp3_;
#line 66 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp5_ = spice_window_get_history_manager (_tmp4_);
#line 66 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp6_ = _tmp5_;
#line 66 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp7_ = action;
#line 66 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	spice_services_history_manager_add_undoable_action (_tmp6_, _tmp7_, FALSE);
#line 67 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	spice_widgets_toolbar_update_properties ((SpiceWidgetsToolbar*) self);
#line 64 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_g_object_unref0 (action);
#line 566 "ShapeBar.c"
}

static void
__spice_widgets_shape_toolbar___lambda113__spice_color_chooser_color_picked (SpiceColorChooser* _sender,
                                                                             const gchar* color,
                                                                             gpointer self)
{
#line 64 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_spice_widgets_shape_toolbar___lambda113_ ((SpiceWidgetsShapeToolbar*) self, color);
#line 576 "ShapeBar.c"
}

static GObject *
spice_widgets_shape_toolbar_constructor (GType type,
                                         guint n_construct_properties,
                                         GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	SpiceWidgetsShapeToolbar * self;
	Block24Data* _data24_;
	GtkScale* _tmp0_;
	GtkScale* _tmp1_;
	GtkStyleContext* _tmp2_;
	GtkScale* _tmp3_;
	GtkScale* _tmp4_;
	GtkScale* _tmp5_;
	GtkScale* _tmp6_;
	GtkScale* _tmp7_;
	GtkButton* border_radius_button = NULL;
	GtkButton* _tmp8_;
	GtkButton* _tmp9_;
	GtkStyleContext* _tmp10_;
	GtkButton* _tmp11_;
	GtkButton* _tmp12_;
	GtkPopover* _tmp13_;
	GtkPopover* _tmp14_;
	GtkPopover* _tmp15_;
	GtkScale* _tmp16_;
	GtkButton* _tmp17_;
	GtkScale* _tmp18_;
	SpiceColorChooser* _tmp19_;
	SpiceColorChooser* _tmp20_;
	SpiceColorChooser* _tmp21_;
	SpiceColorChooser* _tmp22_;
	GtkButton* _tmp23_;
#line 32 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	parent_class = G_OBJECT_CLASS (spice_widgets_shape_toolbar_parent_class);
#line 32 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 32 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPICE_WIDGETS_TYPE_SHAPE_TOOLBAR, SpiceWidgetsShapeToolbar);
#line 32 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_data24_ = g_slice_new0 (Block24Data);
#line 32 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_data24_->_ref_count_ = 1;
#line 32 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_data24_->self = g_object_ref (self);
#line 33 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp0_ = (GtkScale*) gtk_scale_new_with_range (GTK_ORIENTATION_HORIZONTAL, 0.0, 50.0, (gdouble) 1);
#line 33 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	g_object_ref_sink (_tmp0_);
#line 33 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_g_object_unref0 (self->priv->border_radius);
#line 33 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	self->priv->border_radius = _tmp0_;
#line 34 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp1_ = self->priv->border_radius;
#line 34 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp2_ = gtk_widget_get_style_context ((GtkWidget*) _tmp1_);
#line 34 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	gtk_style_context_add_class (_tmp2_, "spice-scale");
#line 35 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp3_ = self->priv->border_radius;
#line 35 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	gtk_scale_add_mark (_tmp3_, 0.0, GTK_POS_BOTTOM, _ ("Square"));
#line 36 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp4_ = self->priv->border_radius;
#line 36 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	gtk_scale_add_mark (_tmp4_, 50.0, GTK_POS_BOTTOM, _ ("Circle"));
#line 37 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp5_ = self->priv->border_radius;
#line 37 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	g_object_set ((GtkWidget*) _tmp5_, "width-request", 200, NULL);
#line 38 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp6_ = self->priv->border_radius;
#line 38 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	gtk_scale_set_draw_value (_tmp6_, FALSE);
#line 39 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp7_ = self->priv->border_radius;
#line 39 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	g_object_set ((GtkWidget*) _tmp7_, "margin", 12, NULL);
#line 41 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp8_ = (GtkButton*) gtk_button_new_from_icon_name ("applications-engineering-symbolic", (GtkIconSize) GTK_ICON_SIZE_MENU);
#line 41 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	g_object_ref_sink (_tmp8_);
#line 41 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	border_radius_button = _tmp8_;
#line 42 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp9_ = border_radius_button;
#line 42 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp10_ = gtk_widget_get_style_context ((GtkWidget*) _tmp9_);
#line 42 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	gtk_style_context_add_class (_tmp10_, GTK_STYLE_CLASS_RAISED);
#line 43 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp11_ = border_radius_button;
#line 43 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp11_, _ ("Roundness"));
#line 45 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp12_ = border_radius_button;
#line 45 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp13_ = (GtkPopover*) gtk_popover_new ((GtkWidget*) _tmp12_);
#line 45 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	g_object_ref_sink (_tmp13_);
#line 45 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_data24_->border_radius_popover = _tmp13_;
#line 46 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp14_ = _data24_->border_radius_popover;
#line 46 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	gtk_popover_set_position (_tmp14_, GTK_POS_BOTTOM);
#line 48 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp15_ = _data24_->border_radius_popover;
#line 48 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp16_ = self->priv->border_radius;
#line 48 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	gtk_container_add ((GtkContainer*) _tmp15_, (GtkWidget*) _tmp16_);
#line 50 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp17_ = border_radius_button;
#line 50 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	g_signal_connect_data (_tmp17_, "clicked", (GCallback) __spice_widgets_shape_toolbar___lambda111__gtk_button_clicked, block24_data_ref (_data24_), (GClosureNotify) block24_data_unref, 0);
#line 55 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp18_ = self->priv->border_radius;
#line 55 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	g_signal_connect_object ((GtkRange*) _tmp18_, "value-changed", (GCallback) __spice_widgets_shape_toolbar___lambda112__gtk_range_value_changed, self, 0);
#line 61 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp19_ = spice_color_chooser_new_with_gradient (TRUE);
#line 61 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	g_object_ref_sink (_tmp19_);
#line 61 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_g_object_unref0 (self->priv->background_color_button);
#line 61 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	self->priv->background_color_button = _tmp19_;
#line 62 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp20_ = self->priv->background_color_button;
#line 62 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp20_, _ ("Shape color"));
#line 64 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp21_ = self->priv->background_color_button;
#line 64 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	g_signal_connect_object (_tmp21_, "color-picked", (GCallback) __spice_widgets_shape_toolbar___lambda113__spice_color_chooser_color_picked, self, 0);
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp22_ = self->priv->background_color_button;
#line 70 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp22_);
#line 71 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_tmp23_ = border_radius_button;
#line 71 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp23_);
#line 32 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_g_object_unref0 (border_radius_button);
#line 32 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	block24_data_unref (_data24_);
#line 32 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_data24_ = NULL;
#line 32 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	return obj;
#line 733 "ShapeBar.c"
}

static void
spice_widgets_shape_toolbar_class_init (SpiceWidgetsShapeToolbarClass * klass,
                                        gpointer klass_data)
{
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	spice_widgets_shape_toolbar_parent_class = g_type_class_peek_parent (klass);
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	g_type_class_adjust_private_offset (klass, &SpiceWidgetsShapeToolbar_private_offset);
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	((SpiceWidgetsToolbarClass *) klass)->item_selected = (void (*) (SpiceWidgetsToolbar*, SpiceCanvasItem*, gboolean)) spice_widgets_shape_toolbar_real_item_selected;
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	((SpiceWidgetsToolbarClass *) klass)->update_properties = (void (*) (SpiceWidgetsToolbar*)) spice_widgets_shape_toolbar_real_update_properties;
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	G_OBJECT_CLASS (klass)->constructor = spice_widgets_shape_toolbar_constructor;
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	G_OBJECT_CLASS (klass)->finalize = spice_widgets_shape_toolbar_finalize;
#line 752 "ShapeBar.c"
}

static void
spice_widgets_shape_toolbar_instance_init (SpiceWidgetsShapeToolbar * self,
                                           gpointer klass)
{
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	self->priv = spice_widgets_shape_toolbar_get_instance_private (self);
#line 761 "ShapeBar.c"
}

static void
spice_widgets_shape_toolbar_finalize (GObject * obj)
{
	SpiceWidgetsShapeToolbar * self;
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPICE_WIDGETS_TYPE_SHAPE_TOOLBAR, SpiceWidgetsShapeToolbar);
#line 23 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_g_object_unref0 (self->priv->background_color_button);
#line 24 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	_g_object_unref0 (self->priv->border_radius);
#line 22 "../Spice-up-1.9.1/src/Widgets/Toolbars/ShapeBar.vala"
	G_OBJECT_CLASS (spice_widgets_shape_toolbar_parent_class)->finalize (obj);
#line 776 "ShapeBar.c"
}

static GType
spice_widgets_shape_toolbar_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (SpiceWidgetsShapeToolbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spice_widgets_shape_toolbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpiceWidgetsShapeToolbar), 0, (GInstanceInitFunc) spice_widgets_shape_toolbar_instance_init, NULL };
	GType spice_widgets_shape_toolbar_type_id;
	spice_widgets_shape_toolbar_type_id = g_type_register_static (SPICE_WIDGETS_TYPE_TOOLBAR, "SpiceWidgetsShapeToolbar", &g_define_type_info, 0);
	SpiceWidgetsShapeToolbar_private_offset = g_type_add_instance_private (spice_widgets_shape_toolbar_type_id, sizeof (SpiceWidgetsShapeToolbarPrivate));
	return spice_widgets_shape_toolbar_type_id;
}

GType
spice_widgets_shape_toolbar_get_type (void)
{
	static volatile gsize spice_widgets_shape_toolbar_type_id__once = 0;
	if (g_once_init_enter (&spice_widgets_shape_toolbar_type_id__once)) {
		GType spice_widgets_shape_toolbar_type_id;
		spice_widgets_shape_toolbar_type_id = spice_widgets_shape_toolbar_get_type_once ();
		g_once_init_leave (&spice_widgets_shape_toolbar_type_id__once, spice_widgets_shape_toolbar_type_id);
	}
	return spice_widgets_shape_toolbar_type_id__once;
}

